@@ -1,8 +1,3 @@
-//  mkgeo_grid -e 20 -a -2 -b 2  > line2.geo
-//  ./convect-P2 line2 P1 1e-2 100 > line2-P1.branch
-//  ./convect-P2 line2 P2 1e-2 100 > line2-P2.branch
-//  ./convect_error < line2-P1.branch > line2-P1-cmp.branch
-//  ./convect_error < line2-P2.branch > line2-P2-cmp.branch
 #include "rheolef.h"
 using namespace rheolef;
 using namespace std;
@@ -22,19 +17,20 @@ int main (int argc, char **argv) {
   field phi_h = interpolate (Xh, phi(d,nu,0));
   characteristic X (-delta_t*uh);
   quadrature_option_type qopt;
-  qopt.set_family(quadrature_option_type::gauss_lobatto);
-  qopt.set_order(Xh.degree());
-  form m (Xh, Xh, "mass", qopt);
-  form a (Xh, Xh, "grad_grad");
+  qopt.set_family (quadrature_option_type::gauss_lobatto);
+  qopt.set_order (Xh.degree());
+  trial phi (Xh); test psi (Xh);
   branch event ("t","phi");
   dout << catchmark("nu") << nu << endl
        << event (0, phi_h);
   for (size_t n = 1; n <= n_max; n++) {
     Float t = n*delta_t;
-    field lh = riesz(Xh, compose(phi_h, X), qopt);
-    form c = (1 + delta_t*phi::sigma(d,nu,t))*m + delta_t*nu*a;
-    solver sc (c.uu());
-    phi_h.set_u() = sc.solve (lh.u() - c.ub()*phi_h.b());
+    Float c1 = 1 + delta_t*phi::sigma(d,nu,t);
+    Float c2 = delta_t*nu;
+    form  a  = integrate (c1*phi*psi + c2*dot(grad(phi),grad(psi)), qopt);
+    field lh = integrate (compose(phi_h, X)*psi, qopt);
+    solver sa (a.uu());
+    phi_h.set_u() = sa.solve (lh.u() - a.ub()*phi_h.b());
     dout << event (t, phi_h);
   }
 }
