@@ -35,7 +35,11 @@ int main (int argc, char **argv) {
     Float alpha = 1.5 + delta_t*phi::sigma(d,nu,t);
     Float beta  = delta_t*nu;
     form c = integrate (alpha*varphi*psi + beta*dot(grad(varphi),grad(psi)), qopt);
+    field lh =  2.0*integrate (compose(phi_h,      X1)*psi, qopt)
+              - 0.5*integrate (compose(phi_h_prec, X2)*psi, qopt);
+#ifdef TODO // boost::proto & g++-4.8
     field lh = integrate ((2.*compose(phi_h, X1) - 0.5*compose(phi_h_prec, X2))*psi, qopt);
+#endif // TODO
     solver sc (c.uu());
     phi_h_prec = phi_h;
     phi_h.set_u() = sc.solve (lh.u() - c.ub()*phi_h.b());
