@@ -32,11 +32,13 @@ L="
 $GEODIR/carre-dom-v2
 "
 
+tol="1e-7"
+
 for fullgeo in $L; do
  geo=`basename $fullgeo`
  dir=`dirname $fullgeo`
  for Pk in P1 P2 P3; do
-   loop_mpirun "./embankment $fullgeo $Pk 2>/dev/null | RHEOPATH=${dir} $ROUNDER 1e-10 2>/dev/null | diff -w -B $SRCDIR/embankment-$geo-$Pk.field - >/dev/null"
+   loop_mpirun "./embankment $fullgeo $Pk 2>/dev/null | RHEOPATH=${dir} $ROUNDER $tol 2>/dev/null | diff -w -B $SRCDIR/embankment-$geo-$Pk.field - >/dev/null"
    if test $? -ne 0; then status=1; fi
  done
 done
