@@ -5,22 +5,21 @@ using namespace rheolef;
 int main (int argc, char**argv) {
   environment rheolef(argc, argv);
   geo lambda (argv[1]);
+  size_t d = lambda.dimension();
   space Xh (lambda, "P1");
   field phi_h = interpolate(Xh, phi);
-  band gh (phi_h);
-  field phi_h_band = phi_h [gh.band()];
-  space Bh (gh.band(), "P1");
+  band gamma_h (phi_h);
+  field phi_h_band = phi_h [gamma_h.band()];
+  space Bh (gamma_h.band(), "P1");
   Bh.block ("isolated");
   Bh.unblock ("zero");
-  form m (Bh, Bh, "mass",      gh);
-  form a (Bh, Bh, "grad_grad", gh);
-  a = m+a;
-  size_t d = lambda.dimension();
-  field lh = riesz (Bh, f(d), gh);
-  vector<vec<Float> > b (gh.n_connected_component());
-  vector<Float>       z (gh.n_connected_component(), 0);
+  trial u (Bh); test v (Bh);
+  form  a  = integrate (gamma_h, u*v + dot(grad_s(u),grad_s(v)));
+  field lh = integrate (gamma_h, f(d)*v);
+  vector<vec<Float> > b (gamma_h.n_connected_component());
+  vector<Float>       z (gamma_h.n_connected_component(), 0);
   for (size_t i = 0; i < b.size(); i++) {
-    const domain& cci = gh.band() ["cc"+itos(i)];
+    const domain& cci = gamma_h.band() ["cc"+itos(i)];
     field phi_h_cci (Bh, 0);
     phi_h_cci [cci] = phi_h_band [cci];
     b[i] = phi_h_cci.u();
@@ -33,7 +32,6 @@ int main (int argc, char**argv) {
   vec<Float> U = sa.solve (F);
   field uh(Bh,0);
   uh.set_u() = U [range(0,uh.u().size())];
-  gh.band().save();
-  dout << catchmark("u")   << uh 
-       << catchmark("phi") << phi_h;
+  dout << catchmark("phi") << phi_h
+       << catchmark("u")   << uh;
 }
