@@ -6,16 +6,18 @@ int main (int argc, char**argv) {
   environment rheolef (argc, argv);
   Float tol    = (argc > 1) ? atof(argv[1]) : 1e-7;
   bool do_dump = (argc > 2) ? true : false;
-  field uh, phi_h;
-  din >> catchmark("u")   >> uh
-      >> catchmark("phi") >> phi_h;
+  field phi_h;
+  din >> catchmark("phi") >> phi_h;
   const space& Xh = phi_h.get_space();
   band gh (phi_h);
   space Bh (gh.band(), "P1");
-  form m (Bh, Bh, "mass",      gh);
-  form a (Bh, Bh, "grad_grad", gh);
   size_t d = Bh.get_geo().dimension();
-  field pi_h_u = interpolate(Bh, u(d));
+  field uh(Bh);
+  din >> catchmark("u")   >> uh;
+  trial u (Bh); test v (Bh);
+  form m = integrate (gh, u*v);
+  form a = integrate (gh, dot(grad_s(u),grad_s(v)));
+  field pi_h_u = interpolate(Bh, u_exact(d));
   field eh = pi_h_u - uh;
   field phi_h_band = phi_h [gh.band()];
   // TODO: loop on each cc(i)
