@@ -8,10 +8,11 @@ int main (int argc, char**argv) {
   field uh; din >> uh;
   const space& Wh = uh.get_space();
   quadrature_option_type qopt;
-  form m (Wh, Wh, "mass");
-  form a (Wh, Wh, "grad_grad");
+  trial u (Wh); test v (Wh);
+  form m = integrate (u*v);
+  form a = integrate (dot(grad_s(u),grad_s(v)));
   size_t d = Wh.get_geo().dimension();
-  field pi_h_u = interpolate(Wh, u(d));
+  field pi_h_u = interpolate(Wh, u_exact(d));
   field eh = uh - pi_h_u;
   dout << "err_l2   " << sqrt(m(eh,eh)) << endl
        << "err_h1   " << sqrt(a(eh,eh)) << endl
