@@ -11,13 +11,13 @@ int main(int argc, char**argv) {
   space Qh (omega, "P1");
   point f (0,0,0);
   f [d-1] = -1;
-  field lh = riesz (Xh, f);
-  form mp (Qh, Qh, "mass");
-  form a (Xh, Xh, "2D_D");
-  form b (Xh, Qh, "div"); b = -b;
-  form c = inv_lambda*mp;
-  field uh (Xh, 0);
-  field ph (Qh, 0);
+  trial u (Xh), p (Qh); test v (Xh), q (Qh);
+  field lh = integrate (dot(f,v));
+  form  a  = integrate (2*ddot(D(u),D(v)));
+  form  b  = integrate (-div(u)*q);
+  form  mp = integrate (p*q);
+  form  c  = inv_lambda*mp;
+  field uh (Xh, 0), ph (Qh, 0);
   solver_abtb elasticity (a.uu(), b.uu(), c.uu(), mp.uu());
   elasticity.solve (lh.u() - a.ub()*uh.b(), -(b.ub()*uh.b()),
                     uh.set_u(),             ph.set_u());
