@@ -5,12 +5,13 @@ using namespace std;
 int main (int argc, char**argv) {
   environment rheolef (argc, argv);
   geo gamma (argv[1]);
-  space Wh (gamma, argv[2]);
   size_t d = gamma.dimension();
-  form m (Wh, Wh, "mass");
-  form a (Wh, Wh, "grad_grad");
+  space Wh (gamma, argv[2]);
+  trial u (Wh); test v (Wh);
+  form m = integrate (u*v);
+  form a = integrate (dot(grad_s(u),grad_s(v)));
   field b = m*field(Wh,1);
-  field lh = riesz(Wh, f(d));
+  field lh = integrate (f(d)*v);
   csr<Float> A = {{  a.uu(),     b.u()},
                   {trans(b.u()),  0   }};
   vec<Float> B =  {  lh.u(),      0   };
