@@ -24,11 +24,5 @@ int main (int argc, char**argv) {
   derr << "err_l2   = " << err_l2 << endl
        << "err_h1   = " << err_h1 << endl
        << "err_linf = " << err_linf << endl;
-#ifdef TO_CLEAN
-  dout << setprecision(numeric_limits<Float>::digits10)
-       << catchmark("u") << uh
-       << catchmark("lambda") << lambda << endl
-       << catchmark("ue") << pi_h_u;
-#endif // TO_CLEAN
   return (err_linf < tol) ? 0 : 1;
 }
