@@ -7,9 +7,10 @@ int main (int argc, char**argv) {
   Float tol = (argc > 1) ? atof(argv[1]) : 1e+38;
   geo gamma_h;
   din >> gamma_h;
-  space Xh (gamma_h, "P1");
-  form m (Xh, Xh, "mass");
-  field one (Xh, 1);
+  space Wh (gamma_h, "P1");
+  trial u (Wh); test v (Wh);
+  form m  = integrate (u*v);
+  field one (Wh, 1);
   Float meas_gamma_h = m(one,one);
   size_t d = gamma_h.dimension();
   Float pi = acos(Float(-1));
