@@ -7,7 +7,7 @@ using namespace std;
 int main (int argc, char**argv) {
   environment rheolef (argc, argv);
   if (argc < 2) {
-    cerr << "usage: " << argv[0] << " <geo> <Re> <err> <hmin> <delta t> <n_adapt>" << endl;
+    cerr << "usage: " << argv[0] << " <geo> <Re> <err> <n_adapt>" << endl;
     exit (1);
   }
   geo    omega (argv[1]);
