@@ -24,11 +24,21 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 GEODIR="${TOP_SRCDIR}/nfem/ptst"
 SBINDIR="../../nfem/sbin"
 BINDIR="../../nfem/pbin"
-NPROC_MAX=${NPROC_MAX-"8"}
+NPROC_MAX=${NPROC_MAX-"2"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
+#echo "      not yet (skipped)"
 
-echo "      not yet (skipped)"
+run "$SBINDIR/mkgeo_grid_2d -v4 -t 10 2>/dev/null | $BINDIR/geo -upgrade - > mesh-2d-10.geo 2>/dev/null"
+if test $? -ne 0; then status=1; fi
+
+run "rm -f mesh-2d-10.field.gz"
+
+loop_mpirun "./navier_stokes_cavity mesh-2d-10 10 0 0 >/dev/null 2>/dev/null &&
+gzip -dc < mesh-2d-10.field.gz 2>/dev/null | $BINDIR/field - -field -round 1e-7 2>/dev/null | diff $SRCDIR/navier_stokes_cavity-10-10.field - >/dev/null"
+if test $? -ne 0; then status=1; fi
+
+run "rm -f mesh-2d-10.field.gz mesh-2d-10.geo"
 
 exit $status
