@@ -1,14 +1,15 @@
-struct u : std::unary_function<point,Float> {
+struct u_poiseuille : field_functor<u_poiseuille,Float> {
   Float operator() (const point& x) const {
     return a*(c+x[1])*(c-x[1]); }
-  u (const Float& c1, std::string sc) : c(c1)
+  u_poiseuille (const Float& c1, std::string sc) : c(c1)
    { a = (sc == "cartesian") ? 3/(2*pow(c,3)) : 4/pow(c,4); }
   protected: Float c, a;
 };
-struct psi : std::unary_function<point,Float> {
+struct psi_poiseuille : field_functor<psi_poiseuille,Float> {
   Float operator() (const point& x) const {
     return xy ? a*sqr(c-x[1])*(2*c+x[1]) : a*sqr(c-x[1])*sqr(c+x[1]); }
-  psi (const Float& c1, std::string sc) : c(c1), xy(sc == "cartesian")
+  psi_poiseuille (const Float& c1, std::string sc)
+   : c(c1), xy(sc == "cartesian")
    { a = xy ? -1/(2*pow(c,3)) : -1/pow(c,4); }
   protected: Float c, a; bool xy;
 };
