@@ -7,10 +7,9 @@ int main(int argc, char**argv) {
   geo omega (argv[1]);
   size_t d = omega.dimension();
   space Xh (omega, argv[2]);
-  form a  (Xh, Xh, "grad_grad");
-  form ab (Xh, Xh, "mass", omega["boundary"]);
-  a = a + ab;
-  field lh = riesz(Xh, f(d)) + riesz(Xh, g(d), "boundary");
+  trial u (Xh); test v (Xh);
+  form  a  = integrate (dot(grad(u),grad(v))) + integrate ("boundary", u*v);
+  field lh = integrate (f(d)*v) + integrate ("boundary", g(d)*v);
   field uh (Xh);
   solver sa (a.uu());
   uh.set_u() = sa.solve (lh.u() - a.ub()*uh.b());
