@@ -10,13 +10,11 @@ int main(int argc, char**argv) {
   point u (1,0,0);
   trial phi (Xh); test psi (Xh);
   form ah = integrate (dot(u,grad_h(phi))*psi + sigma*phi*psi)
-          + integrate (omega.boundary(), 
-		max(0, -dot(u,normal()))*inner(phi)*inner(psi))
-          + integrate (omega.internal_sides(), 
+          + integrate ("boundary", max(0, -dot(u,normal()))*phi*psi)
+          + integrate ("internal_sides", 
 	 	- dot(u,normal())*jump(phi)*average(psi)
                 + 0.5*alpha*abs(dot(u,normal()))*jump(phi)*jump(psi));
-  field lh = integrate (omega.boundary(),
-		max(0, -dot(u,normal()))*inner(psi));
+  field lh = integrate ("boundary", max(0, -dot(u,normal()))*psi);
   solver sah (ah.uu());
   field phi_h(Xh);
   phi_h.set_u() = sah.solve(lh.u());
