@@ -7,18 +7,11 @@ const Float epsilon = 0.01;
 int main(int argc, char**argv) {
     geo omega (argv[1]);
     space Vh (omega, "P1");
-    if (omega.dimension() <= 2) {
-      Vh.block ("left"); Vh.block ("right");
-    } else {
-      Vh.block ("back"); Vh.block ("front");
-    }
+    Vh.block ("left");
+    Vh.block ("right");
     field uh (Vh);
-    if (omega.dimension() <= 2)
-      uh["left"] = uh["right"] = 0;
-    else
-      uh["back"] = uh["front"] = 0;
+    uh["left"] = uh["right"] = 0;
     field fh (Vh, 1);
-
     space Qh (omega, "P0", "vector");
     field eta (Qh);
     eta ["east"] = 1;
