@@ -41,12 +41,12 @@ numbering_P2d::idof (
    *           This requires ordered K_idx : all "e" and then all "t",
    *           and then all "q" ... => geo format version 3 ?
    */
-  switch (K.type()) {
+  switch (K.variant()) {
     case reference_element::e: return  3*K.index() + i_dof_local;
     case reference_element::t: return  6*K.index() + i_dof_local;
     case reference_element::T: return 10*K.index() + i_dof_local;
     default : {
-        error_macro ("unexpected elment type `" << K.type() << "'");
+        error_macro ("unexpected elment type `" << K.variant() << "'");
         return 0;
     }
   }
