@@ -77,7 +77,7 @@ basis_symbolic_hermite_on_geo::put_cxx_header(ostream& out) const
       << "  static point grad_eval(" << endl
       << "    size_type    i_dof_local," << endl
       << "    const point& hat_x);" << endl
-      << "  static basic_point<point> hessian_eval(" << endl
+      << "  static tensor hessian_eval(" << endl
       << "    size_type    i_dof_local," << endl
       << "    const point& hat_x);" << endl
       << "  static void eval(" << endl
@@ -88,7 +88,7 @@ basis_symbolic_hermite_on_geo::put_cxx_header(ostream& out) const
       << "    vector<point>& values);" << endl
       << "  static void hessian_eval(" << endl
       << "    const point&   hat_x," << endl
-      << "    vector<basic_point<point> >& values);" << endl
+      << "    vector<tensor >& values);" << endl
       << "  static void hat_node(" << endl
       << "    vector<point>& hat_node);" << endl
       << "};" << endl;
@@ -118,7 +118,7 @@ basis_symbolic_hermite_on_geo::put_cxx_body(ostream& out) const
   }
   out << "    default : {" << endl
       << "      error_macro (\"dof_family: invalid i_dof_local = \" << i_dof_local);" << endl
-      << "      return reference_element::dof_family_max;" << endl
+      << "      return element_constant::dof_family_max;" << endl
       << "    }" << endl
       << "  }" << endl
       << "}" << endl; 
@@ -179,21 +179,20 @@ basis_symbolic_hermite_on_geo::put_cxx_body(ostream& out) const
   // --------------------------------------------------
   // hessian_eval
   // --------------------------------------------------
-  out << "basic_point<point>" << endl
+  out << "tensor" << endl
       << class_name.str() << "::hessian_eval(" << endl
       << "  size_type    i_dof_local," << endl
       << "  const point& hat_x)" << endl
       << "{" << endl
       << "  typedef Float T;" << endl
-      << "  point ini_p(0);" << endl
-      << "  basic_point<point> val(ini_p,ini_p,ini_p);" << endl
+      << "  tensor val(0.);" << endl
       << "  switch (i_dof_local) {" << endl;
   for (size_type i = 0; i < _basis.size(); i++) {
     out << "    case " << i << ": {" << endl;
     for (size_type j = 0; j < d; j++) 
     for (size_type k = 0; k < d; k++) {
 	ex expr = indexed_symbol(_hessian_basis[i][j][k]);
-        out << "      val[" << j << "][" << k << "] = ";
+        out << "      val(" << j << "," << k << ") = ";
         expr.print(print_csrc_double(cout));
         out << ";" << endl;
     }
@@ -249,17 +248,16 @@ basis_symbolic_hermite_on_geo::put_cxx_body(ostream& out) const
   out << "void" << endl
       << class_name.str() << "::hessian_eval(" << endl
       << "  const point&   hat_x," << endl
-      << "  vector<basic_point<point> >& values)" << endl
+      << "  vector<tensor >& values)" << endl
       << "{" << endl
-      << "  point ini_p(0);" << endl
-      << "  basic_point<point> ini_val(ini_p,ini_p,ini_p);" << endl
+      << "  tensor ini_val(0.);" << endl
       << "  values.resize(" << _basis.size() << ",ini_val);" << endl
       << "  typedef Float T;" << endl;
   for (size_type i = 0; i < _basis.size(); i++) {
     for (size_type j = 0; j < d; j++) 
     for (size_type k = 0; k < d; k++) {
       ex expr = indexed_symbol(_hessian_basis[i][j][k]);
-      out << "  values[" << i << "][" << j << "][" << k << "] = ";
+      out << "  values[" << i << "](" << j << "," << k << ") = ";
       expr.print(print_csrc_double(cout));
       out << ";" << endl;
     }
@@ -299,12 +297,13 @@ basis_symbolic_hermite::put_cxx_header(ostream& out) const
     out << "#ifndef _RHEOLEF_" << name() << "_H" << endl
         << "#define _RHEOLEF_" << name() << "_H" << endl
         << "#include \"rheolef/basis.h\"" << endl
+        << "#include \"rheolef/tensor.h\"" << endl
         << "namespace rheolef {" << endl
         << endl
         << "class " << class_name.str() << ": public basis_rep {" << endl
         << "public:" << endl
         << "  typedef size_t size_type;" << endl
-        << "  " << class_name.str() << "() : basis_rep(reference_element::Hermite) {}" << endl
+        << "  " << class_name.str() << "() : basis_rep(\"" << name() << "\", element_constant::Hermite) {}" << endl
         << "  ~" << class_name.str() << "();" << endl
         << "  size_type degree () const;" << endl
         << "  size_type size (" << endl
@@ -320,7 +319,7 @@ basis_symbolic_hermite::put_cxx_header(ostream& out) const
         << "    reference_element hat_K," << endl
         << "    size_type         i_dof_local," << endl
         << "    const point&      hat_x) const;" << endl
-        << "  basic_point<point> hessian_eval(" << endl
+        << "  tensor hessian_eval(" << endl
         << "    reference_element hat_K," << endl
         << "    size_type         i_dof_local," << endl
         << "    const point&      hat_x) const;" << endl
@@ -335,7 +334,7 @@ basis_symbolic_hermite::put_cxx_header(ostream& out) const
         << "  void hessian_eval(" << endl
         << "    reference_element hat_K," << endl
         << "    const point&      hat_x," << endl
-        << "    std::vector<basic_point<point> >&    values) const;" << endl
+        << "    std::vector<tensor >&    values) const;" << endl
         << "  void hat_node(" << endl
         << "    reference_element hat_K," << endl
         << "    std::vector<point>&    hat_node) const;" << endl
@@ -352,10 +351,10 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
     out << "#include \"" << name() << ".h\"" << endl;
     out << "using namespace rheolef;" << endl;
     out << "using namespace std;" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       operator[](i).put_cxx_header(out);
     }
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       operator[](i).put_cxx_body(out);
     }
     stringstream class_name;
@@ -382,9 +381,9 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
 	<< class_name.str() << "::size (" << endl
 	<< "    reference_element hat_K, basis_rep::dof_family_type family) const" << endl
         << "{" << endl
-	<< "    if (family==reference_element::dof_family_max)" << endl
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+	<< "    if (family == element_constant::dof_family_max)" << endl
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
@@ -396,13 +395,13 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
         << "        return 0;" << endl
         << "      }" << endl
         << "    }" << endl
-	<< "   else if (family==reference_element::Lagrange)" << endl 
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+	<< "   else if (family == element_constant::Lagrange)" << endl 
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
-          << "        return " << b.size_family(reference_element::Lagrange) << ";" << endl
+          << "        return " << b.size_family(element_constant::Lagrange) << ";" << endl
           << "      }" << endl;
     }
     out << "      default : {" << endl
@@ -410,13 +409,13 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
         << "        return 0;" << endl
         << "      }" << endl
         << "    }" << endl	
-	<< "   else if (family==reference_element::Hermite)" << endl 
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+	<< "   else if (family == element_constant::Hermite)" << endl 
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
-          << "        return " << b.size_family(reference_element::Hermite) << ";" << endl
+          << "        return " << b.size_family(element_constant::Hermite) << ";" << endl
           << "      }" << endl;
     }
     out << "      default : {" << endl
@@ -436,8 +435,8 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
         << "    reference_element hat_K," << endl
         << "    size_type         i_dof_local) const" << endl
         << "{" << endl
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
@@ -446,7 +445,7 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
     }
     out << "      default : {" << endl
         << "        error_macro (\"eval: unsupported `\" << hat_K.name() << \"' element type\");" << endl
-        << "        return reference_element::dof_family_max;" << endl
+        << "        return element_constant::dof_family_max;" << endl
         << "      }" << endl
         << "    }" << endl
         << "}" << endl;
@@ -459,8 +458,8 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
         << "    size_type         i_dof_local," << endl
         << "    const point&      hat_x) const" << endl
         << "{" << endl
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
@@ -482,8 +481,8 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
         << "    size_type         i_dof_local," << endl
         << "    const point&      hat_x) const" << endl
         << "{" << endl
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
@@ -499,14 +498,14 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
      // --------------------------------------------------
     // hessian_eval
     // --------------------------------------------------
-    out << "basic_point<point>" << endl
+    out << "tensor" << endl
         << class_name.str() << "::hessian_eval(" << endl
         << "    reference_element hat_K," << endl
         << "    size_type         i_dof_local," << endl
         << "    const point&      hat_x) const" << endl
         << "{" << endl
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
@@ -515,9 +514,7 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
     }
     out << "      default : {" << endl
         << "        error_macro (\"hessian_eval: unsupported `\" << hat_K.name() << \"' element type\");" << endl
-        << "	    point ini_p(0);" << endl
-        << "	    basic_point<point> ini_val(ini_p,ini_p,ini_p);" << endl
-        << "        return ini_val;" << endl
+        << "        return tensor(0.);" << endl
         << "      }" << endl
         << "    }" << endl
         << "}" << endl;
@@ -530,8 +527,8 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
         << "    const point&      hat_x," << endl
         << "    vector<Float>&    values) const" << endl
         << "{" << endl
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
@@ -552,8 +549,8 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
         << "    const point&      hat_x," << endl
         << "    vector<point>&    values) const" << endl
         << "{" << endl
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
@@ -572,10 +569,10 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
         << class_name.str() << "::hessian_eval(" << endl
         << "    reference_element hat_K," << endl
         << "    const point&      hat_x," << endl
-        << "    vector<basic_point<point> >&    values) const" << endl
+        << "    vector<tensor >&    values) const" << endl
         << "{" << endl
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
@@ -595,8 +592,8 @@ basis_symbolic_hermite::put_cxx_body(ostream& out) const
         << "    reference_element hat_K," << endl
         << "    vector<point>&    hat_node) const" << endl
         << "{" << endl
-        << "    switch (hat_K.type()) {" << endl;
-    for (size_type i = 0; i < reference_element::max_size; i++) {
+        << "    switch (hat_K.variant()) {" << endl;
+    for (size_type i = 0; i < reference_element::max_variant; i++) {
       const basis_symbolic_hermite_on_geo& b = operator[](i);
       if (b.size() == 0) continue;
       out << "      case reference_element::" << b.hat_K().name() << ": {" << endl
