@@ -75,12 +75,12 @@ struct hack_array_iterator {
 // the sequential representation
 // -------------------------------------------------------------
 template <class T, class A>
-class hack_array_seq_rep : public array_seq_rep<typename T::raw_type, A> {
+class hack_array_seq_rep : public array_rep<typename T::raw_type,sequential,A> {
 public:
 
 // typedefs:
 
-  typedef array_seq_rep<typename T::raw_type, A> base;
+  typedef array_rep<typename T::raw_type, sequential, A> base;
   typedef T		  	              raw_value_type;
   typedef typename T::generic_type            value_type;
   typedef typename T::generic_type            generic_value_type;
@@ -173,6 +173,9 @@ public:
   typedef typename base::iterator             iterator;
   typedef typename base::const_iterator       const_iterator;
   typedef distributed		  	      memory_type;
+  typedef std::map <size_type, automatic_value_type, std::less<size_type>, heap_allocator<std::pair<size_type,automatic_value_type> > >
+                                              scatter_map_type;
+
 
   struct dis_reference {
     dis_reference (hack_array_mpi_rep<T,A>& x, size_type dis_i)
@@ -226,31 +229,33 @@ public:
   }
 
   template<class Set>
-  void append_dis_indexes (const Set& ext_idx_set) { append_dis_entry (ext_idx_set, _ext_x); }
+  void append_dis_indexes (const Set& ext_idx_set) const { append_dis_entry (ext_idx_set, _ext_x); }
 
   template<class Set>
   void set_dis_indexes    (const Set& ext_idx_set) { get_dis_entry    (ext_idx_set, _ext_x); }
+  
+  void update_dis_entries() const;
 
   const_reference dis_at (size_type dis_i) const;
 
   template <class A2>
   void repartition (					      // old_numbering for *this
-        const array_mpi_rep<size_type,A2>& partition,	      // old_ownership
+        const array_rep<size_type,distributed,A2>& partition,	      // old_ownership
         hack_array_mpi_rep<T,A>&                new_array,	      // new_ownership (created)
-        array_mpi_rep<size_type,A2>&       old_numbering,     // new_ownership
-        array_mpi_rep<size_type,A2>&       new_numbering) const; // old_ownership
+        array_rep<size_type,distributed,A2>&    old_numbering,     // new_ownership
+        array_rep<size_type,distributed,A2>&    new_numbering) const; // old_ownership
 
 #ifdef TODO
     void permutation_apply (				      // old_numbering for *this
-        const array_mpi_rep<size_type>& new_numbering,        // old_ownership
-        array_mpi_rep<T>&               new_array) const;     // new_ownership (already allocated)
+        const array_rep<size_type,distributed,>& new_numbering,        // old_ownership
+        array_rep<T,distributed>&               new_array) const;     // new_ownership (already allocated)
 
     void reverse_permutation (                                // old_ownership for *this=iold2dis_inew
-        array_mpi_rep<size_type>& inew2dis_iold) const;       // new_ownership
+        array_rep<size_type,distributed>& inew2dis_iold) const;       // new_ownership
+#endif // TODO
 
     // get all external pairs (dis_i, values):
     const scatter_map_type& get_dis_map_entries() const { return _ext_x; }
-#endif // TODO
 
 // i/o:
 
@@ -280,17 +285,13 @@ protected:
     };
     /** 3) scatter (get_entry): specialized versions for T=container and T=simple type
       */
-public:
-    typedef std::map <size_type, automatic_value_type, std::less<size_type>, heap_allocator<std::pair<size_type,automatic_value_type> > >
-                                                      scatter_map_type;
-
 protected:
 // data:
     stash_map_type   _stash;		// for assembly msgs:
     message_type     _send;
     message_type     _receive;
     size_type        _receive_max_size;
-    scatter_map_type _ext_x;		// for ext values (scatter)
+    mutable scatter_map_type _ext_x;	// for ext values (scatter)
 };
 #endif // _RHEOLEF_HAVE_MPI
 
@@ -388,11 +389,18 @@ public:
     reference       operator[] (size_type i)       { return base::data().operator[] (i); }
     const_reference operator[] (size_type i) const { return base::data().operator[] (i); }
 
+    const_reference dis_at (size_type dis_i) const { return base::data().operator[] (dis_i); }
+
           iterator begin()       { return base::data().begin(); }
     const_iterator begin() const { return base::data().begin(); }
           iterator end()         { return base::data().end(); }
     const_iterator end() const   { return base::data().end(); }
 
+// global accessors (for compatibility with distributed interface):
+
+    template<class Set> void append_dis_indexes (const Set& ext_idx_set) const {}
+    void update_dis_entries() const {}
+
 // global modifiers (for compatibility with distributed interface):
 
     dis_reference dis_entry (size_type dis_i) { return operator[] (dis_i); }
@@ -532,7 +540,7 @@ public:
     void get_dis_entry    (const Set& ext_idx_set, Map& ext_idx_map) const { base::data().get_dis_entry (ext_idx_set, ext_idx_map); }
 
     template<class Set>
-    void append_dis_indexes (const Set& ext_idx_set)  { base::data().append_dis_indexes (ext_idx_set); }
+    void append_dis_indexes (const Set& ext_idx_set) const { base::data().append_dis_indexes (ext_idx_set); }
 
     template<class Set>
     void set_dis_indexes    (const Set& ext_idx_set)  { base::data().set_dis_indexes (ext_idx_set); }
@@ -542,6 +550,8 @@ public:
     // get all external pairs (dis_i, values):
     const scatter_map_type& get_dis_map_entries() const { return base::data().get_dis_map_entries(); }
 
+    void update_dis_entries() const { base::data().update_dis_entries(); }
+
 // global modifiers (for compatibility with distributed interface):
 
     dis_reference dis_entry (size_type dis_i)       { return base::data().dis_entry(dis_i); }
