@@ -74,6 +74,10 @@ class point_basic {
 	point_basic<T>& operator = (const point_basic<T1>& p)
 		{ _x[0] = p._x[0]; _x[1] = p._x[1]; _x[2] = p._x[2]; return *this; }
 
+#ifdef _RHEOLEF_HAVE_STD_INITIALIZER_LIST
+        point_basic (const std::initializer_list<T>& il);
+#endif // _RHEOLEF_HAVE_STD_INITIALIZER_LIST
+
 // accessors:
 
 	T& operator[](int i_coord)	        { return _x[i_coord%3]; }
@@ -277,6 +281,25 @@ template<class T> struct scalar_traits                  { typedef T type; };
 template<class T> struct scalar_traits<point_basic<T> > { typedef T type; };
 template<class T> struct  float_traits<point_basic<T> > { typedef typename float_traits<T>::type type; };
 
+#ifdef _RHEOLEF_HAVE_STD_INITIALIZER_LIST
+template<class T>
+point_basic<T>::point_basic (const std::initializer_list<T>& il) : _x() {
+#ifdef _RHEOLEF_HAVE_STD_INITIALIZER_ITERATOR
+    typedef typename std::initializer_list<T>::const_iterator const_iterator;
+#else // _RHEOLEF_HAVE_STD_INITIALIZER_ITERATOR
+    typedef const T* const_iterator;
+#endif // _RHEOLEF_HAVE_STD_INITIALIZER_ITERATOR
+    check_macro (il.size() <= 3, "unexpected initializer list size=" << il.size() << " > 3");
+    size_type i = 0;
+    for (const_iterator iter = il.begin(); iter != il.end(); ++iter, ++i) {
+      _x[i] = *iter;
+    }
+    for (i = il.size(); i < 3; ++i) {
+      _x[i] = T();
+    }
+}
+#endif // _RHEOLEF_HAVE_STD_INITIALIZER_LIST
+
 // input/output
 template<class T>
 inline
