@@ -25,6 +25,22 @@
 
 namespace rheolef {
 
+namespace edge {
+#include "edge.icc"
+} // namespace edge
+
+namespace triangle {
+#include "triangle.icc"
+} // namespace triangle
+
+namespace quadrangle {
+#include "quadrangle.icc"
+} // namespace quadrangle
+
+namespace tetrahedron {
+#include "tetrahedron.icc"
+} // namespace tetrahedron
+
 namespace prism {
 #include "prism.icc"
 } // namespace prism
@@ -35,14 +51,6 @@ namespace hexahedron {
 
 #include "reference_element_declare.cc"
 
-#ifdef TO_CLEAN
-// static data members:
-const   reference_element::dof_family_type
-        reference_element::Lagrange       = 0,
-        reference_element::Hermite        = 1,
-        reference_element::dof_family_max = 2;
-#endif // TO_CLEAN
-
 // ==============================================================================
 // generic
 // ==============================================================================
@@ -218,6 +226,64 @@ reference_element::init_local_nnode_by_variant (
   sz [reference_element::P] = (order-1)*(order-1)*(order-2)/2;
   sz [reference_element::H] = (order-1)*(order-1)*(order-1);
 }
+Float
+reference_element::side_measure (size_type loc_isid) const
+{
+#define _RHEOLEF_geo_element_auto_case(VARIANT) 			\
+    case   reference_element::VARIANT:					\
+      return reference_element_##VARIANT::side_measure (loc_isid);
+
+  switch (variant()) {
+    _RHEOLEF_geo_element_auto_case(p)
+    _RHEOLEF_geo_element_auto_case(e)
+    _RHEOLEF_geo_element_auto_case(t)
+    _RHEOLEF_geo_element_auto_case(q)
+    _RHEOLEF_geo_element_auto_case(T)
+    _RHEOLEF_geo_element_auto_case(P)
+    _RHEOLEF_geo_element_auto_case(H)
+    default: error_macro ("unexpected element variant `"<<variant()<<"'"); return 0;
+  }
+#undef _RHEOLEF_geo_element_auto_case
+}
+void
+reference_element::side_normal (size_type loc_isid, point_basic<Float>& hat_n) const
+{
+#define _RHEOLEF_geo_element_auto_case(VARIANT) 			\
+    case   reference_element::VARIANT:					\
+      reference_element_##VARIANT::side_normal (loc_isid, hat_n); break;
+
+  switch (variant()) {
+    _RHEOLEF_geo_element_auto_case(p)
+    _RHEOLEF_geo_element_auto_case(e)
+    _RHEOLEF_geo_element_auto_case(t)
+    _RHEOLEF_geo_element_auto_case(q)
+    _RHEOLEF_geo_element_auto_case(T)
+    _RHEOLEF_geo_element_auto_case(P)
+    _RHEOLEF_geo_element_auto_case(H)
+    default: error_macro ("unexpected element variant `"<<variant()<<"'");
+  }
+#undef _RHEOLEF_geo_element_auto_case
+}
+const point_basic<Float>&
+reference_element::vertex (size_type iloc) const
+{
+#define _RHEOLEF_geo_element_auto_case(VARIANT) 			\
+    case   reference_element::VARIANT:					\
+      return reference_element_##VARIANT::vertex (iloc);
+
+  static point_basic<Float> dummy;
+  switch (variant()) {
+    _RHEOLEF_geo_element_auto_case(p)
+    _RHEOLEF_geo_element_auto_case(e)
+    _RHEOLEF_geo_element_auto_case(t)
+    _RHEOLEF_geo_element_auto_case(q)
+    _RHEOLEF_geo_element_auto_case(T)
+    _RHEOLEF_geo_element_auto_case(P)
+    _RHEOLEF_geo_element_auto_case(H)
+    default: error_macro ("unexpected element variant `"<<variant()<<"'"); return dummy;
+  }
+#undef _RHEOLEF_geo_element_auto_case
+}
 // ==============================================================================
 // point
 // ==============================================================================
@@ -251,6 +317,21 @@ reference_element_p::first_inod_by_variant (
   if (subgeo_variant == reference_element::p) return 0;
   return 1;
 }
+Float
+reference_element_p::side_measure (size_type loc_isid)
+{
+  return 0;
+}
+void
+reference_element_p::side_normal (size_type loc_isid, point_basic<Float>& hat_n)
+{
+}
+const point_basic<Float>&
+reference_element_p::vertex (size_type iloc)
+{
+  static point_basic<Float> dummy;
+  return dummy;
+}
 // ==============================================================================
 // edge
 // ==============================================================================
@@ -300,6 +381,21 @@ reference_element_e::first_inod_by_variant (
   if (subgeo_variant == reference_element::e) return 2;
   return order+1;
 }
+Float
+reference_element_e::side_measure (size_type loc_isid)
+{
+  return 1;
+}
+void
+reference_element_e::side_normal (size_type loc_isid, point_basic<Float>& hat_n)
+{
+  hat_n[0] = (loc_isid == 0) ? -1 : 1;
+}
+const point_basic<Float>&
+reference_element_e::vertex (size_type iloc)
+{
+  return edge::vertex[iloc];
+}
 // ==============================================================================
 // triangle
 // ==============================================================================
@@ -369,6 +465,26 @@ reference_element_t::first_inod_by_variant (
   if (subgeo_variant == reference_element::t) return 3 + 3*(order-1);
   return (order+1)*(order+2)/2;
 }
+Float
+reference_element_t::side_measure (size_type loc_isid)
+{
+  return (loc_isid != 1) ? 1 : sqrt(Float(2.));
+}
+void
+reference_element_t::side_normal (size_type loc_isid, point_basic<Float>& hat_n)
+{
+  switch (loc_isid) {
+    case 0:  hat_n = point_basic<Float>( 0,-1); break;
+    case 1:  hat_n = point_basic<Float>( 1, 1)/sqrt(Float(2)); break;
+    case 2:
+    default: hat_n = point_basic<Float>(-1,0); break;
+  }
+}
+const point_basic<Float>&
+reference_element_t::vertex (size_type iloc)
+{
+  return triangle::vertex[iloc];
+}
 // ==============================================================================
 // quadrangle
 // ==============================================================================
@@ -444,6 +560,27 @@ reference_element_q::first_inod_by_variant (
   if (subgeo_variant == reference_element::q) return 4 + 4*(order-1);
   return (order+1)*(order+1);
 }
+Float
+reference_element_q::side_measure (size_type loc_isid)
+{
+  return 2;
+}
+void
+reference_element_q::side_normal (size_type loc_isid, point_basic<Float>& hat_n) 
+{
+  switch (loc_isid) {
+    case 0:  hat_n = point_basic<Float>( 0,-1); break;
+    case 1:  hat_n = point_basic<Float>( 1, 0); break;
+    case 2:  hat_n = point_basic<Float>( 0, 1); break;
+    case 3:
+    default: hat_n = point_basic<Float>(-1, 0); break;
+  }
+}
+const point_basic<Float>&
+reference_element_q::vertex (size_type iloc)
+{
+  return quadrangle::vertex[iloc];
+}
 // ==============================================================================
 // tetra
 // ==============================================================================
@@ -604,6 +741,28 @@ reference_element_T::face2edge_orient (size_type loc_iface, size_type loc_iface_
 {
   return geo_element_T_fac2edg_orient [loc_iface][loc_iface_jedg];
 }
+Float
+reference_element_T::side_measure (size_type loc_isid)
+{
+  return (loc_isid != 3) ? 0.5 : sqrt(Float(3.))/2.;
+}
+void
+reference_element_T::side_normal (size_type loc_isid, point_basic<Float>& hat_n)
+{
+  // TODO: generate side_normal automatically from tetrahedron.icc, as it depends upon conventions
+  switch (loc_isid) {
+    case 0:  hat_n = point_basic<Float>( 0, 0,-1); break;
+    case 1:  hat_n = point_basic<Float>(-1, 0, 0); break;
+    case 2:  hat_n = point_basic<Float>( 0,-1, 0); break;
+    case 3:
+    default: hat_n = point_basic<Float>( 1, 1, 1)/sqrt(Float(3)); break;
+  }
+}
+const point_basic<Float>&
+reference_element_T::vertex (size_type iloc)
+{
+  return tetrahedron::vertex[iloc];
+}
 // ==============================================================================
 // prism
 // ==============================================================================
@@ -770,6 +929,23 @@ reference_element_P::first_inod_by_variant (
   if (subgeo_variant == reference_element::P) return 6 + 9*(order-1) + 2*((order-1)*(order-2)/2) + 3*(order-1)*(order-1);
   return ((order+1)*(order+1)*(order+2))/2;
 }
+Float
+reference_element_P::side_measure (size_type loc_isid)
+{
+  if (loc_isid <= 1) return 0.5;              // top and bottom faces
+  if (loc_isid == 3) return 2*sqrt(Float(2)); // largest vertical face
+  return 2;                                   // two others vertical faces
+}
+void
+reference_element_P::side_normal (size_type loc_isid, point_basic<Float>& hat_n)
+{
+  fatal_macro ("side_normal(3d): not yet");
+}
+const point_basic<Float>&
+reference_element_P::vertex (size_type iloc)
+{
+  return prism::vertex[iloc];
+}
 // ==============================================================================
 // hexa
 // ==============================================================================
@@ -946,5 +1122,21 @@ reference_element_H::first_inod_by_variant (
   if (subgeo_variant == reference_element::H) return 8 + 12*(order-1) + 6*(order-1)*(order-1);
   return (order+1)*(order+1)*(order+1);
 }
+Float
+reference_element_H::side_measure (size_type loc_isid)
+{
+  return 2;
+}
+void
+reference_element_H::side_normal (size_type loc_isid, point_basic<Float>& hat_n)
+{
+  fatal_macro ("side_normal(3d): not yet");
+}
+const point_basic<Float>&
+reference_element_H::vertex (size_type iloc)
+{
+  return hexahedron::vertex[iloc];
+}
+// ==============================================================================
 
 } // namespace rheolef
