@@ -314,6 +314,7 @@ static point_basic<T> eig2x2 (const tensor_basic<T>& a, tensor_basic<T>& q)
 {
     // TODO: check if a is symetric !
     point_basic<T> d (0,0,0);
+    q.fill (0);
     if (a(0,1) == 0) {
       // a is already diagonal
       if (a(0,0) >= a(1,1)) {
@@ -332,20 +333,27 @@ static point_basic<T> eig2x2 (const tensor_basic<T>& a, tensor_basic<T>& q)
     // here a(0,1) != 0
     T discr = sqr(a(1,1) - a(0,0)) + 4*sqr(a(0,1));
     T trace = a(0,0) + a(1,1);
-    d[0] = (trace + ::sqrt(discr))/2; 
-    d[1] = (trace - ::sqrt(discr))/2;
+    d[0] = (trace + sqrt(discr))/2; 
+    d[1] = (trace - sqrt(discr))/2;
     T lost_precision = 1e-6;
     if (fabs(d[0]) + lost_precision*fabs(d[1]) == fabs(d[0])) { // d[1] == 0 up to machine precision
 	d[1] = 0;
     }
     T c0 = (d[0]-a(0,0))/a(0,1);
-    T n0 = ::sqrt(1+sqr(c0));
+    T n0 = sqrt(1+sqr(c0));
     q(0,0) =  1/n0;
     q(1,0) = c0/n0;
     T c1 = (d[1]-a(0,0))/a(0,1);
-    T n1 = ::sqrt(1+sqr(c1));
+    T n1 = sqrt(1+sqr(c1));
     q(0,1) =  1/n1;
     q(1,1) = c1/n1;
+#ifdef TO_CLEAN
+    tensor_basic<T> I = tensor_basic<T>::eye(2);
+warning_macro ("q=" << q);
+warning_macro ("err0=" << norm(I-trans(q,2)*q));
+warning_macro ("err1=" << norm(I-q*trans(q,2)));
+warning_macro ("err2=" << norm(a-q*diag(d)*trans(q,2)));
+#endif // TO_CLEAN
     return d;
 }
 // ------------------------------------------
@@ -390,7 +398,7 @@ tensor_basic<T>::svd (tensor_basic<T>& u, tensor_basic<T>& v, size_t dim) const
     size_t k = i;
     T p = S[i];
     for (size_t j = i+1; j < dim; j++) {
-      if (S[j] > p) {
+      if (j < 3 && S[j] > p) {
         k = j;
         p = S[j];
       }
