@@ -57,6 +57,10 @@ class tensor_basic {
 	tensor_basic (const tensor_basic<T>& a);
 	static tensor_basic<T> eye (size_type d = 3);
 
+#ifdef _RHEOLEF_HAVE_STD_INITIALIZER_LIST
+        tensor_basic (const std::initializer_list<std::initializer_list<T> >& il);
+#endif // _RHEOLEF_HAVE_STD_INITIALIZER_LIST
+
 // affectation:
 
 	tensor_basic<T>& operator = (const tensor_basic<T>& a);
@@ -127,6 +131,8 @@ class tensor_basic {
 	friend tensor_basic<U> inv  (const tensor_basic<U>& a, size_t d = 3);
 	template <class U>
 	friend tensor_basic<U> diag (const point_basic<U>& d);
+	template <class U>
+	friend point_basic<U> diag (const tensor_basic<U>& a);
 
 // metric and geometric transformations:
 
@@ -162,6 +168,10 @@ class tensor_basic {
 };
 typedef tensor_basic<Float> tensor;
 
+// nonlinear algebra:
+template<class T>
+tensor_basic<T> exp (const tensor_basic<T>& a, size_t d = 3);
+
 // inputs/outputs:
 template<class T>
 inline
@@ -223,6 +233,29 @@ tensor_basic<T>::tensor_basic (const tensor_basic<T>& a)
     for (size_type i = 0; i < 3; i++) for (size_type j = 0; j < 3; j++)
       _x[i][j] = a._x[i][j];
 }
+#ifdef _RHEOLEF_HAVE_STD_INITIALIZER_LIST
+template<class T>
+tensor_basic<T>::tensor_basic (const std::initializer_list<std::initializer_list<T> >& il) : _x() {
+#ifdef _RHEOLEF_HAVE_STD_INITIALIZER_ITERATOR
+    typedef typename std::initializer_list<std::initializer_list<T> >::const_iterator const_iterator;
+    typedef typename std::initializer_list<T>::const_iterator                         const_iterator_row;
+#else // _RHEOLEF_HAVE_STD_INITIALIZER_ITERATOR
+    typedef const std::initializer_list<T>* const_iterator;
+    typedef const T*                        const_iterator_row;
+#endif // _RHEOLEF_HAVE_STD_INITIALIZER_ITERATOR
+    fill (T());
+    check_macro (il.size() <= 3, "unexpected initializer list size=" << il.size() << " > 3");
+    size_type i = 0;
+    for (const_iterator iter = il.begin(); iter != il.end(); ++iter, ++i) {
+      const std::initializer_list<T>& row = *iter;
+      check_macro (row.size() <= 3, "unexpected initializer list size=" << row.size() << " > 3");
+      size_type j = 0;
+      for (const_iterator_row jter = row.begin(); jter != row.end(); ++jter, ++j) {
+        _x[i][j] = *jter;
+      }
+    }
+}
+#endif // _RHEOLEF_HAVE_STD_INITIALIZER_LIST
 template<class T>
 inline
 tensor_basic<T>&
@@ -345,6 +378,17 @@ diag (const point_basic<T>& d)
   a(2,2) = d[2];
   return a;
 }
+template<class T>
+inline
+point_basic<T>
+diag (const tensor_basic<T>& a)
+{
+  point_basic<T> d;
+  d[0] = a(0,0);
+  d[1] = a(1,1);
+  d[2] = a(2,2);
+  return d;
+}
 template <class T>
 inline
 T
