@@ -50,6 +50,11 @@ public:
   tensor4_basic (const T& init_val = 0);
   tensor4_basic (const tensor4_basic<T>& a);
 
+#ifdef _RHEOLEF_HAVE_STD_INITIALIZER_LIST
+        tensor4_basic (const std::initializer_list<std::initializer_list<
+			     std::initializer_list<std::initializer_list<T> > > >& il);
+#endif // _RHEOLEF_HAVE_STD_INITIALIZER_LIST
+
 // affectation:
 
   tensor4_basic<T>& operator= (const tensor4_basic<T>& a);
@@ -60,11 +65,35 @@ public:
   T&       operator()(size_type i, size_type j, size_type k, size_type l);
   const T& operator()(size_type i, size_type j, size_type k, size_type l) const;
 
+// algebra:
+
+  tensor4_basic<T>& operator*= (const T& k);
+  tensor4_basic<T>& operator/= (const T& k) { return operator*= (1./k); }
+  tensor4_basic<T>  operator+ (const tensor4_basic<T>& b) const;
+  tensor4_basic<T>  operator- (const tensor4_basic<T>& b) const;
+
+// io:
+  std::ostream& put (std::ostream& out, size_type d=3) const;
+
 // data:
 protected:
   T _x [3][3][3][3];
 };
 typedef tensor4_basic<Float> tensor4;
+
+// nonlinear algebra:
+template <class T>
+T norm2 (const tensor4_basic<T>&);
+template <class T>
+T norm (const tensor4_basic<T>& a) { return sqrt(norm2(a)); }
+template <class T>
+tensor4_basic<T> dexp (const tensor_basic<T>& a, size_t d = 3);
+
+// algebra:
+template <class T>
+tensor_basic<T> ddot (const tensor4_basic<T>&, const tensor_basic<T>&);
+template <class T>
+tensor_basic<T> ddot (const tensor_basic<T>&, const tensor4_basic<T>&);
 //>tensor4:
 // -----------------------------------------------------------------------
 // inlined
@@ -72,30 +101,6 @@ typedef tensor4_basic<Float> tensor4;
 template<class T> struct  float_traits<tensor4_basic<T> > { typedef typename float_traits<T>::type type; };
 template<class T> struct scalar_traits<tensor4_basic<T> > { typedef T type; };
 
-template<class T>
-inline
-tensor4_basic<T>&
-tensor4_basic<T>::operator= (const T& val)
-{ 
-    for (size_type i = 0; i < 3; i++)
-    for (size_type j = 0; j < 3; j++)
-    for (size_type k = 0; k < 3; k++)
-    for (size_type l = 0; l < 3; l++)
-      _x[i][j][k][l] = val;
-    return *this;
-}
-template<class T>
-inline
-tensor4_basic<T>&
-tensor4_basic<T>::operator= (const tensor4_basic<T>& a)
-{
-    for (size_type i = 0; i < 3; i++)
-    for (size_type j = 0; j < 3; j++)
-    for (size_type k = 0; k < 3; k++)
-    for (size_type l = 0; l < 3; l++)
-      _x[i][j][k][l] = a._x[i][j][k][l];
-    return *this;
-}
 template<class T>
 inline
 tensor4_basic<T>::tensor4_basic (const T& init_val)
@@ -122,22 +127,29 @@ tensor4_basic<T>::operator() (size_type i, size_type j, size_type k, size_type l
 {
     return _x[i%3][j%3][k%3][l%3];
 }
+template <class T>
+inline
+tensor4_basic<T>
+operator* (const T& k, const tensor4_basic<T>& a)
+{
+  tensor4_basic<T> b = a;
+  b *= k;
+  return b;
+}
+template <class T>
+inline
+tensor4_basic<T>
+operator* (const tensor4_basic<T>& a, const T& k)
+{
+  return k*a;
+}
+template <class T>
+inline
+tensor4_basic<T>
+operator/ (const tensor4_basic<T>& a, const T& k)
+{
+  return (1./k)/a;
+}
 
 }// namespace rheolef
 # endif /* _RHEOLEF_TENSOR4_H */
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
