@@ -109,14 +109,25 @@ field::field (const const_field_component& ui)
 
 Float 
 field::operator() (const point& x, size_type i_comp) const
+{
+    Float v;
+    bool is_inside;
+    evaluate(x, v, is_inside, i_comp);
+    check_macro(is_inside,
+	"evaluate: point (" << x << ") is outside the mesh.");
+    return v;
+}
+  
+void
+field::evaluate (const point& x, Float& result, bool& is_inside, size_type i_comp) const
 {
     const geo& Th = get_geo();
     Th.init_localizer (Th.boundary());
     size_type K_idx;
-    check_macro (Th.localize (x, K_idx),
-	"evaluate: point (" << x << ") is outside the mesh.");
+    is_inside=Th.localize (x, K_idx);
+    if (!is_inside) { result=numeric_limits<Float>::max(); return; }
     meshpoint hat_x_in_K = Th.hatter (x, K_idx);
-    return evaluate (hat_x_in_K, i_comp);
+    result = evaluate (hat_x_in_K, i_comp);
 }
 void 
 field::evaluate (const point& x, Float& result) const
@@ -127,17 +138,33 @@ field::evaluate (const point& x, Float& result) const
 }
 void 
 field::evaluate (const point& x, point& result) const
+{
+    bool is_inside;
+    evaluate (x, result, is_inside);
+    check_macro(is_inside,
+	"evaluate: point (" << x << ") is outside the mesh.");
+}
+void 
+field::evaluate (const point& x, point& result, bool& is_inside) const
 {
     check_macro (get_valued_type() == fem_helper::vectorial ||
 	   (get_valued_type() == fem_helper::scalar && dimension() == 1),
 	"evaluate: vector field expected, get " << get_valued() << " one.");
     for (size_type i_comp = 0; i_comp < n_component(); i_comp++)
-        result [i_comp] = operator() (x, i_comp);
+        { evaluate(x, result [i_comp], is_inside, i_comp); }
     for (size_type i_comp = n_component(); i_comp < 3; i_comp++)
         result [i_comp] = 0;
 }
 void 
 field::evaluate (const point& x, tensor& result) const
+{
+    bool is_inside;
+    evaluate (x, result, is_inside);
+    check_macro(is_inside,
+	"evaluate: point (" << x << ") is outside the mesh.");
+}
+void 
+field::evaluate (const point& x, tensor& result, bool& is_inside) const
 {
     fem_helper::coordinate_type   sys_coord = coordinate_system_type();
     fem_helper::valued_field_type valued    = get_valued_type();
@@ -148,7 +175,7 @@ field::evaluate (const point& x, tensor& result) const
     result = Float(0);
     for (size_type i_comp = 0; i_comp < n_component(); i_comp++) {
       fem_helper::pair_size_type ij_comp = fem_helper::tensor_subscript (valued, sys_coord, i_comp);
-      result (ij_comp.first, ij_comp.second) = operator() (x, i_comp);
+      evaluate(x, result(ij_comp.first, ij_comp.second), is_inside, i_comp); 
       if (ij_comp.first != ij_comp.second)
 	result (ij_comp.second, ij_comp.first) = result (ij_comp.first, ij_comp.second);
     }
@@ -157,7 +184,7 @@ field::evaluate (const point& x, tensor& result) const
 void
 field::get_dof_value (const basis& b, const geo_element& K, tiny_vector<Float>& dofv, size_type i_comp) const
 {
-    size_t nb_dof = b.size (K.type()) ;
+    size_t nb_dof = b.size (K.variant()) ;
     tiny_vector<size_type> dof  (nb_dof);
     dofv.resize (nb_dof);
     
@@ -175,7 +202,7 @@ void
 field::get_dof_value_from_global (const basis& b, const geo_element& S,
 	tiny_vector<Float>& dofv, size_type i_comp) const
 {
-    size_t nb_dof = b.size (S.type()) ;
+    size_t nb_dof = b.size (S.variant()) ;
     tiny_vector<size_type> msh_dof  (nb_dof);
     tiny_vector<size_type> dmn_dof  (nb_dof);
     dofv.resize (nb_dof);
@@ -433,6 +460,13 @@ operator * (const field& x, const field& y)
         return z;
     }
     size_type d = x.dimension(); // get physical dimension
+    // both x and y vectorial ? then scalar product
+    if ((xt == fem_helper::vectorial) && (yt == fem_helper::vectorial)) {
+      field z (y.get_space()[0], Float(0));
+      for (size_type j = 0; j < d; j++)
+          z += x[j] * y[j];
+      return z;
+    }
     // x vectorial and y tensorial ?
     if ((xt == fem_helper::tensorial || xt == fem_helper::unsymmetric_tensorial) &&
         (yt == fem_helper::vectorial)) {
@@ -480,8 +514,18 @@ operator / (const field& x, const field& y)
     check_macro (x.get_space() == y.get_space(),
 	"incompatible spaces for field/field operator");
     field z (x.get_space());
-    z.u = x.u / y.u;
-    z.b = x.b / y.b;
+    if (x.n_component()>1 && y.n_component()==1) 
+     {
+	for (size_t i=0; i<x.n_component(); i++)
+	 {
+	    z[i] = x[i]/y;    
+	 }
+     }
+    else
+     {
+	z.u = x.u / y.u;
+	z.b = x.b / y.b;
+     }
     return z;
 }
 // tensor field transposition
@@ -932,7 +976,7 @@ field::field(const space& V, const field& w)
   vec<Float>::iterator xb = b.begin();
   for (geo::const_iterator iter_K = g.begin(); iter_K != g.end(); iter_K++) {
       const geo_element& K = *iter_K;
-      size_type nb_dof = b_V.size(K.type()) ;
+      size_type nb_dof = b_V.size(K.variant()) ;
       tiny_vector<space::size_type> dof_V(nb_dof), dof_W(nb_dof);
       V.set_dof(K, dof_V, 0) ;
       W.set_dof(K, dof_W, 0) ;
