@@ -98,6 +98,7 @@ georep_calculate_metric_bamg (const field& u0, field& metric, const adapt_option
         bamg_name = basename + ".bamg";
         ofstream bamg_stream (bamg_name.c_str());
         if (verbose) cerr << "! file \"" << bamg_name << "\" created." << endl;
+	bamg_stream << setanglecorner(opt.anglecorner);
         if (opt.double_precision) bamg_stream << setprecision(numeric_limits<Float>::digits10) ;
         bamg_stream << bamg << g;
         // create also a cad file : basename + ".cad"
@@ -123,6 +124,7 @@ georep_calculate_metric_bamg (const field& u0, field& metric, const adapt_option
     int status = 0;
     string command = opt.generator;
     command += " -coef "     + ftos(opt.hcoef);
+    command += " -errg "     + ftos(opt.err);
     command += " -hmin "     + ftos(opt.hmin);
     command += " -hmax "     + ftos(opt.hmax);
     command += " -ratio "    + ftos(opt.ratio);
@@ -229,6 +231,7 @@ georep_calculate_metric_bamg (const Vector<field>& criteria, field& metric, cons
         bamg_name = basename + ".bamg";
         ofstream bamg_stream (bamg_name.c_str());
         if (opt.double_precision) bamg_stream << setprecision(numeric_limits<Float>::digits10) ;
+	bamg_stream << setanglecorner(opt.anglecorner);
         if (verbose) cerr << "! file \"" << bamg_name << "\" created." << endl;
         bamg_stream << bamg << g;
         // create also a cad file : basename + ".cad"
@@ -254,6 +257,7 @@ georep_calculate_metric_bamg (const Vector<field>& criteria, field& metric, cons
     int status = 0;
     string command = opt.generator;
     command += " -coef "     + ftos(opt.hcoef);
+    command += " -errg "     + ftos(opt.err);
     command += " -hmin "     + ftos(opt.hmin);
     command += " -hmax "     + ftos(opt.hmax);
     command += " -ratio "    + ftos(opt.ratio);
@@ -360,6 +364,7 @@ georep_metric_adapt_bamg (const field& mh0, georep& adapt_g, const adapt_option_
         bamg_name = basename + ".bamg";
         ofstream bamg_stream (bamg_name.c_str());
         if (opt.double_precision) bamg_stream << setprecision(numeric_limits<Float>::digits10) ;
+	bamg_stream << setanglecorner(opt.anglecorner);
         if (verbose) cerr << "! file \"" << bamg_name << "\" created." << endl;
         bamg_stream << bamg << g;
         // create also a cad file : basename + ".cad"
@@ -383,6 +388,7 @@ georep_metric_adapt_bamg (const field& mh0, georep& adapt_g, const adapt_option_
     int status = 0;
     string command =  opt.generator;
     command += " -coef "     + ftos(opt.hcoef);
+    command += " -errg "     + ftos(opt.err);
     command += " -hmin "     + ftos(opt.hmin);
     command += " -hmax "     + ftos(opt.hmax);
     command += " -ratio "    + ftos(opt.ratio);
@@ -540,6 +546,7 @@ georep_adapt_bamg (const field& u0, georep& adapt_g, const adapt_option_type& op
 	   }
            ofstream bamg_stream (bamg_name.c_str());
            if (opt.double_precision) bamg_stream << setprecision(numeric_limits<Float>::digits10) ;
+	   bamg_stream << setanglecorner(opt.anglecorner);
            if (verbose) cerr << "! file \"" << bamg_name << "\" created." << endl;
            bamg_stream << bamg << g;
            // create also a cad file : basename + ".cad"
@@ -565,6 +572,7 @@ georep_adapt_bamg (const field& u0, georep& adapt_g, const adapt_option_type& op
     int status = 0;
     string command = opt.generator;
     command += " -coef "     + ftos(opt.hcoef);
+    command += " -errg "     + ftos(opt.err);
     command += " -hmin "     + ftos(opt.hmin);
     command += " -hmax "     + ftos(opt.hmax);
     command += " -ratio "    + ftos(opt.ratio);
@@ -701,6 +709,7 @@ georep_adapt_bamg (const Vector<field>& criteria, georep& adapt_g, const adapt_o
         bamg_name = basename + ".bamg";
         ofstream bamg_stream (bamg_name.c_str());
         if (opt.double_precision) bamg_stream << setprecision(numeric_limits<Float>::digits10) ;
+	bamg_stream << setanglecorner(opt.anglecorner);
         if (verbose) cerr << "! file \"" << bamg_name << "\" created." << endl;
         bamg_stream << bamg << g;
         // create also a cad file : basename + ".cad"
@@ -724,6 +733,7 @@ georep_adapt_bamg (const Vector<field>& criteria, georep& adapt_g, const adapt_o
     string adapt_key_name  = adapt_name + ".bb";
     int status = 0;
     string command = opt.generator;
+    command += " -errg "     + ftos(opt.err);
     command += " -coef "     + ftos(opt.hcoef);
     command += " -hmin "     + ftos(opt.hmin);
     command += " -hmax "     + ftos(opt.hmax);
