@@ -293,8 +293,11 @@ georep::gnuplot2d (const string& basename, plot_options& opt) const
    }
   ofstream gdat;
   string coma=",";
-  plot << "set xrange ["<<opt.xmin[0]<<":"<<opt.xmax[0]<<"]" << endl; // to allow mouse-zoom
-  plot << "set yrange ["<<opt.xmin[1]<<":"<<opt.xmax[1]<<"]" << endl;
+  if (!opt.keep_user_range)
+   {
+     plot << "set xrange ["<<opt.xmin[0]<<":"<<opt.xmax[0]<<"]" << endl; // to allow mouse-zoom
+     plot << "set yrange ["<<opt.xmin[1]<<":"<<opt.xmax[1]<<"]" << endl;
+   }
   plot << "plot ";
   if (!opt.silhouette)
    {
@@ -357,7 +360,7 @@ georep::gnuplot2d (const string& basename, plot_options& opt) const
   //
   plot << endl; // because of the trailing "\"
   plot << endl; 
-  if (opt.execute) plot << "pause -1 \"<return>\"\n";
+  if (opt.execute && opt.pause) plot << "pause -1 \"<return>\"\n";
   if (opt.postscript && (!opt.noxplot)) 
    {
 	plot << "set output '" << basename << ".eps'" << endl;
@@ -371,7 +374,9 @@ georep::gnuplot2d (const string& basename, plot_options& opt) const
   int status = 0;
   char command [1000];
   if (opt.execute) {
-      sprintf (command, "gnuplot -persist %s.plot", basename.c_str());
+      if (opt.persist)
+	      sprintf (command, "gnuplot -persist %s.plot", basename.c_str());
+      else    sprintf (command, "gnuplot  %s.plot", basename.c_str());
       if (opt.verbose) clog << "! " << command << endl;
       status = system (command);
   }
