@@ -535,7 +535,7 @@ georep::sort_interface (const domain& d, const interface& bc) const
     check_macro (actual_order_is_set, "Element whose normal is marked " 
     	<< bc.element_of_known_normal << " not found!");
     check_macro (S.size()==1, "The interface has to be a connected set!");
-    if ((*F.begin())!=(*L.begin())) { warning_macro( "Closed interfaces not tested yet! Weird things might happen... \nIn particular, tangents/normals at 'end' points...") ;}
+    if ((*F.begin())==(*L.begin())) { warning_macro( "Closed interfaces not tested yet! Weird things might happen... \nIn particular, tangents/normals at 'end' points...") ;}
     check_macro ((*S.begin()).size()==d.size(), "Not all elements found?");
     if (bc.is_reversed())
       bc.set_sorted( (*S.begin()).size(), (*S.begin()).rbegin(), (*S.begin()).rend());
