@@ -214,7 +214,7 @@ void gnuplot_element(ostream& s, const geo_element& g, georep::const_iterator_no
 	    break ;
 	    }
   default  : {
-	    error_macro("geo_element: unexpected type `" << int(g.type())
+	    error_macro("geo_element: unexpected type `" << int(g.variant())
 		 << "' and dimension "               << dim);
 	    }
   }
@@ -258,7 +258,7 @@ plotmtv_element(ostream& s, const geo_element& g, georep::const_iterator_node x,
 	    break ;
 	    }
   default  : {
-	    error_macro("geo_element: unexpected type `" << int(g.type())
+	    error_macro("geo_element: unexpected type `" << int(g.variant())
 		 << "' and dimension "               << dim);
 	    }
   }
@@ -299,7 +299,7 @@ atom_element(ostream& s, const geo_element& g, georep::const_iterator_node x, ge
 	    break ;
 	    }
   default  : {
-	    error_macro("atom_element: unexpected type `" << int(g.type())
+	    error_macro("atom_element: unexpected type `" << int(g.variant())
 		 << "' and dimension " << dim);
 	    }
   }
@@ -323,7 +323,7 @@ void x3d_element(ostream& s, const geo_element& g, georep::const_iterator_node x
              x3d_face (s, x[g[1]], x[g[2]], x[g[3]], dim, scale, x0, dx);
 	     break ;
   default  : {
-	    error_macro("x3d_element: unexpected type `" << int(g.type())
+	    error_macro("x3d_element: unexpected type `" << int(g.variant())
 		 << "' and dimension " << dim);
 	     }
   }
