@@ -96,7 +96,7 @@ The folowing code prints triangle vertex numbers
     cout << endl;
   @}
 @end example
-@xref{geo_element internal}.
+@xref{geo_element iclass}.
 
 ACCESS TO VERTICE COORDINATES:
 The folowing code prints vertices coordinate
@@ -210,6 +210,8 @@ public:
   fem_helper::coordinate_type coordinate_system_type() const;
 
   size_type serial_number() const;
+  size_type zero_level_set_number() const;
+  //! generates a sequence of numbers for intersected meshes 
 
   const domain& boundary() const;
   void build_subregion(const domain& start_from, const domain& dont_cross, 
@@ -227,11 +229,11 @@ public:
   size_type n_triangle() const ;
   size_type n_quadrangle() const ;
   size_type n_volume() const ;
-  size_type n_tetraedra() const ;
+  size_type n_tetrahedra() const ;
   size_type n_prism() const ;
   size_type n_hexaedra() const ;
   size_type n_subgeo(size_type d) const ;
-  size_type n_element(reference_element::enum_type t) const;
+  size_type n_element(reference_element::variant_type t) const;
 
   Float hmin() const;
   Float hmax() const;
@@ -517,6 +519,12 @@ geo::serial_number() const
     return data().serial_number();  
 }
 inline
+geo::size_type
+geo::zero_level_set_number() const 
+{
+    return data().zero_level_set_number();  
+}
+inline
 const domain&
 geo::boundary() const
 {
@@ -592,9 +600,9 @@ geo::n_volume() const
 }
 inline
 geo::size_type
-geo::n_tetraedra() const
+geo::n_tetrahedra() const
 {
-  return data().n_tetraedra();
+  return data().n_tetrahedra();
 }
 inline
 geo::size_type
@@ -616,7 +624,7 @@ geo::n_subgeo(georep::size_type d) const
 }
 inline
 geo::size_type 
-geo::n_element(reference_element::enum_type t) const
+geo::n_element(reference_element::variant_type t) const
 {
   return data().n_element(t);
 }
