@@ -432,26 +432,40 @@ basis_Pk<T>::size (reference_element hat_K) const
 // get Lagrange nodes associated to dofs:
 template<class T>
 void
-basis_Pk<T>::hat_node (reference_element hat_K, std::vector<point_basic<T> >& hat_x) const
+basis_Pk<T>::hat_node (
+    reference_element                               hat_K, 
+    typename std::vector<point_basic<T> >::iterator hat_x) const
 {
   // TODO: return a const ref ? but hat_node is used at space::cstor and in loop, in gnuplot visu
   _initialize_hat_node (hat_K);
   size_type variant = hat_K.variant();
+  std::copy (_hat_xnod[variant].begin(), _hat_xnod[variant].end(), hat_x);
+}
+template<class T>
+void
+basis_Pk<T>::hat_node (
+    reference_element             hat_K, 
+    std::vector<point_basic<T> >& hat_x) const
+{
+  size_type variant = hat_K.variant();
+  _initialize_hat_node (hat_K);
   hat_x.resize (_hat_xnod[variant].size());
-  std::copy (_hat_xnod[variant].begin(), _hat_xnod[variant].end(), hat_x.begin());
+  hat_node (hat_K, hat_x.begin());
 }
 // evaluation of all basis functions at hat_x:
 template<class T>
 void
-basis_Pk<T>::eval (reference_element hat_K, const point_basic<T>& hat_x, std::vector<T>& values) const
+basis_Pk<T>::eval (
+    reference_element                 hat_K,
+    const point_basic<T>&             hat_x,
+    typename std::vector<T>::iterator values) const
 {
   _initialize_guard (hat_K);
   size_type variant = hat_K.variant();
-  size_type d = hat_K.dimension();
   size_type loc_ndof = _inv_vdm[variant].size1();
+  size_type d = hat_K.dimension();
   precompute_power (hat_x, _degree, d, _hat_xm);
-  values.resize (loc_ndof);
-  std::fill (values.begin(), values.end(), T(0));
+  std::fill (values, values+loc_ndof, T(0));
   // phi_i(x) = vdm^{-T}_ij*monom_j(x)
   for (size_t loc_jdof = 0; loc_jdof < loc_ndof; loc_jdof++) {
     T mx_loc_jdof;
@@ -463,15 +477,30 @@ basis_Pk<T>::eval (reference_element hat_K, const point_basic<T>& hat_x, std::ve
 }
 template<class T>
 void
-basis_Pk<T>::grad_eval (reference_element hat_K, const point_basic<T>& hat_x, std::vector<point_basic<T> >& values) const
+basis_Pk<T>::eval (
+    reference_element     hat_K,
+    const point_basic<T>& hat_x,
+    std::vector<T>&       values) const
 {
   _initialize_guard (hat_K);
   size_type variant = hat_K.variant();
-  size_type d = hat_K.dimension();
   size_type loc_ndof = _inv_vdm[variant].size1();
-  precompute_power (hat_x, _degree, d, _hat_xm);
   values.resize (loc_ndof);
-  std::fill (values.begin(), values.end(), point_basic<T>(0,0,0));
+  eval (hat_K, hat_x, values.begin());
+}
+template<class T>
+void
+basis_Pk<T>::grad_eval (
+    reference_element                               hat_K,
+    const point_basic<T>&                           hat_x,
+    typename std::vector<point_basic<T> >::iterator values) const
+{
+  _initialize_guard (hat_K);
+  size_type variant = hat_K.variant();
+  size_type loc_ndof = _inv_vdm[variant].size1();
+  size_type d = hat_K.dimension();
+  precompute_power (hat_x, _degree, d, _hat_xm);
+  std::fill (values, values+loc_ndof, point_basic<T>(0,0,0));
   // grad_phi_i(x) = vdm^{-T}_ij*grad_monom_j(x)
   for (size_t loc_jdof = 0; loc_jdof < loc_ndof; loc_jdof++) {
     point_basic<T> mx_loc_jdof;
@@ -483,6 +512,19 @@ basis_Pk<T>::grad_eval (reference_element hat_K, const point_basic<T>& hat_x, st
     }
   }
 }
+template<class T>
+void
+basis_Pk<T>::grad_eval (
+    reference_element             hat_K,
+    const point_basic<T>&         hat_x,
+    std::vector<point_basic<T> >& values) const
+{
+  _initialize_guard (hat_K);
+  size_type variant = hat_K.variant();
+  size_type loc_ndof = _inv_vdm[variant].size1();
+  values.resize (loc_ndof);
+  grad_eval (hat_K, hat_x, values.begin());
+}
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
