@@ -93,7 +93,7 @@ OUTPUT FILE FORMAT OPTIONS:
         The argument is any valid image format, such as
         bitmap @code{png}, @code{jpg}, @code{gif} or vectorial @code{ps} or @code{pdf}
         image file formats, and that could be handled by the corresponding render.
-        The output file is e.g. @file{@emph{basename}.png} when @emph{basename}
+        The output file is e.g. @emph{basename}.@code{png} when @emph{basename}
         is the name of the mesh, or can be set with the @code{-name} option.
 
   @end table
