@@ -53,74 +53,6 @@ bool
 band_is_zero (const T& x) {
   return fabs(x) <= band_epsilon;
 }
-
-template<class T, class M>
-static
-void
-add_ball_externals (
-  const geo_basic<T,M>&      band,
-  const array<index_set,M>&  ball)
-{
-}
-#ifdef _RHEOLEF_HAVE_MPI
-template<class T>
-static
-void
-add_ball_externals (
-  const geo_basic<T,distributed>&      band,
-  const array<index_set,distributed>&  ball)
-{
-  check_macro(band.order() == 1, "Only order=1 band supported");
-  index_set ext_iv_set;
-  const array<point_basic<T>,distributed>& node = band.get_nodes();
-  typedef typename array<point_basic<T>,distributed>::scatter_map_type map_t;
-  const map_t& map_node = node.get_dis_map_entries();
-  // TODO: could be done without copy ? by using bind1rst and iterators ?
-  for (typename map_t::const_iterator
-        iter = map_node.begin(),
-        last = map_node.end(); iter != last; ++iter) {
-    ext_iv_set += (*iter).first;
-  }
-  ball.set_dis_indexes (ext_iv_set);
-}
-#endif // _RHEOLEF_HAVE_MPI
-// get je = index of K' = neighbour of K accross side S = K.side(loc_nsid)
-// TODO: store neighbour in K: dis_je = band.neighbour (K,loc_isid);
-// slower: loop on vertices of S and compute ball intersection = {K,K'}
-template<class T, class M>
-geo_element::size_type
-neighbour (
-  const geo_basic<T,M>&      band,
-  const geo_element&         K,
-  geo_element::size_type     loc_isid,
-  const array<index_set,M>&  ball)
-{
-  typedef geo_element::size_type size_type;
-  size_type map_dim   = band.map_dimension();
-  size_type side_dim  = map_dim-1;
-  size_type S_size    = K.subgeo_size (side_dim, loc_isid);
-  size_type S_variant = reference_element::variant (S_size, side_dim);
-  size_type loc_iv0   = K.subgeo_local_vertex (side_dim, loc_isid, 0);
-  size_type dis_inod0 = K [loc_iv0];
-  size_type dis_iv0   = band.dis_inod2dis_iv (dis_inod0);
-  index_set ball_intersect = ball.dis_at (dis_iv0);
-  for (size_type sid_loc_iv = 1, sid_loc_nv = S_size; sid_loc_iv < sid_loc_nv; sid_loc_iv++) {
-    size_type loc_iv = K.subgeo_local_vertex (side_dim, loc_isid, sid_loc_iv);
-    size_type dis_inod = K [loc_iv];
-    size_type dis_iv   = band.dis_inod2dis_iv (dis_inod);
-    ball_intersect.inplace_intersection (ball.dis_at (dis_iv));
-  }
-  check_macro (ball_intersect.size() >  0, "connectivity problem(0)");
-  if (ball_intersect.size() == 1) return std::numeric_limits<size_type>::max(); // no neighbour
-  check_macro (ball_intersect.size() == 2, "connectivity problem(2)");
-  size_type dis_je = *(ball_intersect.begin());
-  if (dis_je == K.dis_ie()) {
-    index_set::const_iterator iter = ball_intersect.begin();
-    ++iter;
-    dis_je = *iter;
-  }
-  return dis_je;
-}
 // =========================================================================
 // part I: subroutine: build vertex cc
 // =========================================================================
@@ -130,9 +62,10 @@ geo_element::size_type
 build_vertex_connex_component (
   const geo_basic<T,M>&                        band,
   const std::vector<geo_element::size_type>&   zero_iv_list,
-  const std::vector<geo_element::size_type>&   isolated_ie_list,
-  const array<index_set,M>&                    ball)
+  const std::vector<geo_element::size_type>&   isolated_ie_list)
 {
+  band.neighbour_guard(); // will use neighbours
+
   typedef geo_element::size_type size_type;
   communicator comm = band.sizes().node_ownership.comm();
   size_type map_dim = band.map_dimension();
@@ -168,7 +101,7 @@ build_vertex_connex_component (
       front.pop_front();
       const geo_element& K = band [ie];
       for (size_type loc_isid = 0, loc_nsid = K.n_subgeo(side_dim); loc_isid < loc_nsid; loc_isid++) {
-        size_type dis_je = neighbour (band, K, loc_isid, ball);
+        size_type dis_je = band.neighbour (ie, loc_isid);
 	if (dis_je == std::numeric_limits<size_type>::max()) continue; // no neighbour
         if (! element_ownership.is_owned (dis_je)) {
           // K' belongs to another partition: cc is splitted on several parts
@@ -213,13 +146,13 @@ build_vertex_connex_component (
     const geo_element& K1 = band [ie];
     size_type K1_dis_icc = element_mark [ie] - 1;
     for (size_type loc_isid = 0, loc_nsid = K1.n_subgeo(side_dim); loc_isid < loc_nsid; loc_isid++) {
-      size_type dis_je = neighbour (band, K1, loc_isid, ball);
+      size_type dis_je = band.neighbour (ie, loc_isid);
       if (dis_je == std::numeric_limits<size_type>::max()) continue; // no neighbour
       size_type K2_mark = element_mark.dis_at (dis_je);
       if (K2_mark == 0) continue;
       size_type K2_dis_icc = K2_mark - 1;
-      a_asr.dis_entry (K1_dis_icc, K2_dis_icc) = 1;
-      a_asr.dis_entry (K2_dis_icc, K1_dis_icc) = 1;
+      a_asr.dis_entry (K1_dis_icc, K2_dis_icc) += 1;
+      a_asr.dis_entry (K2_dis_icc, K1_dis_icc) += 1;
     }
   }
   a_asr.dis_entry_assembly();
@@ -387,6 +320,7 @@ band_basic<T,M>::band_basic (
   // 
   // 2.1) build the band domain in lambda
   const geo_basic<T,M>& lambda = phi_h.get_geo();
+  check_macro(lambda.order() == 1, "Only order=1 band supported");
   size_type map_dim = lambda.map_dimension();
   communicator comm = lambda.geo_element_ownership(map_dim).comm();
   domain_indirect_basic<M> band_indirect (lambda, "band", map_dim, comm, bnd_dom_ie_list);
@@ -443,33 +377,12 @@ band_basic<T,M>::band_basic (
   domain_indirect_basic<M> isolated_dom (_band, "isolated", map_dim, comm, isolated_ie_list);
   _band.insert_domain_indirect (isolated_dom);
   //
-  // 5) subroutine: build connex components of non-isolated vertices in the band
+  // 5) build cc
   //
-  // 5.1) build ball(xi) := { K; xi is a vertex of K }
-  index_set emptyset;
-  distributor vertex_ownership  = _band.sizes().ownership_by_dimension[0];
-  array<index_set,M> ball (vertex_ownership, emptyset);
-  for (typename geo_basic<T,M>::const_iterator
-      iter = _band.begin(map_dim),
-      last = _band.end(map_dim); iter != last; ++iter) {
-    const geo_element& K = *iter;
-    index_set dis_ie_set;
-    dis_ie_set += K.dis_ie();
-    for (size_type loc_inod = 0, loc_nnod = K.size(); loc_inod < loc_nnod; loc_inod++) {
-      size_type dis_inod = K [loc_inod];
-      size_type dis_iv = _band.dis_inod2dis_iv (dis_inod);
-      ball.dis_entry (dis_iv) += dis_ie_set; // union with {dis_ie}
-    }
-  }
-  ball.dis_entry_assembly (index_set_add_op<index_set,index_set>());
-  // 5.3) set ball available at partition boundaries
-  add_ball_externals (_band, ball);
-  // 5.3) build cc
   _ncc = build_vertex_connex_component (
   	_band,
   	zero_iv_list,
-  	isolated_ie_list,
-        ball);
+  	isolated_ie_list);
 }
 // ----------------------------------------------------------------------------
 // instanciation in library
