@@ -51,10 +51,20 @@ public:
 // allocators:
 
     domain_indirect_base_rep();
+    void resize (size_type n) { base::resize (n); }
+
+    // build from a table of element indexes
     domain_indirect_base_rep (const std::string& name, size_type map_dim,
 	const communicator&           comm,
 	const std::vector<size_type>& ie_list);
-    void resize (size_type n) { base::resize (n); }
+    void build_from_list (const std::string& name, size_type map_dim,
+	const communicator&           comm,
+	const std::vector<size_type>& ie_list);
+
+    // c := a union b with c=*this
+    void build_union (
+        const domain_indirect_base_rep<M>& a,
+        const domain_indirect_base_rep<M>& b);
 
 // accessors & modifiers:
 
@@ -114,6 +124,11 @@ public:
 
     void resize (size_type n) { base::resize (n); }
 
+    // c := a union b with c=*this
+    void build_union (
+        const domain_indirect_rep<sequential>& a,
+        const domain_indirect_rep<sequential>& b);
+
 // accessors:
 
     size_type size()       const { return base::size(); }
@@ -149,6 +164,15 @@ public:
 
     odiststream& put (odiststream& ops) const;
 };
+// c := a union b with c=*this
+inline
+void
+domain_indirect_rep<sequential>::build_union (
+        const domain_indirect_rep<sequential>& a,
+        const domain_indirect_rep<sequential>& b)
+{
+  base::build_union (a,b);
+}
 // ---------------------------------------------------------------------
 #ifdef _RHEOLEF_HAVE_MPI
 template<>
@@ -166,6 +190,7 @@ public:
 // allocators:
 
     domain_indirect_rep();
+
     template<class T>
     domain_indirect_rep (
         const geo_basic<T,distributed>& omega,
@@ -174,6 +199,16 @@ public:
 	const communicator&           comm,
 	const std::vector<size_type>& ie_list);
 
+    template<class T>
+    void init_ios (const geo_basic<T,distributed>& omega);
+
+    // c := a union b with c=*this
+    template<class T>
+    void build_union (
+        const geo_basic<T,distributed>& omega,
+        const domain_indirect_rep<distributed>& a,
+        const domain_indirect_rep<distributed>& b);
+
 // accessors & modifiers:
 
     size_type size()       const { return base::size(); }
@@ -213,6 +248,32 @@ domain_indirect_rep<distributed>::domain_indirect_rep()
     _ini_ioige2dis_ioige()
 {
 }
+template<class T>
+inline
+domain_indirect_rep<distributed>::domain_indirect_rep (
+    const geo_basic<T,distributed>& omega,
+    const std::string&            name,
+    size_type                     map_dim,
+    const communicator&           comm,
+    const std::vector<size_type>& ie_list)
+ : domain_indirect_base_rep<distributed>(name, map_dim, comm, ie_list),
+   _ioige2ini_dis_ioige(),
+   _ini_ioige2dis_ioige()
+{
+  init_ios (omega);
+}
+// c := a union b with c=*this
+template<class T>
+inline
+void
+domain_indirect_rep<distributed>::build_union (
+        const geo_basic<T,distributed>& omega,
+        const domain_indirect_rep<distributed>& a,
+        const domain_indirect_rep<distributed>& b)
+{
+  base::build_union (a,b);
+  init_ios (omega);
+}
 #endif // _RHEOLEF_HAVE_MPI
 // ====================================================================
 // 2) wrapper: domain_indirect_basic<M>
@@ -422,6 +483,19 @@ domain_indirect_basic<sequential>::get (
 {
   return base::data().template get (ips, omega, ball);
 }
+// union:
+template<class T>
+inline
+domain_indirect_basic<sequential>
+build_union (
+  const geo_basic<T,sequential>&           omega,
+  const domain_indirect_basic<sequential>& a,
+  const domain_indirect_basic<sequential>& b)
+{
+  domain_indirect_basic<sequential> c;
+  c.data().build_union (a.data(), b.data());
+  return c;
+}
 // ---------------------------------------------------------------------
 #ifdef _RHEOLEF_HAVE_MPI
 //<verbatim:
@@ -574,6 +648,19 @@ domain_indirect_basic<distributed>::ini_ioige2dis_ioige (size_type ini_ioige) co
 {
     return base::data().ini_ioige2dis_ioige (ini_ioige);
 }
+// union:
+template<class T>
+inline
+domain_indirect_basic<distributed>
+build_union (
+  const geo_basic<T,distributed>& omega,
+  const domain_indirect_basic<distributed>& a,
+  const domain_indirect_basic<distributed>& b)
+{
+  domain_indirect_basic<distributed> c;
+  c.data().build_union (omega, a.data(), b.data());
+  return c;
+}
 
 #endif // _RHEOLEF_HAVE_MPI
 
