@@ -34,9 +34,21 @@ domain_indirect_base_rep<M>::domain_indirect_base_rep (
     const communicator&           comm,
     const std::vector<size_type>& ie_list)
  : array<geo_element_indirect,M>(),
-   _name(name),
-   _map_dim(map_dim)
+   _name(),
+   _map_dim()
 {
+  build_from_list (name, map_dim, comm, ie_list);
+}
+template<class M>
+void 
+domain_indirect_base_rep<M>::build_from_list (
+    const std::string&            name,
+    size_type                     map_dim,
+    const communicator&           comm,
+    const std::vector<size_type>& ie_list)
+{
+  _name    = name;
+  _map_dim = map_dim;
   distributor dom_ownership (distributor::decide, comm, ie_list.size());
   array<geo_element_indirect,M>::resize (dom_ownership);
   typename array<geo_element_indirect,M>::iterator oige_iter = array<geo_element_indirect,M>::begin();
@@ -47,6 +59,40 @@ domain_indirect_base_rep<M>::domain_indirect_base_rep (
   }
 }
 // ----------------------------------------------------------------------------
+// @brief build the union of two domains
+// ----------------------------------------------------------------------------
+// c := a union b with c=*this
+template<class M>
+void
+domain_indirect_base_rep<M>::build_union (
+  const domain_indirect_base_rep<M>& a,
+  const domain_indirect_base_rep<M>& b)
+{
+  check_macro (a._map_dim == b._map_dim,
+	"union: domains "<<a._name<<" and " << b._name << " have incompatible dimensions");
+  _name = a._name + "+" + b._name;
+  _map_dim = a._map_dim;
+  // use a map to perform the union efficiently
+  std::map<size_type,geo_element_indirect> c_map;
+  for (typename array<geo_element_indirect,M>::const_iterator
+	iter = a.begin(), last = a.end(); iter != last; ++iter) {
+    size_type ie = (*iter).index();
+    c_map [ie] = *iter;
+  }
+  for (typename array<geo_element_indirect,M>::const_iterator
+	iter = b.begin(), last = b.end(); iter != last; ++iter) {
+    size_type ie = (*iter).index();
+    c_map [ie] = *iter; // not inserted if already present
+  }
+  distributor c_ownership (distributor::decide, a.comm(), c_map.size());
+  array<geo_element_indirect,M>::resize (c_ownership);
+  typename array<geo_element_indirect,M>::iterator oige_iter = array<geo_element_indirect,M>::begin();
+  for (typename std::map<size_type,geo_element_indirect>::const_iterator
+	iter = c_map.begin(), last = c_map.end(); iter != last; ++iter, ++oige_iter) {
+    *oige_iter = (*iter).second;
+  }
+}
+// ----------------------------------------------------------------------------
 /// @brief generic (seq,mpi) i/o in format version 2
 // ----------------------------------------------------------------------------
 odiststream&
@@ -178,7 +224,7 @@ domain_indirect_basic<sequential>::domain_indirect_basic (
         std::vector<index_set>*         ball)
  : smart_pointer<domain_indirect_rep<sequential> > (new_macro(domain_indirect_rep<sequential>))
 {
-  check_macro (omega.data().variant() == geo_abstract_base_rep<U>::geo,
+  check_macro (omega.variant() == geo_abstract_base_rep<U>::geo,
         "build a domain for a geo_domain: not yet");
   const geo_rep<U,sequential>& omega_data = dynamic_cast<const geo_rep<U,sequential>&>(omega.data());
   data().build_from_data (omega_data, d_tmp, ball);
@@ -209,12 +255,7 @@ domain_indirect_basic<sequential>::domain_indirect_basic (
         std::vector<index_set>*         ball);
 
 #define _RHEOLEF_instanciation(M) 					\
-template								\
-domain_indirect_base_rep<M>::domain_indirect_base_rep (			\
-    const std::string&            name,					\
-    size_type                     map_dim,				\
-    const communicator&           comm,					\
-    const std::vector<size_type>& ie_list);
+template class domain_indirect_base_rep<M>;				\
 
 _RHEOLEF_instanciation(sequential)
 #ifdef _RHEOLEF_HAVE_MPI
