@@ -277,7 +277,7 @@ field_basic<T,M>::put_field (odiststream& ods) const
 // ----------------------------------------------------------------------------
 // graphic output switch
 // ----------------------------------------------------------------------------
-// class-member template partial specialization ‘field<T, M>::put(ods)’ is not allowed
+// class-member template partial specialization 'field<T, M>::put(ods)' is not allowed
 // here, we want to specialize for M=seq & M=dist since only seq graphic is vailable yet:
 template <class T> odiststream& visu_gnuplot      (odiststream&, const field_basic<T,sequential>&);
 template <class T> odiststream& visu_vtk_mayavi   (odiststream&, const field_basic<T,sequential>&);
@@ -400,99 +400,13 @@ field_basic<T,M>::dis_evaluate (const point_basic<T>& x, size_type i_comp) const
 #endif // _RHEOLEF_HAVE_MPI
   return value;
 }
-#ifdef TO_CLEAN
-// ----------------------------------------------------------------------------
-// algebra
-// ----------------------------------------------------------------------------
 template <class T, class M>
-field_basic<T,M>
-field_basic<T,M>::operator* (const field_basic<T,M>& vh) const
+point_basic<T>
+field_basic<T,M>::dis_vector_evaluate (const point_basic<T>& x) const
 {
-  if (   get_space().valued_tag() == space_constant::scalar  &&
-      vh.get_space().valued_tag() == space_constant::scalar) {
-    field_basic<T,M> wh (get_space());
-    std::transform(begin_dof(), end_dof(), vh.begin_dof(), wh.begin_dof(), std::multiplies<T>());
-    return wh;
-  } 
-  if (get_space().valued_tag() == space_constant::scalar) {
-    // scalar*vector or scalar*tensor
-    field_basic<T,M> wh (vh.get_space());
-    for (size_type i_comp = 0, n_comp = vh.size(); i_comp < n_comp; i_comp++) {
-      std::transform(begin_dof(), end_dof(), vh[i_comp].begin_dof(), wh[i_comp].begin_dof(), std::multiplies<T>());
-    }
-    return wh;
-  }
-  if (vh.get_space().valued_tag() == space_constant::scalar) {
-    // vector*scalar or tensor*scalar
-    field_basic<T,M> wh (get_space());
-    for (size_type i_comp = 0, n_comp = size(); i_comp < n_comp; i_comp++) {
-      std::transform(operator[](i_comp).begin_dof(), operator[](i_comp).end_dof(), vh.begin_dof(), wh.begin_dof(), std::multiplies<T>());
-    }
-    return wh;
-  }
-  fatal_macro ("field*field: unexpected "<<valued() << "*" << vh.valued());
-  return field_basic<T,M>();
+  fatal_macro ("dis_vector_evaluate: not yet");
+  return point_basic<T>();
 }
-template <class T, class M>
-field_basic<T,M>
-field_basic<T,M>::operator/ (const field_basic<T,M>& vh) const
-{
-  if (   get_space().valued_tag() == space_constant::scalar  &&
-      vh.get_space().valued_tag() == space_constant::scalar) {
-    field_basic<T,M> wh (get_space());
-    std::transform(begin_dof(), end_dof(), vh.begin_dof(), wh.begin_dof(), std::divides<T>());
-    return wh;
-  } 
-  if (vh.get_space().valued_tag() == space_constant::scalar) {
-    // vector/scalar or tensor/scalar
-    field_basic<T,M> wh (get_space());
-    for (size_type i_comp = 0, n_comp = size(); i_comp < n_comp; i_comp++) {
-      std::transform(operator[](i_comp).begin_dof(), operator[](i_comp).end_dof(), vh.begin_dof(), wh.begin_dof(), std::divides<T>());
-    }
-    return wh;
-  }
-  fatal_macro ("field/field: unexpected "<<valued() << "/" << vh.valued());
-  return field_basic<T,M>();
-}
-template <class T, class M>
-field_basic<T,M>
-norm2 (const field_basic<T,M>& uh)
-{
-  typedef typename field_basic<T,M>::size_type size_type;
-  switch (uh.get_space().valued_tag()) {
-    case space_constant::scalar: {
-      return sqr(uh);
-    }
-    case space_constant::vector: {
-      field_basic<T,M> res (uh[0].get_space(), 0);
-      for (size_type i_comp = 0, n_comp = uh.size(); i_comp < n_comp; i_comp++) {
-        res += sqr(uh[i_comp]);
-      }
-      return res;
-    }
-    case space_constant::tensor: {
-      space_constant::coordinate_type sys_coord = uh.get_geo().coordinate_system();
-      if (sys_coord == space_constant::axisymmetric_rz ||
-          sys_coord == space_constant::axisymmetric_rz) {
-        return sqr(uh(0,0)) + sqr(uh(1,1)) + sqr(uh(2,2)) +2*sqr(uh(0,1));
-      }
-      // cartesian tensor:
-      size_t d = uh.get_geo().dimension();
-      switch (d) {
-        case 1 :  return sqr(uh(0,0));
-        case 2 :  return sqr(uh(0,0)) + sqr(uh(1,1)) + 2*sqr(uh(0,1));
-        default : return sqr(uh(0,0)) + sqr(uh(1,1)) + 2*sqr(uh(0,1))
-                       + sqr(uh(2,2))                + 2*sqr(uh(0,2))
-                                                     + 2*sqr(uh(1,2));
-      }
-    }
-    default: {
-      error_macro ("norm: unsupported `"<<uh.get_space().valued()<<"' field");
-      return uh; // not reached
-    }
-  }
-}
-#endif // TO_CLEAN
 // ----------------------------------------------------------------------------
 // tensor component access: sigma_h(i,j)
 // ----------------------------------------------------------------------------
