@@ -335,7 +335,7 @@ public :
 
     T dis_evaluate (const point_basic<T>& x, size_type i_comp = 0) const;
     T operator()   (const point_basic<T>& x) const { return dis_evaluate (x,0); }
-    point vector_evaluate (const point_basic<T>& x) const;
+    point_basic<T> dis_vector_evaluate (const point_basic<T>& x) const;
 
 // internals:
 public:
