@@ -433,9 +433,15 @@ struct field_expr : proto::extends<Expr, field_expr<Expr>, field_domain> {
     typedef const_iterator_begin const_iterator;
     const_iterator begin_dof() const { return const_iterator(*this); }
 
-// random access:
+// typedefs:
+
     typedef typename proto::result_of::eval<const Expr, const field_subscript_context>::type value_type;
-    typedef value_type scalar_type;
+    typedef value_type result_type;
+    typedef typename scalar_traits<value_type>::type scalar_type;
+    typedef typename float_traits<value_type>::type  float_type;
+
+// random access:
+
     scalar_type dof (size_type i) const {
         const field_subscript_context get_subscript(i);
         return proto::eval(*this, get_subscript);
