@@ -348,7 +348,10 @@ public:
             case space_constant::vector:
 	      obj.template evaluate_call<Result, T1, point_basic<T2> >  (K, value); break;
             case space_constant::tensor:
+            case space_constant::unsymmetric_tensor:
 	      obj.template evaluate_call<Result, T1, tensor_basic<T2> > (K, value); break;
+            case space_constant::tensor3:
+	      obj.template evaluate_call<Result, T1, tensor3_basic<T2> > (K, value); break;
             default: error_macro ("unexpected second argument valued tag="<<arg2_valued_tag);
           }
           break;
@@ -360,19 +363,41 @@ public:
             case space_constant::vector:
 	      obj.template evaluate_call<Result, point_basic<T1>, point_basic<T2> >  (K, value); break;
             case space_constant::tensor:
+            case space_constant::unsymmetric_tensor:
 	      obj.template evaluate_call<Result, point_basic<T1>, tensor_basic<T2> > (K, value); break;
+            case space_constant::tensor3:
+	      obj.template evaluate_call<Result, point_basic<T1>, tensor3_basic<T2> > (K, value); break;
             default: error_macro ("unexpected second argument valued tag="<<arg2_valued_tag);
           }
           break;
         }
-        case space_constant::tensor: {
+        case space_constant::tensor:
+        case space_constant::unsymmetric_tensor: {
           switch (arg2_valued_tag) {
             case space_constant::scalar:
 	      obj.template evaluate_call<Result, tensor_basic<T1>, T2>                (K, value); break;
             case space_constant::vector:
 	      obj.template evaluate_call<Result, tensor_basic<T1>, point_basic<T2> >  (K, value); break;
             case space_constant::tensor:
+            case space_constant::unsymmetric_tensor:
 	      obj.template evaluate_call<Result, tensor_basic<T1>, tensor_basic<T2> > (K, value); break;
+            case space_constant::tensor3:
+	      obj.template evaluate_call<Result, tensor_basic<T1>, tensor3_basic<T2> > (K, value); break;
+            default: error_macro ("unexpected second argument valued tag="<<arg2_valued_tag);
+          }
+          break;
+        }
+        case space_constant::tensor3: {
+          switch (arg2_valued_tag) {
+            case space_constant::scalar:
+	      obj.template evaluate_call<Result, tensor3_basic<T1>, T2>                (K, value); break;
+            case space_constant::vector:
+	      obj.template evaluate_call<Result, tensor3_basic<T1>, point_basic<T2> >  (K, value); break;
+            case space_constant::tensor:
+            case space_constant::unsymmetric_tensor:
+	      obj.template evaluate_call<Result, tensor3_basic<T1>, tensor_basic<T2> > (K, value); break;
+            case space_constant::tensor3:
+	      obj.template evaluate_call<Result, tensor3_basic<T1>, tensor3_basic<T2> > (K, value); break;
             default: error_macro ("unexpected second argument valued tag="<<arg2_valued_tag);
           }
           break;
@@ -397,7 +422,10 @@ public:
         case space_constant::vector:
 	  obj.template evaluate_call<Result, Arg1, point_basic<T2> >  (K, value); break;
         case space_constant::tensor:
+        case space_constant::unsymmetric_tensor:
 	  obj.template evaluate_call<Result, Arg1, tensor_basic<T2> > (K, value); break;
+        case space_constant::tensor3:
+	  obj.template evaluate_call<Result, Arg1, tensor3_basic<T2> > (K, value); break;
         default: error_macro ("unexpected second argument valued tag="<<arg2_valued_tag);
       }
     }
@@ -418,7 +446,10 @@ public:
         case space_constant::vector:
 	  obj.template evaluate_call<Result, point_basic<T1>, Arg2>  (K, value); break;
         case space_constant::tensor:
+        case space_constant::unsymmetric_tensor:
 	  obj.template evaluate_call<Result, tensor_basic<T1>, Arg2> (K, value); break;
+        case space_constant::tensor3:
+	  obj.template evaluate_call<Result, tensor3_basic<T1>, Arg2> (K, value); break;
         default: error_macro ("unexpected first argument valued tag="<<arg1_valued_tag);
       }
     }
