@@ -103,7 +103,13 @@ global_get_side (
     case 2: dis_isid = L.face (sid.loc_isid); break;
     default: error_macro ("domain: unexpected side dimension " << sid.dim);
   }
-  return omega.dis_get_geo_element (sid.dim, dis_isid);
+  // TODO: pas tres clair quand on est sur un geo_domain_indirect ou un geo_domain
+  //       dans quel systeme de numerotation doit appartenir la face ?
+  if (omega.variant() != geo_abstract_base_rep<T>::geo_domain_indirect) {
+    return omega.dis_get_geo_element (sid.dim, dis_isid);
+  } else {
+    return omega.get_background_geo().dis_get_geo_element (sid.dim, dis_isid);
+  }
 }
 template<class T>
 const geo_element& 
@@ -364,10 +370,13 @@ field_expr_terminal_field_base_rep<T,M>::initialize (
     _omega = omega;
     _bops.set (quad, _uh.get_space().get_numbering().get_basis());
     _uh.dis_dof_update();
-    _use_bgd2dom = (_omega.variant()        == geo_abstract_base_rep<T>::geo_domain_indirect &&
-                    _uh.get_geo().variant() != geo_abstract_base_rep<T>::geo_domain_indirect);
-    _use_dom2bgd = (_omega.variant()        != geo_abstract_base_rep<T>::geo_domain_indirect &&
-                    _uh.get_geo().variant() == geo_abstract_base_rep<T>::geo_domain_indirect);
+    _use_dom2bgd = (_omega.variant()        == geo_abstract_base_rep<T>::geo_domain &&
+                    _uh.get_geo().variant() != geo_abstract_base_rep<T>::geo_domain);
+    _use_bgd2dom = (_omega.variant()        != geo_abstract_base_rep<T>::geo_domain &&
+                    _uh.get_geo().variant() == geo_abstract_base_rep<T>::geo_domain);
+    _have_dg_on_sides = _uh.get_space().get_numbering().is_discontinuous()
+                      && _omega.variant() == geo_abstract_base_rep<T>::geo_domain_indirect
+                      && 1 + omega.map_dimension() == omega.get_background_geo().map_dimension();
 }
 template<class T, class M>
 bool
@@ -380,10 +389,13 @@ field_expr_terminal_field_base_rep<T,M>::initialize (
     _omega = Xh.get_geo();
     _bops.set (Xh.get_numbering().get_basis(), _uh.get_space().get_numbering().get_basis());
     _uh.dis_dof_update();
-    _use_dom2bgd = (_omega.variant()        != geo_abstract_base_rep<T>::geo &&
-                    _uh.get_geo().variant() == geo_abstract_base_rep<T>::geo);
-    _use_bgd2dom = (_omega.variant()        == geo_abstract_base_rep<T>::geo &&
-                    _uh.get_geo().variant() != geo_abstract_base_rep<T>::geo);
+    _use_dom2bgd = (_omega.variant()        == geo_abstract_base_rep<T>::geo_domain &&
+                    _uh.get_geo().variant() != geo_abstract_base_rep<T>::geo_domain);
+    _use_bgd2dom = (_omega.variant()        != geo_abstract_base_rep<T>::geo_domain &&
+                    _uh.get_geo().variant() == geo_abstract_base_rep<T>::geo_domain);
+    _have_dg_on_sides = _uh.get_space().get_numbering().is_discontinuous()
+                      && _omega.variant() == geo_abstract_base_rep<T>::geo_domain_indirect
+                      && 1 + _omega.map_dimension() == _omega.get_background_geo().map_dimension();
     return true;
 }
 template<class T, class M>
@@ -397,8 +409,26 @@ field_expr_terminal_field_base_rep<T,M>::evaluate_initialize (
     } else if (_use_dom2bgd) { // get bgd_K on background mesh:
       const geo_element& bgd_K = _omega.dom2bgd_geo_element (K);
       _uh.get_space().dis_idof (bgd_K, _dis_idof);
-    } else {                   // use K directly
-      _uh.get_space().dis_idof (K, _dis_idof);
+    } else {
+      // use K directly
+      if (_have_dg_on_sides && K.dimension() == _omega.map_dimension()) {
+        // omits "inner(u)" on a sides-domain => assume a boundary side
+        size_type L_map_d = K.dimension() + 1;
+        check_macro (K.master(1) == std::numeric_limits<size_type>::max(),
+          "unexpected non-boundary side K="<<K);
+        size_type L_dis_ie = K.master(0);
+        check_macro (L_dis_ie != std::numeric_limits<size_type>::max(),
+          "unexpected isolated side K="<<K);
+        const geo_element& L = _omega.dis_get_geo_element (L_map_d, L_dis_ie);
+        _tilde_L = L.variant();
+        side_information_type sid;
+        L.get_side_informations (K, sid);
+        _bops.restrict_on_side (_tilde_L, sid);
+        _uh.get_space().dis_idof (L, _dis_idof);
+      } else {
+        // usual case:
+        _uh.get_space().dis_idof (K, _dis_idof);
+      }
     }
 }
 template<class T, class M>
@@ -446,6 +476,9 @@ field_expr_terminal_field_rep<T,M>::evaluate (
 {
     base::evaluate_initialize (K);
     reference_element hat_K = K.variant();
+    if (base::_have_dg_on_sides && K.dimension() == base::_omega.map_dimension()) {
+      hat_K = base::_tilde_L;
+    }
     value.resize (base::_bops.size(hat_K));
     size_type q = 0;
     for (typename std::vector<Result>::iterator
@@ -476,6 +509,9 @@ field_expr_terminal_field_grad_rep<T,M>::valued_tag() const
   switch (uh_valued_tag) {
     case space_constant::scalar: return space_constant::vector;
     case space_constant::vector: return space_constant::unsymmetric_tensor;
+    case space_constant::tensor: 
+    case space_constant::unsymmetric_tensor:
+                                 return space_constant::tensor3;
     default:
       error_macro ("unsupported "<<uh_valued_tag<< "-valued field for the grad() operator");
       return space_constant::last_valued;
@@ -937,7 +973,7 @@ set_value (
   }
   obj._start_q += nloc_comp_q;
 }
-// vector-valued case:
+// tensor-valued case:
 template<class T, class M>
 static
 void
@@ -948,6 +984,28 @@ set_value (
 {
     fatal_macro ("characteristic: not yet for tensor-valued fields");
 }
+// tensor3-valued case:
+template<class T, class M>
+static
+void
+set_value (
+  const field_expr_terminal_field_o_characteristic_rep<T,M>& obj,
+  const geo_element&                  K, 
+  std::vector<tensor3_basic<T> >&     value)
+{
+    fatal_macro ("characteristic: not yet for tensor3-valued fields");
+}
+// tensor4-valued case:
+template<class T, class M>
+static
+void
+set_value (
+  const field_expr_terminal_field_o_characteristic_rep<T,M>& obj,
+  const geo_element&                  K, 
+  std::vector<tensor4_basic<T> >&     value)
+{
+    fatal_macro ("characteristic: not yet for tensor4-valued fields");
+}
 template<class T, class M>
 template<class Result>
 void
@@ -968,22 +1026,26 @@ template class field_expr_terminal_function_rep< normal_pseudo_function<T> >; \
 template class field_expr_terminal_function_rep<h_local_pseudo_function<T> >; \
 template class field_expr_terminal_function_rep<penalty_pseudo_function<T> >; \
 
-#define _RHEOLEF_instanciation_base_both_members(T,M,Result) 		\
+// extra when Result=tensor3, tensor4
+#define _RHEOLEF_instanciation_base_both_members_full(T,M,Result) 	\
 template void field_expr_terminal_field_rep<T,M>::evaluate<Result > ( 	\
     		const geo_element&, std::vector<Result >&) const;	\
+template void field_expr_terminal_field_grad_rep<T,M>::evaluate<Result > ( \
+    		const geo_element&, std::vector<Result >&) const;	\
 template void field_expr_terminal_field_rep<T,M>::evaluate_on_side<Result > ( 	\
     		const geo_element& K, const side_information_type& sid, 	\
 		std::vector<Result>& value) const;			\
-template void field_expr_terminal_field_grad_rep<T,M>::evaluate<Result > ( \
+template void field_expr_terminal_field_o_characteristic_rep<T,M>::evaluate<Result > ( 	\
     		const geo_element&, std::vector<Result >&) const;	\
+
+#define _RHEOLEF_instanciation_base_both_members_mini(T,M,Result) 	\
+	_RHEOLEF_instanciation_base_both_members_full(T,M,Result) 	\
 template void field_expr_terminal_field_div_rep<T,M>::evaluate<Result > ( \
     		const geo_element&, std::vector<Result >&) const;	\
 template void field_expr_terminal_field_curl_rep<T,M>::evaluate<Result > ( \
     		const geo_element&, std::vector<Result >&) const;	\
 template void field_expr_terminal_field_dg_rep<T,M>::evaluate<Result > ( \
     		const geo_element&, std::vector<Result >&) const;	\
-template void field_expr_terminal_field_o_characteristic_rep<T,M>::evaluate<Result > ( 	\
-    		const geo_element&, std::vector<Result >&) const;	\
 
 #define _RHEOLEF_instanciation_base_both(T,M) 				\
 template class field_expr_terminal_field_rep<T,M>;			\
@@ -992,9 +1054,11 @@ template class field_expr_terminal_field_div_rep<T,M>;			\
 template class field_expr_terminal_field_curl_rep<T,M>;			\
 template class field_expr_terminal_field_dg_rep<T,M>;			\
 template class field_expr_terminal_field_o_characteristic_rep<T,M>;	\
-        _RHEOLEF_instanciation_base_both_members(T,M,T) 		\
-        _RHEOLEF_instanciation_base_both_members(T,M,point_basic<T>) 	\
-        _RHEOLEF_instanciation_base_both_members(T,M,tensor_basic<T>) 	\
+        _RHEOLEF_instanciation_base_both_members_mini(T,M,T) 		\
+        _RHEOLEF_instanciation_base_both_members_mini(T,M,point_basic<T>) 	\
+        _RHEOLEF_instanciation_base_both_members_mini(T,M,tensor_basic<T>) 	\
+        _RHEOLEF_instanciation_base_both_members_full(T,M,tensor3_basic<T>) 	\
+        _RHEOLEF_instanciation_base_both_members_full(T,M,tensor4_basic<T>) 	\
 
 #define _RHEOLEF_instanciation_seq(T)	 				\
         _RHEOLEF_instanciation_base_seq_only(T) 			\
