@@ -362,11 +362,13 @@ public:
 // alocators:
 
   field_expr_terminal_field_base_rep (const field_basic<T,M>& uh)
-    : _uh(uh),   _omega(), _bops(), _use_dom2bgd(false), _use_bgd2dom(false), _dis_idof() {}
+    : _uh(uh),   _omega(), _bops(), _use_dom2bgd(false), _use_bgd2dom(false), 
+      _have_dg_on_sides(false), _tilde_L(), _dis_idof() {}
 
   template <class Expr>
   explicit field_expr_terminal_field_base_rep (const field_expr<Expr>& expr) 
-    : _uh(expr), _omega(), _bops(), _use_dom2bgd(false), _use_bgd2dom(false), _dis_idof() {}
+    : _uh(expr), _omega(), _bops(), _use_dom2bgd(false), _use_bgd2dom(false), 
+      _have_dg_on_sides(false), _tilde_L(), _dis_idof() {}
 
 // accessors:
 
@@ -385,6 +387,8 @@ public:
   mutable basis_on_pointset<T>     _bops;
   mutable bool                     _use_dom2bgd;
   mutable bool                     _use_bgd2dom;
+  mutable bool                     _have_dg_on_sides;
+  mutable reference_element        _tilde_L;
 // working data:
   mutable std::vector<size_type>   _dis_idof;
 };
@@ -429,7 +433,10 @@ public:
   template<class ValueType>
   void valued_check() const {
     space_constant::valued_type valued_tag = space_constant::valued_tag_traits<ValueType>::value;
-    check_macro (base::_uh.valued_tag() == valued_tag, "unexpected "<<base::_uh.valued()
+    check_macro ((base::_uh.valued_tag() == valued_tag) ||
+                 (base::_uh.valued_tag() == space_constant::unsymmetric_tensor &&
+                  valued_tag             == space_constant::tensor),
+           "unexpected "<< base::_uh.valued()
         << "-valued field while a " << space_constant::valued_name(valued_tag)
         << "-valued one is expected in expression");
   }
