@@ -29,6 +29,8 @@
 # include "rheolef/field_indirect.h"
 # include "rheolef/field_expr.h"
 # include "rheolef/field_expr_ops.h"
+# include "rheolef/field_nonlinear_expr_ops.h"
+# include "rheolef/interpolate.h"
 # include "rheolef/field_evaluate.h"
 # include "rheolef/piola.h"
 # include "rheolef/rounder.h"
@@ -87,7 +89,7 @@ put_edge (std::ostream& gdat, const geo_element& E, const geo_basic<T,sequential
     xi.put (gdat, dim); gdat << " " << ui << endl;
     bbox.update (xi, ui);
   }
-  gdat << endl;
+  gdat << endl << endl;
 }
 template<class T>
 static
@@ -427,7 +429,8 @@ visu_gnuplot_vector (odiststream& ods, const field_basic<T,sequential>& uh)
   size_type d     = omega.dimension();
   Float diam_omega = norm (omega.xmax() - omega.xmin()); // characteristic length in omega
   Float h_moy = diam_omega/pow(n_elt,1./d);
-  field_basic<T,sequential> norm_uh = norm(uh);
+  space_basic<T,sequential> Xh (uh.get_geo(), uh.get_approx());
+  field_basic<T,sequential> norm_uh = interpolate(Xh, norm(uh));
   Float norm_max_uh = norm_uh.max_abs();      // get max vector length
   if (norm_max_uh + 1 == 1) norm_max_uh = 1;
   Float scale = h_moy/norm_max_uh;
