@@ -50,6 +50,8 @@ public:
                                                  dual_self_type;
   typedef typename RawExpr::maybe_symmetric 	 maybe_symmetric;
 
+  static const space_constant::valued_type valued_hint = space_constant::valued_tag_traits<value_type>::value;
+
 // alocators:
 
   form_vf_expr (const RawExpr& raw_expr) 
@@ -121,6 +123,8 @@ public:
 				typename Expr2::dual_self_type>::type>::type 
 	                                                maybe_symmetric;
 
+  static const space_constant::valued_type valued_hint = space_constant::valued_tag_traits<value_type>::value;
+
 // alocators:
 
   form_vf_expr_bf_field (const BinaryFunction& f, 
@@ -247,6 +251,8 @@ public:
                                                         dual_self_type;
   typedef typename Expr::maybe_symmetric::type          maybe_symmetric;
 
+  static const space_constant::valued_type valued_hint = space_constant::valued_tag_traits<value_type>::value;
+
 // alocators:
 
   form_vf_expr_uf (const UnaryFunction& f, const Expr& expr)
@@ -326,6 +332,8 @@ public:
 		             typename Expr2::maybe_symmetric::type>::type
 	                                                maybe_symmetric;
 
+  static const space_constant::valued_type valued_hint = space_constant::valued_tag_traits<value_type>::value;
+
 // alocators:
 
   form_vf_expr_bf (const BinaryFunction& f, 
@@ -418,6 +426,8 @@ public:
   // TODO: problem when ddot(eta_h,otimes(u,v)) when eta_h is unsymmetric tensor 
   // and "unsymmetric tensor" is not known at compile time
 
+  static const space_constant::valued_type valued_hint = space_constant::valued_tag_traits<value_type>::value;
+
 // alocators:
 
   form_vf_expr_binded_bf (const BinaryFunction& f, 
@@ -428,7 +438,9 @@ public:
       _vf_expr(vf_expr),
       _scalar_nl_value_quad(),
       _vector_nl_value_quad(),
-      _tensor_nl_value_quad()
+      _tensor_nl_value_quad(),
+      _tensor3_nl_value_quad(),
+      _tensor4_nl_value_quad()
     {}
 
 // accessors:
@@ -487,6 +499,8 @@ public:
   mutable std::vector<scalar_type>                 _scalar_nl_value_quad;
   mutable std::vector<point_basic<scalar_type> >   _vector_nl_value_quad;
   mutable std::vector<tensor_basic<scalar_type> >  _tensor_nl_value_quad;
+  mutable std::vector<tensor3_basic<scalar_type> > _tensor3_nl_value_quad;
+  mutable std::vector<tensor4_basic<scalar_type> > _tensor4_nl_value_quad;
 };
 #ifndef TODO
 #endif // TODO
