@@ -20,7 +20,40 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ///
 /// =========================================================================
+/*
+  geo: mesh data structure
+  author: Pierre.Saramito@imag.fr
+  date: 20 april 2013
 
+  geo is an alias to geo_basic<T,M>
+ 	T: the current Float represetation (e.g. double)
+	M: the memory model (sequential or distributed)
+           the default memory model has been choosen by the configure script
+
+  geo_basic<T,M> is a smart_pointer_clone<geo_abstract_rep<T,M> >
+	i.e. a pointer with shalow copy semantic on a pure virtual base class geo_abstract_rep<T,M>
+        used by polymorphic hierarchy of classes.
+
+  there are three concrete variants for this base class:
+    geo_rep<T,M> 		 : for usual meshes, as omega
+    geo_domain_indirect_rep<T,M> : for usual boundary domains, as gamma=omega["boundary"]
+    geo_domain_rep<T,M> 	 : for compacted boundary domains, as gamma=omega["boundary"]
+				   used when defining a space on a boundary domain, as
+					space W (omega["boundary"], "P1");
+				   => elments and vertex are renumbered in a compact form
+				      for easy P1 dofs numbering.
+
+   Most code is shared by these three classes and by the sequential/distributed variants.
+   This leads to the following hierarchy of classes:
+
+        geo_abstract_base_rep<T>             : virtual methods for M=seq
+          geo_abstract_rep<T,M>              : M=seq,dis have separated impl; add methods for M=dis
+            geo_domain_indirect_base_rep<T,M>: data + methods for domains
+              geo_domain_indirect_rep<T,M>   : M=seq,dis have separated impl; add methods for M=dis
+            geo_base_rep<T,M>                : data + methods for geometry
+              geo_rep<T,M>                   : M=seq,dis have separated impl: add methods for M=dis
+                geo_domain_rep<T,M>          : data + methods for compacted geometry on domain
+*/
 #include "rheolef/geo_element.h"
 #include "rheolef/array.h"
 #include "rheolef/hack_array.h"
@@ -169,6 +202,10 @@ public:
 
     virtual const distributor&  geo_element_ownership (size_type dim) const = 0;
     virtual const_reference get_geo_element           (size_type dim, size_type ige) const = 0;
+    virtual const geo_element& bgd2dom_geo_element (const geo_element& bgd_K) const { return bgd_K; }
+    virtual const geo_element& dom2bgd_geo_element (const geo_element& dom_K) const { return dom_K; }
+    virtual size_type neighbour (size_type ie, size_type loc_isid) const = 0;
+    virtual void neighbour_guard() const = 0;
 
     virtual const_iterator_by_variant begin_by_variant (variant_type variant) const = 0;
     virtual const_iterator_by_variant   end_by_variant (variant_type variant) const = 0;
@@ -413,7 +450,8 @@ public:
     const geo_size&  ios_sizes() const { return _gs; }
 
     const distributor& geo_element_ownership (size_type dim) const { return _gs.ownership_by_dimension[dim]; }
-    const_reference    get_geo_element       (size_type dim, size_type ige) const;
+    const_reference     get_geo_element (size_type dim, size_type ige) const;
+    const_reference dis_get_geo_element (size_type dim, size_type dis_ige) const;
 
     const_iterator_by_variant begin_by_variant (variant_type variant) const;
           iterator_by_variant begin_by_variant (variant_type variant);
@@ -450,6 +488,9 @@ public:
                 const point_basic<T>&     v,
                       point_basic<T>&     y) const;
 
+    size_type neighbour (size_type ie, size_type loc_isid) const;
+    void neighbour_guard() const;
+
 // additional accessors & modifier:
 
     reference get_geo_element (size_type dim, size_type ige);
@@ -473,6 +514,8 @@ public:
     size_type      dis_size() const { return dis_size (map_dimension()); }
     size_type    dis_n_edge() const { return dis_size (1); }
     size_type    dis_n_face() const { return dis_size (2); }
+    size_type dis_inod2dis_iv (size_type dis_inod) const;
+    size_type dis_iv2dis_inod (size_type dis_iv)   const;
 
     const_reference operator[] (size_type ie) const { return get_geo_element (map_dimension(), ie); }
     reference  	    operator[] (size_type ie)	    { return get_geo_element (map_dimension(), ie); }
@@ -489,8 +532,9 @@ public:
     const_iterator end_face()            const { return base::end   (2); }
 
 protected:
-// internal:
     void compute_bbox();
+    void init_neighbour() const;
+    template<class U> friend void add_ball_externals (const geo_base_rep<U,M>&, const array<index_set,M>&);
 
 // data:
 // 0) header:
@@ -503,6 +547,7 @@ protected:
     geo_size                                 _gs; // counters by geo_element dimension: 0,1,2,3
     mutable std::vector<domain_indirect_basic<M> > _domains;
     bool				     _have_connectivity; // e.g.list of  edges in a 2d triangular mesh
+    mutable bool			     _have_neighbour; // inter-element connectivity
 // 2) coordinates:
     array<node_type, M>                      _node;
     size_type                                _dimension;
@@ -515,51 +560,13 @@ protected:
 };
 template <class T, class M>
 inline
-geo_base_rep<T,M>::geo_base_rep ()
- : geo_abstract_rep<T,M>(),
-   _name("*nogeo*"),
-   _version(0),
-   _serial_number(0),
-   _geo_element(),
-   _map_dimension(0),
-   _gs(),
-   _domains(),
-   _have_connectivity(false),
-   _node(),
-   _dimension(0),
-   _sys_coord(space_constant::cartesian),
-   _xmin(),
-   _xmax(),
-   _numbering("P1"),
-   _locator(),
-   _tracer_ray_boundary()
+void
+geo_base_rep<T,M>::neighbour_guard() const
 {
+  if (_have_neighbour) return;
+  _have_neighbour = true;
+  init_neighbour();
 }
-template <class T, class M>
-inline
-geo_base_rep<T,M>::geo_base_rep (const geo_base_rep<T,M>& o)
- : geo_abstract_rep<T,M>(o),
-   _name                (o._name),
-   _version             (o._version),
-   _serial_number       (o._serial_number),
-   _geo_element         (o._geo_element),
-   _map_dimension       (o._map_dimension),
-   _gs                  (o._gs),
-   _domains             (o._domains),
-   _have_connectivity   (o._have_connectivity),
-   _node                (o._node),
-   _dimension           (o._dimension),
-   _sys_coord           (o._sys_coord),
-   _xmin                (o._xmin),
-   _xmax                (o._xmax),
-   _numbering           (o._numbering),
-   _locator             (o._locator),
-   _tracer_ray_boundary(o._tracer_ray_boundary)
-{
-  trace_macro ("physical copy of geo_base_rep: dim="<<o.dimension()<<", dis_size="<<o.dis_size());
-}
-#define _RHEOLEF_geo_element_case(VARIANT,MEMBER) 	\
-
 template <class T, class M>
 typename geo_base_rep<T,M>::iterator_by_variant
 geo_base_rep<T,M>::begin_by_variant (variant_type variant)
@@ -658,7 +665,10 @@ public:
       const boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential>,
                          reference_element::max_variant>& elt_list);
 
-    void build_from_domain (const domain_indirect_rep<sequential>& indirect, const geo_abstract_rep<T,sequential>& omega);
+    void build_from_domain (
+	const domain_indirect_rep<sequential>&              indirect,
+	const geo_abstract_rep<T,sequential>&               omega,
+              std::map<size_type,size_type>&                bgd_ie2dom_ie);
 
 // abstract accessors redefined:
 
@@ -697,8 +707,10 @@ public:
     const distributor& vertex_ownership()        const { return geo_element_ownership(0); }
     const_reference operator[] (size_type ie) const { return get_geo_element (map_dimension(), ie); }
     reference       operator[] (size_type ie)       { return get_geo_element (map_dimension(), ie); }
+#ifdef TO_CLEAN
     size_type             dis_inod2dis_iv (size_type dis_inod) const { return dis_inod; }
     size_type             dis_iv2dis_inod (size_type dis_iv)   const { return dis_iv; }
+#endif // TO_CLEAN
 
 // i/o:
 
@@ -707,7 +719,7 @@ public:
     odiststream& put         (odiststream& ops) const { return put_geo(ops); }
 
     void dump (std::string name) const;
-    void load (std::string name);
+    void load (std::string name, const communicator& = communicator());
     bool check(bool verbose) const;
 
 // modifier:
@@ -734,7 +746,6 @@ protected:
     void domain_set_side_part1 (
                 const domain_indirect_rep<sequential>&    indirect,
                 const geo_abstract_rep<T,sequential>&     bgd_omega,
-                array<size_type,sequential>&              bgd_iv2dom_dis_iv,
                 size_type                                 sid_dim,
                 array<size_type,sequential>&              bgd_isid2dom_dis_isid,
                 array<size_type,sequential>&              dom_isid2bgd_isid,
@@ -751,27 +762,6 @@ protected:
     		size_type                                 size_by_variant [reference_element::max_variant]);
     void build_external_entities () {} // for distributed compat
 };
-template <class T>
-inline
-geo_rep<T,sequential>::geo_rep ()
- : geo_base_rep<T,sequential>()
-{
-}
-template <class T>
-inline
-geo_rep<T,sequential>::geo_rep (const geo_rep<T,sequential>& omega)
- : geo_base_rep<T,sequential>(omega)
-{
-}
-template <class T>
-inline
-geo_abstract_rep<T,sequential>*
-geo_rep<T,sequential>::clone() const 
-{
-  typedef geo_rep<T,sequential> rep;
-  return new_macro (rep(*this));
-}
-
 #ifdef _RHEOLEF_HAVE_MPI
 // =========================================================================
 /// @brief distributed mesh representation
@@ -800,7 +790,10 @@ public:
     geo_rep (const geo_rep<T,distributed>&);
     geo_abstract_rep<T,distributed>* clone() const;
 
-    void build_from_domain (const domain_indirect_rep<distributed>& indirect, const geo_abstract_rep<T,distributed>& omega);
+    void build_from_domain (
+        const domain_indirect_rep<distributed>&              indirect,
+        const geo_abstract_rep<T,distributed>&               omega,
+              std::map<size_type,size_type>&                 bgd_ie2dom_ie);
 
     // build from_list (for level set)
     geo_rep (
@@ -812,12 +805,10 @@ public:
 // abstract accessors defined:
 
     distributor geo_element_ios_ownership (size_type dim) const;
-    const_reference   dis_get_geo_element (size_type dim, size_type dis_ige) const;
+
     size_type             ige2ios_dis_ige (size_type dim, size_type ige) const;
     size_type         dis_ige2ios_dis_ige (size_type dim, size_type dis_ige) const;
     size_type             ios_ige2dis_ige (size_type dim, size_type ios_ige) const;
-    size_type             dis_inod2dis_iv (size_type dis_inod) const;
-    size_type             dis_iv2dis_inod (size_type dis_iv) const;
     const geo_size&  ios_sizes() const { return _ios_gs; }
     void locate (
                 const array<point_basic<T>,distributed>&     x,
@@ -885,7 +876,6 @@ protected:
     void domain_set_side_part1 (
                 const domain_indirect_rep<distributed>&    indirect,
                 const geo_abstract_rep<T,distributed>&     bgd_omega,
-                array<size_type>&                          bgd_iv2dom_dis_iv,
                 size_type                                  sid_dim,
                 array<size_type>&                          bgd_isid2dom_dis_isid,
                 array<size_type>&                          dom_isid2bgd_isid,
@@ -911,38 +901,6 @@ protected:
     array<size_type>             _igev2ios_dis_igev [reference_element::max_variant];
     array<size_type>             _ios_igev2dis_igev [reference_element::max_variant];
 };
-template <class T>
-inline
-geo_rep<T,distributed>::geo_rep ()
- : geo_base_rep<T,distributed>(),
-   _inod2ios_dis_inod(),
-   _ios_inod2dis_inod(),
-   _ios_ige2dis_ige(),
-   _ios_gs(),
-   _igev2ios_dis_igev(),
-   _ios_igev2dis_igev()
-{
-}
-template <class T>
-inline
-geo_rep<T,distributed>::geo_rep (const geo_rep<T,distributed>& o)
- : geo_base_rep<T,distributed>(o),
-   _inod2ios_dis_inod(o._inod2ios_dis_inod),
-   _ios_inod2dis_inod(o._ios_inod2dis_inod),
-   _ios_ige2dis_ige  (o._ios_ige2dis_ige),
-   _ios_gs           (o._ios_gs),
-   _igev2ios_dis_igev(o._igev2ios_dis_igev),
-   _ios_igev2dis_igev(o._ios_igev2dis_igev)
-{
-}
-template <class T>
-inline
-geo_abstract_rep<T,distributed>*
-geo_rep<T,distributed>::clone() const 
-{
-  typedef geo_rep<T,distributed> rep;
-  return new_macro (rep(*this));
-}
 #endif // _RHEOLEF_HAVE_MPI
 
 // =========================================================================
@@ -965,6 +923,14 @@ End:
 // =========================================================================
 /// @brief sequential mesh with reference counting
 // =========================================================================
+// handler for complex geo names as "square[boundary]"
+template<class T, class M> geo_basic<T,M> geo_load (const std::string& name);
+
+// guards for omega.boundary(), omega.internal_sides() and omega.sides()
+template<class T, class M> void boundary_guard       (const geo_basic<T,M>&);
+template<class T, class M> void internal_sides_guard (const geo_basic<T,M>&);
+template<class T, class M> void sides_guard          (const geo_basic<T,M>&);
+
 //<verbatim:
 template <class T>
 class geo_basic<T,sequential> : public smart_pointer_clone<geo_abstract_rep<T,sequential> > {
@@ -1009,6 +975,7 @@ public:
     size_type                 dimension() const { return base::data().dimension(); }
     size_type             map_dimension() const { return base::data().map_dimension(); }
     size_type             serial_number() const { return base::data().serial_number(); }
+    size_type                   variant() const { return base::data().variant(); }
     coordinate_type   coordinate_system() const { return base::data().coordinate_system(); }
     std::string  coordinate_system_name() const { return space_constant::coordinate_system_name(coordinate_system()); }
     const basis_basic<T>& get_piola_basis() const { return base::data().get_piola_basis(); }
@@ -1020,6 +987,13 @@ public:
     const geo_size&  ios_sizes()             const { return base::data().ios_sizes(); }
     const_reference get_geo_element (size_type dim, size_type ige) const { return base::data().get_geo_element (dim, ige); }
           reference get_geo_element (size_type dim, size_type ige)       { return base::data().get_geo_element (dim, ige); }
+    const_reference dis_get_geo_element (size_type dim, size_type dis_ige) const
+		{ return get_geo_element (dim, dis_ige); }
+    const geo_element& bgd2dom_geo_element (const geo_element& bgd_K) const { return base::data().bgd2dom_geo_element (bgd_K); }
+    const geo_element& dom2bgd_geo_element (const geo_element& dom_K) const { return base::data().dom2bgd_geo_element (dom_K); }
+    size_type neighbour (size_type ie, size_type loc_isid) const {
+			  return base::data().neighbour (ie, loc_isid); }
+    void neighbour_guard() const { base::data().neighbour_guard(); }
     size_type        n_node()   const { return base::data().n_node(); }
     const node_type&     node(size_type     inod) const { return base::data().node(inod); }
     const node_type& dis_node(size_type dis_inod) const { return base::data().dis_node(dis_inod); }
@@ -1041,6 +1015,9 @@ public:
     size_type n_domain () const { return base::data().n_domain_indirect (); }
     geo_basic<T,sequential> get_domain (size_type i) const;
     geo_basic<T,sequential> operator[] (const std::string& name) const;
+    geo_basic<T,sequential> boundary() const;
+    geo_basic<T,sequential> internal_sides() const;
+    geo_basic<T,sequential> sides() const;
 
     size_type seq_locate (
 		const point_basic<T>& x,
@@ -1147,34 +1124,39 @@ inline
 geo_basic<T,sequential>::geo_basic (std::string name, const communicator& comm)
   : base (0)
 {
-    // allocate a new geo_rep<mpi> object ; TODO geo_rep(name,comm)
-    geo_rep<T,sequential>* ptr = new_macro((geo_rep<T,sequential>));
-    ptr->load (name);
-    base::operator= (ptr);
+    base::operator= (geo_load<T,sequential>(name));
 }
 template <class T>
 inline
 void
 geo_basic<T,sequential>::load (std::string name, const communicator& comm)
 {
-    // allocate a new geo_rep<mpi> object ; TODO geo_rep(name,comm)
-    geo_rep<T,sequential>* ptr = new_macro((geo_rep<T,sequential>));
-    ptr->load (name);
-    base::operator= (ptr);
+    base::operator= (geo_load<T,sequential>(name));
 }
-#ifdef TO_CLEAN
 template <class T>
 inline
-idiststream&
-geo_basic<T,sequential>::get (idiststream& ips)
+geo_basic<T,sequential>
+geo_basic<T,sequential>::boundary() const
 {
-    // allocate a new geo_rep object (TODO: do a dynamic_cast ?)
-    geo_rep<T,sequential>* ptr = new_macro((geo_rep<T,sequential>));
-    ptr->get (ips);
-    base::operator= (ptr);
-    return ips;
+   boundary_guard (*this);
+   return operator[] ("boundary");
+}
+template <class T>
+inline
+geo_basic<T,sequential>
+geo_basic<T,sequential>::internal_sides() const
+{
+   internal_sides_guard (*this);
+   return operator[] ("internal_sides");
+}
+template <class T>
+inline
+geo_basic<T,sequential>
+geo_basic<T,sequential>::sides() const
+{
+   sides_guard (*this);
+   return operator[] ("sides");
 }
-#endif // TO_CLEAN
 #ifdef _RHEOLEF_HAVE_MPI
 // =========================================================================
 /// @brief distributed mesh with rerefence counting
@@ -1224,6 +1206,7 @@ public:
     size_type                 dimension() const { return base::data().dimension(); }
     size_type             map_dimension() const { return base::data().map_dimension(); }
     size_type             serial_number() const { return base::data().serial_number(); }
+    size_type                   variant() const { return base::data().variant(); }
     coordinate_type   coordinate_system() const { return base::data().coordinate_system(); }
     std::string  coordinate_system_name() const { return space_constant::coordinate_system_name(coordinate_system()); }
     const basis_basic<T>& get_piola_basis() const { return base::data().get_piola_basis(); }
@@ -1238,6 +1221,13 @@ public:
 		{ return base::data().get_geo_element (dim, ige); }
     const_reference dis_get_geo_element (size_type dim, size_type dis_ige) const
 		{ return base::data().dis_get_geo_element (dim, dis_ige); }
+    const geo_element& bgd2dom_geo_element (const geo_element& bgd_K) const
+		{ return base::data().bgd2dom_geo_element (bgd_K); }
+    const geo_element& dom2bgd_geo_element (const geo_element& dom_K) const
+		{ return base::data().dom2bgd_geo_element (dom_K); }
+    size_type neighbour (size_type ie, size_type loc_isid) const {
+			  return base::data().neighbour (ie, loc_isid); }
+    void neighbour_guard() const { base::data().neighbour_guard(); }
     distributor geo_element_ios_ownership (size_type dim) const {
 	return base::data().geo_element_ios_ownership (dim); }
     size_type ige2ios_dis_ige (size_type dim, size_type ige) const {
@@ -1274,6 +1264,9 @@ public:
     size_type n_domain () const { return base::data().n_domain_indirect (); }
     geo_basic<T,distributed> get_domain (size_type i) const;
     geo_basic<T,distributed> operator[] (const std::string& name) const;
+    geo_basic<T,distributed> boundary() const;
+    geo_basic<T,distributed> internal_sides() const;
+    geo_basic<T,distributed> sides() const;
 
     size_type seq_locate (
 		const point_basic<T>& x,
@@ -1371,20 +1364,14 @@ inline
 geo_basic<T,distributed>::geo_basic (std::string name, const communicator& comm)
   : base (0)
 {
-    // allocate a new geo_rep<mpi> object ; TODO geo_rep(name,comm)
-    geo_rep<T,distributed>* ptr = new_macro((geo_rep<T,distributed>));
-    ptr->load (name, comm);
-    base::operator= (ptr);
+    base::operator= (geo_load<T,distributed>(name));
 }
 template <class T>
 inline
 void
 geo_basic<T,distributed>::load (std::string name, const communicator& comm)
 {
-    // allocate a new geo_rep<mpi> object ; TODO geo_rep(name,comm)
-    geo_rep<T,distributed>* ptr = new_macro((geo_rep<T,distributed>));
-    ptr->load (name, comm);
-    base::operator= (ptr);
+    base::operator= (geo_load<T,distributed>(name));
 }
 template <class T>
 inline
@@ -1397,12 +1384,37 @@ geo_basic<T,distributed>::get (idiststream& ips)
     base::operator= (ptr);
     return ips;
 }
+template <class T>
+inline
+geo_basic<T,distributed>
+geo_basic<T,distributed>::boundary() const
+{
+   boundary_guard (*this);
+   return operator[] ("boundary");
+}
+template <class T>
+inline
+geo_basic<T,distributed>
+geo_basic<T,distributed>::internal_sides() const
+{
+   internal_sides_guard (*this);
+   return operator[] ("internal_sides");
+}
+template <class T>
+inline
+geo_basic<T,distributed>
+geo_basic<T,distributed>::sides() const
+{
+   sides_guard (*this);
+   return operator[] ("sides");
+}
 #endif // _RHEOLEF_HAVE_MPI
 
 // ==============================================================================
 // geo fat interface: members are specific to geo_rep
 // => check that pointer to geo_abstract_rep points to a geo_rep
 // ==============================================================================
+
 #define _RHEOLEF_save(M)	                                              	\
 template <class T>								\
 void										\
