@@ -105,6 +105,8 @@ public:
 
     const distributor& geo_element_ownership (size_type dim) const;
     const_reference get_geo_element (size_type dim, size_type ige) const;
+    size_type neighbour (size_type ie, size_type loc_iside) const;
+    void neighbour_guard() const;
 
 // unimplemented geo_abstract interface:
 
@@ -198,20 +200,11 @@ public:
     typedef typename base::size_type                    size_type;
     typedef typename base::node_type                    node_type;
 
-    geo_domain_indirect_rep () : base() {}
-    geo_domain_indirect_rep (const geo_domain_indirect_rep<T,sequential>& x) : base(x) {}
-    geo_domain_indirect_rep (const domain_indirect_basic<sequential>& indirect, const geo_basic<T,sequential>& omega)
-	: base(indirect,omega) {}
+    geo_domain_indirect_rep ();
+    geo_domain_indirect_rep (const geo_domain_indirect_rep<T,sequential>& x);
+    geo_domain_indirect_rep (const domain_indirect_basic<sequential>& indirect, const geo_basic<T,sequential>& omega);
     geo_abstract_rep<T,sequential>* clone() const;
 };
-template <class T>
-inline
-geo_abstract_rep<T,sequential>*
-geo_domain_indirect_rep<T,sequential>::clone() const
-{
-  typedef geo_domain_indirect_rep<T,sequential> rep;
-  return new_macro(rep(*this));
-}
 // ========================================================================
 // distributed rep
 // ========================================================================
@@ -224,10 +217,9 @@ public:
     typedef typename base::node_type                    node_type;
     typedef typename base::const_reference              const_reference;
 
-    geo_domain_indirect_rep() : base() {}
-    geo_domain_indirect_rep (const geo_domain_indirect_rep<T,distributed>& x) : base(x) {}
-    geo_domain_indirect_rep (const domain_indirect_basic<distributed>& indirect, const geo_basic<T,distributed>& omega)
-	: base(indirect,omega) {}
+    geo_domain_indirect_rep();
+    geo_domain_indirect_rep (const geo_domain_indirect_rep<T,distributed>& x);
+    geo_domain_indirect_rep (const domain_indirect_basic<distributed>& indirect, const geo_basic<T,distributed>& omega);
     geo_abstract_rep<T,distributed>* clone() const;
 
 // accessors: the geo_abstract mpi interface is defined here
@@ -241,28 +233,19 @@ public:
         boost::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
         array<size_type,distributed>&                           idof2ios_dis_idof) const;
 };
-template <class T>
-inline
-geo_abstract_rep<T,distributed>*
-geo_domain_indirect_rep<T,distributed>::clone() const
-{
-  typedef geo_domain_indirect_rep<T,distributed> rep;
-  return new_macro(rep(*this));
-}
 #endif // _RHEOLEF_HAVE_MPI
 // ========================================================================
 // geo_basic allocator and accessor related to domains
 // ========================================================================
-#define _RHEOLEF_geo_cstor(M)					\
+#define _RHEOLEF_geo_domain(M)					\
 template<class T>						\
 inline								\
 geo_basic<T,M>::geo_basic (					\
-    const domain_indirect_basic<M>& dom, 				\
+    const domain_indirect_basic<M>& dom, 			\
     const geo_basic<T,M>& omega)				\
  : base (new_macro((geo_domain_indirect_rep<T,M>)(dom,omega)))	\
 {								\
-}
-#define _RHEOLEF_geo_dmn_by_idx(M)				\
+}								\
 template<class T>						\
 inline								\
 geo_basic<T,M>							\
@@ -270,29 +253,45 @@ geo_basic<T,M>::get_domain (size_type i) const			\
 {								\
     const domain_indirect_basic<M>& dm = base::data().get_domain_indirect (i); \
     return geo_basic<T,M> (dm, *this);				\
-}
-#define _RHEOLEF_geo_dmn_by_name(M)				\
+}								\
 template<class T>						\
 inline								\
 geo_basic<T,M>							\
 geo_basic<T,M>::operator[] (const std::string& name) const	\
 {								\
-    const domain_indirect_basic<M>& dm = base::data().get_domain_indirect (name); \
-    return geo_basic<T,M> (dm, *this);				\
+  if (name == "boundary")             boundary_guard (*this);   \
+  if (name == "sides")                   sides_guard (*this);   \
+  if (name == "internal_sides") internal_sides_guard (*this);   \
+  const domain_indirect_basic<M>& dm  				\
+   = base::data().get_domain_indirect (name); 			\
+  return geo_basic<T,M> (dm, *this);				\
+}								\
+template<class T>						\
+inline										\
+geo_basic<T,M>									\
+operator+ (const geo_basic<T,M>& a, const geo_basic<T,M>& b) 			\
+{                                                                               \
+  check_macro (a.variant() == geo_abstract_base_rep<T>::geo_domain_indirect &&	\
+               b.variant() == geo_abstract_base_rep<T>::geo_domain_indirect,	\
+    "union of geo may be domains of a mesh (was "				\
+	<<a.name()<<" and "<<b.name()<<")");					\
+  check_macro (a.get_background_geo().name() == b.get_background_geo().name(),	\
+    "union of domains between incompatible meshes (was "			\
+	<<a.get_background_geo().name()<<" and "<<b.get_background_geo().name()<<")"); \
+  const geo_domain_indirect_rep<T,M>& a_dom                                     \
+       = dynamic_cast<const geo_domain_indirect_rep<T,M>&>(a.data());           \
+  const geo_domain_indirect_rep<T,M>& b_dom                                     \
+       = dynamic_cast<const geo_domain_indirect_rep<T,M>&>(b.data());           \
+ domain_indirect_basic<M> c_dom							\
+   = build_union (a.get_background_geo(), a_dom.get_indirect(), b_dom.get_indirect()); \
+  return geo_basic<T,M> (c_dom, a.get_background_geo());			\
 }
-_RHEOLEF_geo_cstor(sequential)
-_RHEOLEF_geo_dmn_by_idx(sequential)
-_RHEOLEF_geo_dmn_by_name(sequential)
 
+_RHEOLEF_geo_domain(sequential)
 #ifdef _RHEOLEF_HAVE_MPI
-_RHEOLEF_geo_cstor(distributed)
-_RHEOLEF_geo_dmn_by_idx(distributed)
-_RHEOLEF_geo_dmn_by_name(distributed)
+_RHEOLEF_geo_domain(distributed)
 #endif // _RHEOLEF_HAVE_MPI
-
-#undef _RHEOLEF_geo_cstor
-#undef _RHEOLEF_geo_dmn_by_idx
-#undef _RHEOLEF_geo_dmn_by_name
+#undef _RHEOLEF_domain
 
 } // namespace rheolef
 #endif // _RHEOLEF_DOMAIN_H
