@@ -34,7 +34,6 @@ void
 geo_rep<T,distributed>::domain_set_side_part1 (
     const domain_indirect_rep<distributed>&    indirect, 
     const geo_abstract_rep<T,distributed>&     bgd_omega,
-    array<size_type>&                          bgd_iv2dom_dis_iv,
     size_type                                  sid_dim,
     array<size_type>&                          bgd_isid2dom_dis_isid,
     array<size_type>&                          dom_isid2bgd_isid,
@@ -69,8 +68,8 @@ geo_rep<T,distributed>::domain_set_side_part1 (
       bgd_ios_isid_is_on_domain.dis_entry (bgd_ios_dis_isid) += 1;
     }
   }
-  bgd_isid_is_on_domain.dis_entry_assembly     (set_add_op<size_type,size_type>()); // logical "or"
-  bgd_ios_isid_is_on_domain.dis_entry_assembly (set_add_op<size_type,size_type>());
+  bgd_isid_is_on_domain.dis_entry_assembly(); // logical "or" accross processes
+  bgd_ios_isid_is_on_domain.dis_entry_assembly();
 
   // 1.2 counting & distribution for dom_isid 
   size_type dom_nsid = 0;
@@ -93,9 +92,9 @@ geo_rep<T,distributed>::domain_set_side_part1 (
   dom_isid2bgd_isid.resize     (dom_isid_ownership,                       std::numeric_limits<size_type>::max());
   for (size_type dom_isid = 0, bgd_isid = 0, bgd_nsid = bgd_omega.geo_element_ownership(sid_dim).size(); bgd_isid < bgd_nsid; bgd_isid++) {
     if (bgd_isid_is_on_domain[bgd_isid] == 0) continue;
-    size_type dom_dis_isid = first_dom_dis_isid + dom_isid;
+    size_type dom_dis_isid = first_dom_dis_isid + dom_isid; // distributed case !
     bgd_isid2dom_dis_isid [bgd_isid] = dom_dis_isid;
-    dom_isid2bgd_isid [dom_isid] = bgd_isid;
+    dom_isid2bgd_isid     [dom_isid] = bgd_isid;
     const geo_element& bgd_S = bgd_omega.get_geo_element(sid_dim,bgd_isid);
     size_by_variant [bgd_S.variant()]++;
     dom_isid++;
@@ -204,7 +203,7 @@ geo_rep<T,distributed>::domain_set_side_part2 (
         size_type bgd_dis_inod = dom_S[iloc];
         size_type bgd_dis_iv   = bgd_omega.dis_inod2dis_iv (bgd_dis_inod);
         size_type dom_dis_iv   = bgd_iv2dom_dis_iv.dis_at (bgd_dis_iv);
-        size_type dom_dis_inod = dis_iv2dis_inod (dom_dis_iv);
+        size_type dom_dis_inod = base::dis_iv2dis_inod (dom_dis_iv);
         dom_S[iloc] = dom_dis_inod;
       }
     }
@@ -309,10 +308,11 @@ geo_rep<T,distributed>::domain_set_side_part2 (
 template <class T>
 void
 geo_rep<T,distributed>::build_from_domain (
-    const domain_indirect_rep<distributed>&    indirect, 
-    const geo_abstract_rep<T,distributed>&     bgd_omega)
+        const domain_indirect_rep<distributed>&              indirect,
+        const geo_abstract_rep<T,distributed>&               bgd_omega,
+              std::map<size_type,size_type>&                 bgd_ie2dom_ie)
 {
-  base::_name = bgd_omega.name() + "." + indirect.name();
+  base::_name = bgd_omega.name() + "[" + indirect.name() + "]";
   base::_version       = 4;
   base::_numbering.set_degree(bgd_omega.get_piola_basis().degree());
   base::_dimension     = bgd_omega.dimension();
@@ -320,13 +320,13 @@ geo_rep<T,distributed>::build_from_domain (
   size_type map_dim = base::_map_dimension;
   size_type size_by_variant [reference_element::max_variant];
   std::fill (size_by_variant, size_by_variant+reference_element::max_variant, 0);
-  array<size_type> bgd_ige2dom_dis_ige [4];
-  array<size_type> dom_ige2bgd_ige     [4];
   // ------------------------------------------------------------------------
   // 1) _geo_element[0]: compact renumbering
   // ------------------------------------------------------------------------
+  boost::array<array<size_type,distributed>,4>  bgd_ige2dom_dis_ige;
+  boost::array<array<size_type,distributed>,4>  dom_ige2bgd_ige;
   array<size_type> dom_isid2dom_ios_dis_isid [4];
-  domain_set_side_part1 (indirect, bgd_omega, bgd_ige2dom_dis_ige[0], 0,
+  domain_set_side_part1 (indirect, bgd_omega, 0,
 	bgd_ige2dom_dis_ige[0], dom_ige2bgd_ige[0],
         dom_isid2dom_ios_dis_isid [0], size_by_variant);
   domain_set_side_part2 (indirect, bgd_omega, bgd_ige2dom_dis_ige[0], 0,
@@ -340,8 +340,11 @@ geo_rep<T,distributed>::build_from_domain (
     size_by_variant [variant] = 0;
   }
   std::set<size_type> ext_bgd_dis_iv_set;
+  distributor ioige_ownership = indirect.ownership();
+  size_type first_dis_ioige = ioige_ownership.first_index();
   for (size_type ioige = 0, noige = indirect.size(); ioige < noige; ioige++) {
     size_type ige = indirect.oige (ioige).index();
+    bgd_ie2dom_ie [ige] = ioige;
     const geo_element& bgd_K = bgd_omega.get_geo_element (map_dim, ige);
     size_by_variant [bgd_K.variant()]++;
     for (size_type iloc = 0; iloc < bgd_K.size(); iloc++) {
@@ -375,7 +378,7 @@ geo_rep<T,distributed>::build_from_domain (
   //   => then can determine the node count (order > 1)
   // ------------------------------------------------------------------------
   for (size_type sid_dim = 1; sid_dim < base::_map_dimension; sid_dim++) {
-    domain_set_side_part1 (indirect, bgd_omega, bgd_ige2dom_dis_ige[0], sid_dim,
+    domain_set_side_part1 (indirect, bgd_omega, sid_dim,
 	bgd_ige2dom_dis_ige[sid_dim], dom_ige2bgd_ige[sid_dim],
         dom_isid2dom_ios_dis_isid [sid_dim], size_by_variant);
   }
@@ -396,7 +399,6 @@ geo_rep<T,distributed>::build_from_domain (
   // ------------------------------------------------------------------------
   // 6) set _geo_element[] values
   // ------------------------------------------------------------------------
-  size_type first_dis_ioige  = indirect.ownership().first_index();
   for (size_type ioige = 0, noige = indirect.size(); ioige < noige; ioige++) {
     size_type dis_ioige = first_dis_ioige + ioige;
     size_type ige = indirect.oige (ioige).index();
@@ -411,7 +413,7 @@ geo_rep<T,distributed>::build_from_domain (
       size_type bgd_dis_inod = bgd_K[iloc];
       size_type bgd_dis_iv   = bgd_omega.dis_inod2dis_iv (bgd_dis_inod);
       size_type dom_dis_iv   = bgd_ige2dom_dis_ige[0].dis_at (bgd_dis_iv);
-      size_type dom_dis_inod = dis_iv2dis_inod (dom_dis_iv);
+      size_type dom_dis_inod = base::dis_iv2dis_inod (dom_dis_iv);
       dom_K[iloc] = dom_dis_inod;
     }
   }
@@ -656,7 +658,7 @@ geo_rep<T,distributed>::build_from_domain (
   for (size_type dom_iv = 0, dom_nv = base::_geo_element[reference_element::p].size(); dom_iv < dom_nv; dom_iv++) {
     geo_element& P = base::_geo_element[reference_element::p][dom_iv];
     size_type dom_dis_iv = first_dom_dis_iv + dom_iv;
-    size_type dom_dis_inod = dis_iv2dis_inod (dom_dis_iv);
+    size_type dom_dis_inod = base::dis_iv2dis_inod (dom_dis_iv);
     P[0] = dom_dis_inod;
   }
   /** TODO
