@@ -23,107 +23,6 @@
 
 namespace rheolef {
 
-#ifdef TO_CLEAN
-// ------------------------------------------------------------------------
-// build edge and face connectivity from domain
-// ------------------------------------------------------------------------
-template <class T>
-void
-geo_rep<T,sequential>::domain_set_side (
-    const domain_indirect_rep<sequential>&    indirect, 
-    const geo_abstract_rep<T,sequential>&     bgd_omega,
-    array<size_type,sequential>&              bgd_iv2dom_iv,
-    size_type                                 sid_dim,
-    array<size_type,sequential>&              bgd_isid2dom_isid,
-    array<size_type,sequential>&              dom_isid2bgd_isid,
-    boost::array<size_type,reference_element::max_variant>& size_by_variant)
-{
-  if (sid_dim != 0 && base::_map_dimension <= sid_dim) return;
-  communicator comm = bgd_omega.geo_element_ownership(sid_dim).comm();
-  // ------------------------------------------------------------------------
-  // 1) side compact re-numbering
-  // ------------------------------------------------------------------------
-  // 1.1 loop on elements and mark used sides
-  array<size_type,sequential> bgd_isid_is_on_domain     (bgd_omega.geo_element_ownership(sid_dim), 0); // logical, init to "false"
-  for (size_type ioige = 0, noige = indirect.size(); ioige < noige; ioige++) {
-    size_type ige = indirect.oige (ioige).index();
-    const geo_element& K = bgd_omega.get_geo_element (base::_map_dimension, ige);
-    for (size_type loc_isid = 0, loc_nsid = K.n_subgeo(sid_dim); loc_isid < loc_nsid; loc_isid++) {
-      size_type bgd_isid; // TODO: = K.subgeo (sid_dim, loc_isid);
-      switch (sid_dim) {
-        case 0: bgd_isid = K[loc_isid];      break;
-        case 1: bgd_isid = K.edge(loc_isid); break;
-	default:
-        case 2: bgd_isid = K.face(loc_isid); break;
-      }
-      bgd_isid_is_on_domain [bgd_isid] += 1;
-    }
-  }
-  // 1.2 counting & distribution for dom_isid 
-  size_type dom_nsid = 0;
-  for (size_type bgd_isid = 0, bgd_nsid = bgd_omega.geo_element_ownership(sid_dim).size(); bgd_isid < bgd_nsid; bgd_isid++) {
-    if (bgd_isid_is_on_domain[bgd_isid] != 0) dom_nsid++ ;
-  }
-  // 1.3 numbering dom_isid & permutation: bgd_isid <--> dom_isid
-  for (size_type variant = reference_element::first_variant_by_dimension(sid_dim);
-                 variant < reference_element:: last_variant_by_dimension(sid_dim); variant++) {
-    size_by_variant [variant] = 0;
-  }
-  distributor dom_isid_ownership (distributor::decide, comm, dom_nsid);
-  bgd_isid2dom_isid.resize (bgd_omega.geo_element_ownership(sid_dim), std::numeric_limits<size_type>::max());
-  dom_isid2bgd_isid.resize (dom_isid_ownership,                       std::numeric_limits<size_type>::max());
-  for (size_type dom_isid = 0, bgd_isid = 0, bgd_nsid = bgd_omega.geo_element_ownership(sid_dim).size(); bgd_isid < bgd_nsid; bgd_isid++) {
-    if (bgd_isid_is_on_domain[bgd_isid] == 0) continue;
-    bgd_isid2dom_isid [bgd_isid] = dom_isid;
-    dom_isid2bgd_isid [dom_isid] = bgd_isid;
-    const geo_element& bgd_S = bgd_omega.get_geo_element(sid_dim,bgd_isid);
-    size_by_variant [bgd_S.variant()]++;
-    dom_isid++;
-  }
-  // ------------------------------------------------------------------------
-  // 2) defines _geo_element[sid_dim] and S.set_ios_dis_ie
-  //    also reperate external vertices
-  // ------------------------------------------------------------------------
-  // 2.1 compute sizes ands resize
-  size_type dom_nge = 0;
-  size_type dom_dis_nge = 0;
-  for (size_type variant = reference_element::first_variant_by_dimension(sid_dim);
-                 variant < reference_element:: last_variant_by_dimension(sid_dim); variant++) {
-
-     distributor dom_igev_ownership (distributor::decide, comm, size_by_variant [variant]);
-     geo_element::parameter_type param (variant, 1);
-     base::_geo_element[variant].resize (dom_igev_ownership, param);
-     base::_gs.ownership_by_variant[variant] = dom_igev_ownership;
-     dom_nge     += dom_igev_ownership.size();
-     dom_dis_nge += dom_igev_ownership.dis_size();
-  }
-  base::_gs.ownership_by_dimension[sid_dim] = distributor (dom_dis_nge, comm, dom_nge);
-  // _geo_element[p] n'est pas dimensione dans geo_seq_get.cc ?
-
-  for (size_type dom_isid = 0; dom_isid < dom_nsid; dom_isid++) {
-    size_type bgd_isid = dom_isid2bgd_isid [dom_isid];
-    const geo_element& bgd_S = bgd_omega.get_geo_element(sid_dim,bgd_isid);
-    geo_element& dom_S = get_geo_element(sid_dim,dom_isid);
-    dom_S = bgd_S;
-    dom_S.set_dis_ie     (dom_isid);
-    dom_S.set_ios_dis_ie (dom_isid);
-    // set S face & edge : index, orientation & rotation will be set by propagate_numbering later
-  }
-  // ------------------------------------------------------------------------
-  // 3) propagate new vertex numbering in all `dom_S' new sides
-  // ------------------------------------------------------------------------
-  if (sid_dim > 0) {
-    for (size_type dom_isid = 0; dom_isid < dom_nsid; dom_isid++) {
-      geo_element& dom_S = get_geo_element(sid_dim,dom_isid);
-      for (size_type iloc = 0, nloc = dom_S.size(); iloc < nloc; iloc++) {
-        size_type bgd_iv = dom_S[iloc];
-        size_type dom_iv = bgd_iv2dom_iv [bgd_iv];
-        dom_S[iloc] = dom_iv;
-      }
-    }
-  }
-}
-#endif // TO_CLEAN
 // ------------------------------------------------------------------------
 // build edge and face connectivity from domain
 // ------------------------------------------------------------------------
@@ -132,7 +31,6 @@ void
 geo_rep<T,sequential>::domain_set_side_part1 (
     const domain_indirect_rep<sequential>&    indirect, 
     const geo_abstract_rep<T,sequential>&     bgd_omega,
-    array<size_type,sequential>&              bgd_iv2dom_dis_iv,
     size_type                                 sid_dim,
     array<size_type,sequential>&              bgd_isid2dom_dis_isid,
     array<size_type,sequential>&              dom_isid2bgd_isid,
@@ -179,9 +77,9 @@ geo_rep<T,sequential>::domain_set_side_part1 (
   dom_isid2bgd_isid.resize     (dom_isid_ownership,                       std::numeric_limits<size_type>::max());
   for (size_type dom_isid = 0, bgd_isid = 0, bgd_nsid = bgd_omega.geo_element_ownership(sid_dim).size(); bgd_isid < bgd_nsid; bgd_isid++) {
     if (bgd_isid_is_on_domain[bgd_isid] == 0) continue;
-    size_type dom_dis_isid = dom_isid;
+    size_type dom_dis_isid = dom_isid; // sequential case !
     bgd_isid2dom_dis_isid [bgd_isid] = dom_dis_isid;
-    dom_isid2bgd_isid [dom_isid] = bgd_isid;
+    dom_isid2bgd_isid     [dom_isid] = bgd_isid;
     const geo_element& bgd_S = bgd_omega.get_geo_element(sid_dim,bgd_isid);
     size_by_variant [bgd_S.variant()]++;
     dom_isid++;
@@ -244,7 +142,7 @@ geo_rep<T,sequential>::domain_set_side_part2 (
         size_type bgd_dis_inod = dom_S[iloc];
         size_type bgd_dis_iv   = bgd_omega.dis_inod2dis_iv (bgd_dis_inod);
         size_type dom_dis_iv   = bgd_iv2dom_dis_iv.dis_at (bgd_dis_iv);
-        size_type dom_dis_inod = dis_iv2dis_inod (dom_dis_iv);
+        size_type dom_dis_inod = base::dis_iv2dis_inod (dom_dis_iv);
         dom_S[iloc] = dom_dis_inod;
       }
     }
@@ -256,10 +154,11 @@ geo_rep<T,sequential>::domain_set_side_part2 (
 template <class T>
 void
 geo_rep<T,sequential>::build_from_domain (
-    const domain_indirect_rep<sequential>&    indirect, 
-    const geo_abstract_rep<T,sequential>& bgd_omega)
+        const domain_indirect_rep<sequential>&              indirect,
+        const geo_abstract_rep<T,sequential>&               bgd_omega,
+              std::map<size_type,size_type>&                bgd_ie2dom_ie)
 {
-  base::_name = bgd_omega.name() + "." + indirect.name();
+  base::_name = bgd_omega.name() + "[" + indirect.name() + "]";
   base::_version = 4;
   base::_dimension     = bgd_omega.dimension();
   base::_numbering.set_degree (bgd_omega.get_piola_basis().degree());
@@ -268,13 +167,13 @@ geo_rep<T,sequential>::build_from_domain (
   size_type map_dim = base::_map_dimension;
   size_type size_by_variant [reference_element::max_variant];
   std::fill (size_by_variant, size_by_variant+reference_element::max_variant, 0);
-  array<size_type,sequential> bgd_ige2dom_dis_ige [4];
-  array<size_type,sequential> dom_ige2bgd_ige     [4];
   // ----------------------------------------------------
   // 1) _geo_element[0]: compact re-numbering
   // ----------------------------------------------------
   array<size_type,sequential> dom_isid2dom_ios_dis_isid [4];
-  domain_set_side_part1 (indirect, bgd_omega, bgd_ige2dom_dis_ige[0], 0,
+  boost::array<array<size_type,sequential>,4>  bgd_ige2dom_dis_ige;
+  boost::array<array<size_type,sequential>,4>  dom_ige2bgd_ige;
+  domain_set_side_part1 (indirect, bgd_omega, 0,
         bgd_ige2dom_dis_ige[0], dom_ige2bgd_ige[0],
         dom_isid2dom_ios_dis_isid [0], size_by_variant);
   domain_set_side_part2 (indirect, bgd_omega, bgd_ige2dom_dis_ige[0], 0,
@@ -289,6 +188,7 @@ geo_rep<T,sequential>::build_from_domain (
   }
   for (size_type ioige = 0, noige = indirect.size(); ioige < noige; ioige++) {
     size_type ige = indirect.oige (ioige).index();
+    bgd_ie2dom_ie [ige] = ioige;
     const geo_element& bgd_K = bgd_omega.get_geo_element (map_dim, ige);
     size_by_variant [bgd_K.variant()]++;
   }
@@ -312,7 +212,7 @@ geo_rep<T,sequential>::build_from_domain (
   //   => then can determine the node count (order > 1)
   // ------------------------------------------------------------------------
   for (size_type sid_dim = 1; sid_dim < base::_map_dimension; sid_dim++) {
-    domain_set_side_part1 (indirect, bgd_omega, bgd_ige2dom_dis_ige[0], sid_dim,
+    domain_set_side_part1 (indirect, bgd_omega, sid_dim,
         bgd_ige2dom_dis_ige[sid_dim], dom_ige2bgd_ige[sid_dim],
         dom_isid2dom_ios_dis_isid [sid_dim], size_by_variant);
   }
@@ -348,7 +248,7 @@ geo_rep<T,sequential>::build_from_domain (
       size_type bgd_dis_inod = bgd_K[iloc];
       size_type bgd_dis_iv   = bgd_omega.dis_inod2dis_iv (bgd_dis_inod);
       size_type dom_dis_iv   = bgd_ige2dom_dis_ige[0].dis_at (bgd_dis_iv);
-      size_type dom_dis_inod = dis_iv2dis_inod (dom_dis_iv);
+      size_type dom_dis_inod = base::dis_iv2dis_inod (dom_dis_iv);
       dom_K[iloc] = dom_dis_inod;
     }
   }
@@ -411,7 +311,7 @@ geo_rep<T,sequential>::build_from_domain (
   // ------------------------------------------------------------------------
   for (size_type dom_iv = 0, dom_nv = base::_geo_element[reference_element::p].size(); dom_iv < dom_nv; dom_iv++) {
     geo_element& P = base::_geo_element[reference_element::p][dom_iv];
-    size_type dom_inod = dis_iv2dis_inod (dom_iv);
+    size_type dom_inod = base::dis_iv2dis_inod (dom_iv);
     P[0] = dom_inod;
   }
   /** TODO
