@@ -348,11 +348,12 @@ geo_locate_rep<T,M,D>::seq_locate (
   // epsilon is only for bbox: then, predicate on element K is exact
   // TODO: compute epsilon with omega.hmin scale ?
   // static const T eps = 1e5*std::numeric_limits<T>::epsilon();
-  static const T eps = 1000*std::numeric_limits<T>::epsilon();
+  // static const T eps = 1000*std::numeric_limits<T>::epsilon();
+  static const T eps = sqrt(std::numeric_limits<T>::epsilon());
   Interval xe = Interval (cgal_locate_traits<T,D>::make_cgal_point_window (x, eps), 0);
   std::list<Interval> intersected_boxes;
   // point query = inverse range query ; from ::CGAL documentation:
-  // "In order to perform an inverse range query, a range query of ε width has to be performed.
+  // "In order to perform an inverse range query, a range query of epsilon width has to be performed.
   // We prefered not to offer an extra function for this sort of query, since the inverse range
   // query is a special case of the range query (window_query)"
   _tree.window_query (xe, std::back_inserter(intersected_boxes));
@@ -361,7 +362,7 @@ geo_locate_rep<T,M,D>::seq_locate (
     const geo_element& K = omega[ie];
     bool intersect = K.contains (omega.get_nodes(), x); 
     if (intersect) {
-      dis_ie = K.dis_ie(); // global 'ie' index of the element
+      dis_ie = K.dis_ie();
       break;
     }
   }
