@@ -616,8 +616,23 @@ geo_rep<T,distributed>::trace_ray_boundary (
     if (hit) {
       // here x[i)+v[i] cross the local boundary partition
       dis_ie[i] = base::_locator.seq_locate (*this, y[i]);
+      if (dis_ie[i] == std::numeric_limits<size_type>::max()) {
+        // y was outside Omega ? most of the time, y is exactly on the boundary:
+        // dirty hack: project y on the bbox of the boundary:
+        //  - this works in 1d when Omega is simply connected
+        //  - this works in 2d & 3d when Omega is a rectangle or a paralellotope...
+        // TODO: boundary projection in the multi-connected case with: y = omega.nearest(x+v)
+	T eps = 1e3*std::numeric_limits<T>::epsilon();
+        for (size_t k = 0; k < base::_dimension; k++) {
+          y[i][k] = std::max (std::min (y[i][k]+eps, base::_xmax[k]-eps), base::_xmin[k]);
+        }
+        dis_ie[i] = base::_locator.seq_locate (*this, y[i]);
+      }
+#ifndef TO_CLEAN
+      std::cerr << std::setprecision (17);
+#endif // TO_CLEAN
       check_macro (dis_ie[i] != std::numeric_limits<size_type>::max(),
-        "trace_ray_boundary: locator failed at x="<<ptos(x[i],base::_dimension)<<",v="<<ptos(v[i],base::_dimension));
+        "trace_ray_boundary: locator failed at y="<<ptos(y[i],base::_dimension));
     } else {
       // here x[i)+v[i] cross the boundary, on a boundary part that is managed by another proc
       failed.push_back (i);
