@@ -25,6 +25,7 @@
 #include "rheolef/form_vf_expr.h"
 #include "rheolef/form_option_type.h"
 #include "rheolef/integrate_numeric.icc"
+#include "rheolef/riesz.h" // for details::f_constant
 namespace rheolef { 
 
 /*Class:integrate
@@ -32,12 +33,12 @@ NAME: @code{integrate} - integrate a function or an expression
 @findex  integrate
 DESCRIPTION:
   Integrate an expression over a domain by using a quadrature formulae.
-  There are two main usages of the integrate function, depending upon the 
+  There are three main usages of the integrate function, depending upon the 
   type of the expression.
-  When the expression is a numerical one, it leads to a numerical value.
-  When the expression involves a symbolic test-function @pxref{test class},
+  (i) When the expression is a numerical one, it leads to a numerical value.
+  (ii) When the expression involves a symbolic test-function @pxref{test class},
   the result is a linear form, represented by the @code{field} class. 
-  When the expression involves both  symbolic trial- and test-functions @pxref{test class},
+  (iii) When the expression involves both  symbolic trial- and test-functions @pxref{test class},
   the result is a bilinear form, represented by the @code{field} class. 
 SYNOPSYS:
 @example
@@ -78,13 +79,22 @@ DEFAULT ARGUMENTS:
   field l2h = integrate (omega["boundary"], f*v, qopt);
   field l3h = integrate ("boundary", f*v, qopt);
 @end example
-  Also, the quadrature formulae is optional: by default
-  it is deduced from the space containing the test-function. 
-  Let k be its polynomial degree, then the default quadrature is
+  The quadrature formulae is required, except when a test and/or trial
+  function is provided in the expression to integrate.
+  In that case, the quadrature formulae is deduced from the space
+  containing the test (or trial) function. 
+  When a test function is suppied, let k be its polynomial degree.
+  Then the default quadrature is
   choosen to be exact at least for 2*k+1 polynoms.
+  When both a test and trial functions are suppied, let k1 and k2 be their polynomial degrees.
+  Then the default quadrature is
+  choosen to be exact at least for k1+k2+1 polynoms.
+  Also, when the expression is a constant, the quadrature function is optional:
+  in that case, the constant is also optional and the following call:
 @example
-  field l4h = integrate (f*v);
+  Float meas = integrate (omega);
 @end example
+  is valid and returns the measure of the domain.
 End: */
 
 // ----------------------------------------------
@@ -232,15 +242,6 @@ integrate (const band_basic<T,M>& gh, const form_vf_expr<Expr>& expr,
 // ----------------------------------------------
 // numeric integration
 // ----------------------------------------------
-#ifdef TODO
-// TODO: Float r = integrate(omega);
-// -> implementation speciale ? field one(P0) ? geo.order > 1 => quadrature d'ordre identique ?
-template <class T, class M>
-T integrate (const geo_basic<T,M>& dom, const T& f = 1, const quadrature_option_type& qopt = quadrature_option_type())
-{
-}
-#endif // TODO
-
 template <class T, class M, class Function>
 T integrate (const geo_basic<T,M>& dom, const field_functor<Function,T>& f, const quadrature_option_type& qopt)
 {
@@ -248,6 +249,16 @@ T integrate (const geo_basic<T,M>& dom, const field_functor<Function,T>& f, cons
   typedef field_nonlinear_expr<arg_t>             expr_t;
   return details::integrate_numeric (dom, expr_t(arg_t(f.get_ref())), qopt);
 }
+// Float r = integrate(omega); ICI
+template <class T, class M>
+T integrate (const geo_basic<T,M>& dom, const T& f = 1, const quadrature_option_type& qopt = quadrature_option_type())
+{
+  typedef details::f_constant<point_basic<T>,T> f_cte_t;
+  typedef field_expr_terminal_function<f_cte_t> arg_t;
+  typedef field_nonlinear_expr<arg_t>           expr_t;
+  f_cte_t f_cte (f);
+  return details::integrate_numeric (dom, expr_t(arg_t(f_cte)), qopt);
+}
 template <class T, class M>
 T integrate (const geo_basic<T,M>& dom, T (*f)(const point_basic<T>&), const quadrature_option_type& qopt)
 {
@@ -256,17 +267,6 @@ T integrate (const geo_basic<T,M>& dom, T (*f)(const point_basic<T>&), const qua
   typedef field_nonlinear_expr<arg_t>             expr_t;
   return details::integrate_numeric (dom, expr_t(arg_t(f)), qopt);
 }
-#ifdef TO_CLEAN
-// function<> is ambiguous with form_vf_expr<Expr>...! why...?
-template <class M>
-Float integrate (const geo_basic<Float,M>& dom, const function<Float(const point_basic<Float>&)>& f, const quadrature_option_type& qopt)
-{
-  typedef function<Float(const point_basic<Float>&)> fun_t;
-  typedef field_expr_terminal_function<fun_t>        arg_t;
-  typedef field_nonlinear_expr<arg_t>                expr_t;
-  return details::integrate_numeric (dom, expr_t(arg_t(f)), qopt);
-}
-#endif // TO_CLEAN
 template <class T, class M>
 T integrate (const geo_basic<T,M>& dom, const field_basic<T,M>& f, const quadrature_option_type& qopt)
 {
@@ -303,6 +303,13 @@ T integrate (const geo_basic<T,M>& dom, const field_component_const<T,M>& f, con
   return details::integrate_numeric (dom, expr_t(arg_t(f)), qopt);
 }
 template <class T, class M, class E>
+T integrate (const geo_basic<T,M>& dom, const field_expr<E>& f, const quadrature_option_type& qopt)
+{
+  typedef field_expr_terminal_field<T,M>  arg_t;
+  typedef field_nonlinear_expr<arg_t>     expr_t;
+  return details::integrate_numeric (dom, expr_t(arg_t(f)), qopt);
+}
+template <class T, class M, class E>
 T integrate (const geo_basic<T,M>& dom, const field_nonlinear_expr<E>& f, const quadrature_option_type& qopt)
 {
   return details::integrate_numeric (dom, f, qopt);
