@@ -187,8 +187,12 @@ struct interpolate_internal_check<T,M,Expr,undeterminated_basic<T>,Status> {
 	interpolate_internal_check<T,M,Expr,tensor_basic<T>,mpl::true_> eval;
 	return eval (Xh, expr);
     }
-    default: error_macro ("unexpected "
-	<< space_constant::valued_name (expr.valued_tag()) << " expression");
+    default:
+        warning_macro ("Expr="<<pretty_typename_macro(Expr));
+        warning_macro ("Status="<<typename_macro(Status));
+        error_macro ("unexpected `"
+	<< space_constant::valued_name (expr.valued_tag())
+        << "' valued expression");
         return field_basic<T,M>();
   }
 }};
