@@ -125,11 +125,16 @@ public:
 
     void dis_idof (const geo_element& K, std::vector<size_type>& dis_idof) const;
 
+
+    // TODO: merge all V.xxx_momentum: the return type can be computed from Function::result_type
     template <class Function>
-    T momentum (Function f, size_type idof) const { return f (xdof(idof)); }
+    T momentum (const Function& f, size_type idof) const { return f (xdof(idof)); }
 
     template <class Function>
-    point_basic<T> vector_momentum (Function f, size_type idof) const { return f (xdof(idof)); }
+    point_basic<T> vector_momentum (const Function& f, size_type idof) const { return f (xdof(idof)); }
+
+    template <class Function>
+    tensor_basic<T> tensor_momentum (const Function& f, size_type idof) const { return f (xdof(idof)); }
 
     array<size_type, M> build_indirect_array (
     	const space_base_rep<T,M>& Wh, const std::string& dom_name) const;
@@ -345,10 +350,13 @@ public:
     const array<point_basic<T>,sequential>& get_xdofs() const;
 
     template <class Function>
-    T momentum (Function f, size_type idof) const;
+    T momentum (const Function& f, size_type idof) const;
 
     template <class Function>
-    point_basic<T> vector_momentum (Function f, size_type idof) const;
+    point_basic<T> vector_momentum (const Function& f, size_type idof) const;
+
+    template <class Function>
+    tensor_basic<T> tensor_momentum (const Function& f, size_type idof) const;
 
     array<size_type, sequential> build_indirect_array (
     	const space_basic<T,sequential>& Wh, const std::string& dom_name) const;
@@ -610,7 +618,7 @@ template<class T>
 template <class Function>
 inline
 T
-space_basic<T,sequential>::momentum (Function f, size_type idof) const
+space_basic<T,sequential>::momentum (const Function& f, size_type idof) const
 {
     return base::data().momentum (f, idof);
 }
@@ -618,10 +626,18 @@ template<class T>
 template <class Function>
 inline
 point_basic<T>
-space_basic<T,sequential>::vector_momentum (Function f, size_type idof) const
+space_basic<T,sequential>::vector_momentum (const Function& f, size_type idof) const
 {
     return base::data().vector_momentum (f, idof);
 }
+template<class T>
+template <class Function>
+tensor_basic<T>
+space_basic<T,sequential>::tensor_momentum (const Function& f, size_type idof) const
+{
+    return base::data().tensor_momentum (f, idof);
+}
+
 // ---------------------------------------------------------------------
 #ifdef _RHEOLEF_HAVE_MPI
 //<verbatim:
@@ -686,10 +702,13 @@ public:
     const array<point_basic<T>,distributed>& get_xdofs() const;
 
     template <class Function>
-    T momentum (Function f, size_type idof) const;
+    T momentum (const Function& f, size_type idof) const;
 
     template <class Function>
-    point_basic<T> vector_momentum (Function f, size_type idof) const;
+    point_basic<T> vector_momentum (const Function& f, size_type idof) const;
+
+    template <class Function>
+    tensor_basic<T> tensor_momentum (const Function& f, size_type idof) const;
 
     array<size_type, distributed> build_indirect_array (
     	const space_basic<T,distributed>& Wh, const std::string& dom_name) const;
@@ -952,7 +971,7 @@ template<class T>
 template <class Function>
 inline
 T
-space_basic<T,distributed>::momentum (Function f, size_type idof) const
+space_basic<T,distributed>::momentum (const Function& f, size_type idof) const
 {
     return base::data().momentum (f, idof);
 }
@@ -960,10 +979,17 @@ template<class T>
 template <class Function>
 inline
 point_basic<T>
-space_basic<T,distributed>::vector_momentum (Function f, size_type idof) const
+space_basic<T,distributed>::vector_momentum (const Function& f, size_type idof) const
 {
     return base::data().vector_momentum (f, idof);
 }
+template<class T>
+template <class Function>
+tensor_basic<T>
+space_basic<T,distributed>::tensor_momentum (const Function& f, size_type idof) const
+{
+    return base::data().tensor_momentum (f, idof);
+}
 #endif // _RHEOLEF_HAVE_MPI
 
 // only valid when M=sequential or M=distributed => use a macro
