@@ -48,6 +48,12 @@ template<class T> struct is_point<point_basic<T> > : boost::mpl::true_ {};
 template<class T> struct is_tensor                   : boost::mpl::false_ {};
 template<class T> struct is_tensor<tensor_basic<T> > : boost::mpl::true_ {};
 
+template<class T> struct is_tensor3                    : boost::mpl::false_ {};
+template<class T> struct is_tensor3<tensor3_basic<T> > : boost::mpl::true_ {};
+
+template<class T> struct is_tensor4                    : boost::mpl::false_ {};
+template<class T> struct is_tensor4<tensor4_basic<T> > : boost::mpl::true_ {};
+
 }} // namespace rheolef::details
 
 // -------------------------------------------------------------
@@ -76,9 +82,10 @@ typedef enum {
 	vector             = 1,
 	tensor             = 2, // symmetric, D_ij
         unsymmetric_tensor = 3,
-        tensor4            = 4, // symmetric, A_ijkl
-	mixed              = 5,
-	last_valued        = 6
+        tensor3            = 4, // unsymmetric, G_ijk
+        tensor4            = 5, // symmetric, A_ijkl
+	mixed              = 6,
+	last_valued        = 7
 } valued_type;
 
 const std::string& valued_name (valued_type tag);
@@ -99,6 +106,7 @@ size_type n_component (
 template<class T> struct valued_tag_traits                           { static const valued_type value = scalar; };
 template<class T> struct valued_tag_traits<point_basic<T> >          { static const valued_type value = vector; };
 template<class T> struct valued_tag_traits<tensor_basic<T> >         { static const valued_type value = tensor; };
+template<class T> struct valued_tag_traits<tensor3_basic<T> >        { static const valued_type value = tensor3; };
 template<class T> struct valued_tag_traits<tensor4_basic<T> >        { static const valued_type value = tensor4; };
 template<class T> struct valued_tag_traits<undeterminated_basic<T> > { static const valued_type value = last_valued; };
 
@@ -109,18 +117,22 @@ template<int Tag, class T> struct valued_type_traits                { typedef un
 template<class T>          struct valued_type_traits<scalar,T>      { typedef T                       type; };
 template<class T>          struct valued_type_traits<vector,T>      { typedef point_basic<T>          type; };
 template<class T>          struct valued_type_traits<tensor,T>      { typedef tensor_basic<T>         type; };
+template<class T>          struct valued_type_traits<tensor3,T>     { typedef tensor3_basic<T>        type; };
 template<class T>          struct valued_type_traits<tensor4,T>     { typedef tensor4_basic<T>        type; };
 template<class T>          struct valued_type_traits<last_valued,T> { typedef undeterminated_basic<T> type; };
 
 // tensorial up and down helpers (for grad(expr))
-template<class T> struct rank_down                   { typedef undeterminated_basic<typename scalar_traits<T>::type>  type; };
-template<class T> struct rank_down<point_basic<T> >  { typedef T                   type; };
-template<class T> struct rank_down<tensor_basic<T> > { typedef point_basic<T>      type; };
+template<class T> struct rank_down                    { typedef undeterminated_basic<typename scalar_traits<T>::type>  type; };
+template<class T> struct rank_down<point_basic<T> >   { typedef T                   type; };
+template<class T> struct rank_down<tensor_basic<T> >  { typedef point_basic<T>      type; };
+template<class T> struct rank_down<tensor3_basic<T> > { typedef tensor_basic<T>     type; };
+template<class T> struct rank_down<tensor4_basic<T> > { typedef tensor3_basic<T>    type; };
 
-template<class T> struct rank_up                  { typedef point_basic<typename scalar_traits<T>::type>  type; };
-template<class T> struct rank_up<point_basic<T> > { typedef tensor_basic<T> type; };
+template<class T> struct rank_up                           { typedef point_basic<typename scalar_traits<T>::type>  type; };
+template<class T> struct rank_up<point_basic<T> >          { typedef tensor_basic<T> type; };
+template<class T> struct rank_up<tensor_basic<T> >         { typedef tensor3_basic<T> type; };
+template<class T> struct rank_up<tensor3_basic<T> >        { typedef tensor4_basic<T> type; };
 template<class T> struct rank_up<undeterminated_basic<T> > { typedef undeterminated_basic<typename scalar_traits<T>::type>  type; };
-// TODO: tensor3
 
 template<class T>
 T contract_product (const T& a, const T& b) { return a*b; }
