@@ -173,10 +173,11 @@ put (std::ostream& os, const space_constitution<T,M>& constit, size_t level = 0)
     return os;
   }
   if (constit.valued_tag() == space_constant::vector ||
-      constit.valued_tag() == space_constant::tensor) {
+      constit.valued_tag() == space_constant::tensor ||
+      constit.valued_tag() == space_constant::unsymmetric_tensor) {
     assert_macro (constit.get_hierarchy().size() >= 1, "invalid space_constitution");
     const space_constitution<T,M>& base_constit = *(constit.get_hierarchy().begin());
-    std::string spec = (constit.valued_tag() == space_constant::vector) ? "vector" : "tensor";
+    std::string spec = space_constant::valued_name (constit.valued_tag());
     os << spec << "(";
     put (os, base_constit, level+1);
     os << ")";
@@ -323,7 +324,9 @@ space_constitution_rep<T,M>::get_geo() const
   if (! is_hierarchical()) {
     return get_scalar().get_geo();
   }
-  check_macro (_valued_tag == space_constant::vector || _valued_tag == space_constant::tensor,
+  check_macro (_valued_tag == space_constant::vector ||
+	       _valued_tag == space_constant::tensor ||
+	       _valued_tag == space_constant::unsymmetric_tensor,
 	"get_geo: undefined for heterogeneous space products");
   // each component of homogeneous tensorial space product have the same mesh:
   assert_macro (_hier_constit.size() > 0, "get_geo: empty vectorial/tensorial space product");
@@ -338,7 +341,9 @@ space_constitution_rep<T,M>::get_numbering() const
   if (! is_hierarchical()) {
     return get_scalar().get_numbering();
   }
-  check_macro (_valued_tag == space_constant::vector || _valued_tag == space_constant::tensor,
+  check_macro (_valued_tag == space_constant::vector ||
+	       _valued_tag == space_constant::tensor ||
+	       _valued_tag == space_constant::unsymmetric_tensor,
 	"get_numbering: undefined for heterogeneous space products");
   // each component of homogeneous tensorial space product have the same basis:
   assert_macro (_hier_constit.size() > 0, "get_numbering: empty vectorial/tensorial space product");
@@ -447,7 +452,8 @@ space_constitution_rep<T,M>::loc_ndof (const reference_element& hat_K) const
       return get_numbering().get_basis().size (hat_K);
     }
     case space_constant::vector:
-    case space_constant::tensor: {
+    case space_constant::tensor:
+    case space_constant::unsymmetric_tensor: {
       // LIMITATION: assume homogeneous vector or tensor valued
       // multi-component case: shift from i_comp=0
       size_type loc_comp_ndof = get_numbering().get_basis().size (hat_K);
@@ -471,7 +477,8 @@ space_constitution_rep<T,M>::dis_idof (const geo_element& K, std::vector<size_ty
       return;
     }
     case space_constant::vector:
-    case space_constant::tensor: {
+    case space_constant::tensor:
+    case space_constant::unsymmetric_tensor: {
       // LIMITATION: assume homogeneous vector or tensor valued
       // multi-component case: shift from i_comp=0
       assert_macro (_hier_constit.size() > 0, "unexpected empty vector valued");
