@@ -1,4 +1,4 @@
-///
+//
 /// This file is part of Rheolef.
 ///
 /// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
@@ -34,7 +34,8 @@ test_rep<T,M>::test_rep (const space_type& V)
   _dis_inod_K(),
   _dis_inod_L(),
   _piola_on_quad(),
-  _elements_on_bgd_dom(false)
+  _elements_on_bgd_dom(false),
+  _have_dg_on_sides(false)
 {
 }
 template <class T, class M>
@@ -49,7 +50,8 @@ test_rep<T,M>::test_rep (const test_rep<T,M>& x)
   _dis_inod_K(x._dis_inod_K),
   _dis_inod_L(x._dis_inod_L),
   _piola_on_quad(x._piola_on_quad),
-  _elements_on_bgd_dom(x._elements_on_bgd_dom)
+  _elements_on_bgd_dom(x._elements_on_bgd_dom),
+  _have_dg_on_sides(x._have_dg_on_sides)
 {
   trace_macro ("*** PHYSICAL COPY OF TEST_REP ***");
 }
@@ -58,15 +60,20 @@ void
 test_rep<T,M>::initialize (const geo_basic<float_type,M>& dom, const quadrature<T>& quad, bool ignore_sys_coord) const
 {
   _is_on_band = false;
+  _elements_on_bgd_dom = false;
+  _have_dg_on_sides = false;
   if (_V.get_geo().variant() != geo_abstract_base_rep<float_type>::geo_domain || _V.get_geo().name() == dom.name()) {
-    if (_dom.variant() != geo_abstract_base_rep<T>::geo_domain_indirect) {
+    if (dom.variant() != geo_abstract_base_rep<T>::geo_domain_indirect
+        || 1 + dom.map_dimension() != dom.get_background_geo().map_dimension()
+	|| _V.get_numbering().is_continuous()) {
       // usual case
       _dom = dom;
     } else {
-      // DG: dom="sides", but for a side K, will access to its neighbours L0 & L1 for e.g. dot(grad(u),normal())
+      // DG on dom="sides" or "boundary" or other d-1 sides domain
+      // but for a side K, will access to its neighbours L0 & L1 for e.g. dot(grad(u),normal())
       _dom = dom.get_background_geo();
+      _have_dg_on_sides = true;
     }
-    _elements_on_bgd_dom = false;
   } else {
     // space X (omega);
     // space Y (omega["boundary"]);
@@ -93,6 +100,8 @@ void
 test_rep<T,M>::initialize (const band_basic<float_type,M>& gh, const quadrature<T>& quad, bool ignore_sys_coord) const
 {
   _is_on_band = true;
+  _elements_on_bgd_dom = false;
+  _have_dg_on_sides = false;
   _dom = gh.level_set();
   _gh = gh;
   _basis_on_quad.set (quad, get_vf_space().get_numbering().get_basis());
@@ -115,7 +124,26 @@ test_rep<T,M>::element_initialize (const geo_element& K) const
 {
   if (!_is_on_band) {
     if (!_elements_on_bgd_dom) {
-      _dom.dis_inod (K, _dis_inod_K);
+      if (!_have_dg_on_sides || K.dimension() == _dom.map_dimension()) {
+        _dom.dis_inod (K, _dis_inod_K);
+      } else {
+	// omits "inner(u)" on a sides-domain => assume a boundary side
+        size_type L_map_d = K.dimension() + 1;
+        check_macro (L_map_d == _dom.map_dimension(),
+	  "unexpected dimension for side {"<<K<<"} in domain "<<_dom.name());
+        check_macro (K.master(1) == std::numeric_limits<size_type>::max(),
+          "unexpected non-boundary side K="<<K);
+        size_type L_dis_ie = K.master(0);
+        check_macro (L_dis_ie != std::numeric_limits<size_type>::max(),
+          "unexpected isolated side K="<<K);
+        const geo_element& L = _dom.dis_get_geo_element (L_map_d, L_dis_ie);
+        _tilde_L = L.variant();
+        _dom.dis_inod (L, _dis_inod_K);
+        side_information_type sid;
+        L.get_side_informations (K, sid);
+        _basis_on_quad.restrict_on_side (L, sid);
+        _piola_on_quad.restrict_on_side (L, sid);
+      }
     } else {
       const geo_element& dom_K = _dom.bgd2dom_geo_element (K);
       _dom.dis_inod (dom_K, _dis_inod_K);
@@ -152,10 +180,15 @@ void
 test_rep<T,M>::_basis_evaluate_init (const reference_element& hat_K, size_type q, size_type loc_ndof) const
 {
   if (!_is_on_band) {
-    check_macro (loc_ndof == get_vf_space().get_constitution().loc_ndof (hat_K), 
+    reference_element ref_K = hat_K;
+    if (_have_dg_on_sides && hat_K.dimension() != _dom.map_dimension()) {
+      // DG on boundary: L has a face that contains K
+      ref_K = _tilde_L;
+    }
+    check_macro (loc_ndof == get_vf_space().get_constitution().loc_ndof (ref_K), 
 	"invalid value local ndof="<<loc_ndof<<": expect loc_ndof="
-  	<<get_vf_space().get_constitution().loc_ndof (hat_K));
-    _basis_on_quad.evaluate (hat_K, q);
+  	<<get_vf_space().get_constitution().loc_ndof (ref_K));
+    _basis_on_quad.evaluate (ref_K, q);
   } else {
     check_macro (loc_ndof == get_vf_space().get_constitution().loc_ndof (_tilde_L), 
 	"invalid value local ndof="<<loc_ndof<<": expect loc_ndof="
@@ -217,6 +250,18 @@ test_rep<T,M>::_basis_evaluate (const reference_element& hat_K, size_type q, std
     }
   }
 }
+template <class T, class M>
+void
+test_rep<T,M>::_basis_evaluate (const reference_element& hat_K, size_type q, std::vector<tensor3_basic<T> >& value) const
+{
+  fatal_macro ("basis_evaluate: tensor3, not yet");
+}
+template <class T, class M>
+void
+test_rep<T,M>::_basis_evaluate (const reference_element& hat_K, size_type q, std::vector<tensor4_basic<T> >& value) const
+{
+  fatal_macro ("basis_evaluate: tensor4, not yet");
+}
 // ----------------------------------------------    
 // grad basis
 // ----------------------------------------------    
@@ -258,8 +303,13 @@ test_rep<T,M>::_basis_evaluate (const reference_element& hat_K, size_type q, std
 */
 template <class T, class M>
 void
-test_rep<T,M>::_grad_basis_evaluate_init (const reference_element& hat_K, size_type q, size_type loc_ndof) const
+test_rep<T,M>::_grad_basis_evaluate_init (const reference_element& hat_K_in, size_type q, size_type loc_ndof) const
 {
+  reference_element hat_K = hat_K_in;
+  if (_have_dg_on_sides && hat_K.dimension() != _dom.map_dimension()) {
+      // DG on boundary: L has a face that contains K
+      hat_K = _tilde_L;
+  }
   if (!_is_on_band) {
     check_macro (loc_ndof == get_vf_space().get_constitution().loc_ndof (hat_K), 
 	"invalid value local ndof="<<loc_ndof<<": expect loc_ndof="
@@ -276,10 +326,16 @@ test_rep<T,M>::_grad_basis_evaluate (const reference_element& hat_K, size_type q
 {
   fatal_macro ("grad: unexpected scalar-valued result");
 }
+// grad(scalar) -> vector
 template <class T, class M>
 void
-test_rep<T,M>::_grad_basis_evaluate (const reference_element& hat_K, size_type q, const details::grad_option_type& opt, std::vector<point_basic<T> >& value) const
+test_rep<T,M>::_grad_basis_evaluate (const reference_element& hat_K_in, size_type q, const details::grad_option_type& opt, std::vector<point_basic<T> >& value) const
 {
+  reference_element hat_K = hat_K_in;
+  if (_have_dg_on_sides && hat_K.dimension() != _dom.map_dimension()) {
+    // DG on boundary: L has a face that contains K
+    hat_K = _tilde_L;
+  }
   // grad(u) = DF^{-T}*hat_grad(hat_u)
   _grad_basis_evaluate_init (hat_K, q, value.size());
   size_type       d =  _dom.dimension();
@@ -311,10 +367,16 @@ test_rep<T,M>::_grad_basis_evaluate (const reference_element& hat_K, size_type q
     value[loc_idof] = invDF.trans_mult (_basis_on_quad.grad_value (loc_idof));
   }
 }
+// grad(vector) -> tensor
 template <class T, class M>
 void
-test_rep<T,M>::_grad_basis_evaluate (const reference_element& hat_K, size_type q, const details::grad_option_type& opt, std::vector<tensor_basic<T> >& value) const
+test_rep<T,M>::_grad_basis_evaluate (const reference_element& hat_K_in, size_type q, const details::grad_option_type& opt, std::vector<tensor_basic<T> >& value) const
 {
+  reference_element hat_K = hat_K_in;
+  if (_have_dg_on_sides && hat_K.dimension() != _dom.map_dimension()) {
+    // DG on boundary: L has a face that contains K
+    hat_K = _tilde_L;
+  }
   _grad_basis_evaluate_init (hat_K, q, value.size());
   size_type       d = _dom.dimension();
   size_type K_map_d = hat_K.dimension();
@@ -404,6 +466,55 @@ test_rep<T,M>::_grad_basis_evaluate (const reference_element& hat_K, size_type q
     value[loc_idof](i_comp_theta, i_comp_theta) = phi/r;
   }
 }
+// grad(tensor) -> tensor3
+template <class T, class M>
+void
+test_rep<T,M>::_grad_basis_evaluate (const reference_element& hat_K_in, size_type q, const details::grad_option_type& opt, std::vector<tensor3_basic<T> >& value) const
+{
+  reference_element hat_K = hat_K_in;
+  if (_have_dg_on_sides && hat_K.dimension() != _dom.map_dimension()) {
+    // DG on boundary: L has a face that contains K
+    hat_K = _tilde_L;
+  }
+  // g(i,j,k) = d sigma(i,j) / d xk
+  _grad_basis_evaluate_init (hat_K, q, value.size());
+  size_type       d = _dom.dimension();
+  size_type K_map_d = hat_K.dimension();
+  check_macro (!_is_on_band,  "grad(tensor): band not yet supported");
+  check_macro (!opt.surfacic, "grad(tensor): surfacic not yet supported");
+  _basis_on_quad.evaluate_grad (hat_K, q);
+  tensor_basic<float_type> DF;
+  jacobian_piola_transformation (_dom, _piola_on_quad, hat_K, _dis_inod_K, q, DF);
+  tensor_basic<float_type> invDF = pseudo_inverse_jacobian_piola_transformation (DF, d, K_map_d);
+  //
+  // then fill the value[loc_idoc](i,j,k) array
+  fill (value.begin(), value.end(), tensor3_basic<T>()); // do not remove !
+  size_type n_comp = get_vf_space().size();
+  size_type loc_comp_ndof = value.size() / n_comp;
+  space_constant::valued_type valued_tag = get_vf_space().valued_tag();
+  space_constant::coordinate_type sys_coord = _dom.coordinate_system();
+  bool do_symmetry = (valued_tag != space_constant::unsymmetric_tensor);
+  for (size_type loc_comp_idof = 0; loc_comp_idof < loc_comp_ndof; ++loc_comp_idof) {
+    // grad(phi) = DF^{-T}*grad_hat_phi
+    point_basic<T> grad_phi = invDF.trans_mult (_basis_on_quad.grad_value (loc_comp_idof));
+    for (size_type ij_comp = 0; ij_comp < n_comp; ++ij_comp) {
+      size_type loc_idof = ij_comp*loc_comp_ndof + loc_comp_idof;
+      std::pair<size_type,size_type> ij = space_constant::tensor_subscript (space_constant::tensor, sys_coord, ij_comp);
+      for (size_type k_comp = 0; k_comp < n_comp; ++k_comp) {
+        value[loc_idof](ij.first, ij.second, k_comp) = grad_phi [k_comp];
+        if (do_symmetry && ij.first != ij.second) {
+          value[loc_idof](ij.second, ij.first, k_comp) = grad_phi [k_comp];
+        }
+      }
+    }
+  }
+}
+template <class T, class M>
+void
+test_rep<T,M>::_grad_basis_evaluate (const reference_element& hat_K_in, size_type q, const details::grad_option_type& opt, std::vector<tensor4_basic<T> >& value) const
+{
+  fatal_macro ("grad_basis_evaluate: tensor4, not yet");
+}
 // ----------------------------------------------    
 // div basis
 // ----------------------------------------------    
