@@ -43,4 +43,16 @@ for geo in $L; do
   if test $? -ne 0; then status=1; fi
 done
 
+# ----------------------------------------------------
+# with vertex domains
+# ----------------------------------------------------
+dmn="${SRCDIR}/square_vertex_dom.dmn"
+L="
+square_t_bamg
+"
+for geo in $L; do
+  run "cat ${SRCDIR}/${geo}.bamg ${dmn} | ${BINDIR}/geo -if bamg -geo - 2>/dev/null | diff -Bw ${SRCDIR}/${geo}_vertex_dom.geo - >/dev/null"
+  if test $? -ne 0; then status=1; fi
+done
+
 exit $status
