@@ -21,20 +21,43 @@
 # -------------------------------------------------------------------------
 SRCDIR=${SRCDIR-"."}
 TOP_SRCDIR=${TOP_SRCDIR-"../.."}
-NPROC_MAX=${NPROC_MAX-"7"}
+NPROC_MAX=${NPROC_MAX-"8"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
 
+# ---------------------------------
+# block all sides
+# ---------------------------------
 L="
+carre-tq-10-dom-v2
 line-dom-v2
-carre-100-dom-v2
-cube-10-dom-v2
+carre-bamg-v2
+carre-q-10-dom-v2
+cube-dom-v2
+cube-H-6-dom-v2
+cube-P-5-dom-v2
+my_cube_TP-5-v2
+my_cube_PH-5-v2
+my_cube_TPH-5-v2
 "
-
 for geo in $L; do
-  loop_mpirun "./field_blocked_tst ${SRCDIR}/$geo 1e-10 2>/dev/null | diff -w -B ${SRCDIR}/interpolate-$geo-P1.field - >/dev/null"
+ for Pk in P1 P2 P3; do
+  loop_mpirun "./field_blocked_tst ${SRCDIR}/$geo $Pk 1e-10 2>/dev/null | diff -w -B ${SRCDIR}/interpolate-$geo-$Pk.field - >/dev/null"
   if test $? -ne 0; then status=1; fi
+ done
+done
+# ---------------------------------
+# block "boundary"
+# ---------------------------------
+L="
+circle_p3-v2
+"
+for geo in $L; do
+ for Pk in P1 P2 P3; do
+  loop_mpirun "./field_blocked_tst ${SRCDIR}/$geo $Pk 1e-10 boundary 2>/dev/null | diff -w -B ${SRCDIR}/interpolate-$geo-$Pk.field - >/dev/null"
+  if test $? -ne 0; then status=1; fi
+ done
 done
 
 exit $status
