@@ -24,23 +24,44 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"8"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-#echo "      (not yet)"
-#exit 0
-
 status=0
 
+# --------------------------
+# domain "right"
+# --------------------------
 L="
 line-dom-v2
-carre-100-dom-v2
 carre-bamg-v2
+carre-bamg-q-dom-v2
+carre-q-10-dom-v2
+carre-tq-10-dom-v2
 cube-10-dom-v2
-cube-gmsh-v2
+cube-H-6-dom-v2
+cube-P-5-dom-v2
+my_cube_PH-5-v2
+my_cube_TP-5-v2
+my_cube_TPH-5-v2
 "
 for geo in $L; do
-  for Pk in P1 P0; do
+  for Pk in P1 P2 P3 P0 P1d; do
     loop_mpirun "./field_dom_io_tst ${SRCDIR}/$geo $Pk right 1e-10 < ${SRCDIR}/interpolate_dom-$geo-right-$Pk.field 2>/dev/null | diff -w -B ${SRCDIR}/interpolate_dom-$geo-right-$Pk.field - >/dev/null"
     if test $? -ne 0; then status=1; fi
   done
 done
+# --------------------------
+# domain "boundary"
+# --------------------------
+L="
+circle_p3-v2
+circle_p5-v2
+sphere_p2-v2
+sphere_p3-v2
+"
+for geo in $L; do
+  for Pk in P1 P2 P3 P0 P1d; do
+    loop_mpirun "./field_dom_io_tst ${SRCDIR}/$geo $Pk boundary 1e-10 < ${SRCDIR}/interpolate_dom-$geo-boundary-$Pk.field 2>/dev/null | diff -w -B ${SRCDIR}/interpolate_dom-$geo-boundary-$Pk.field - >/dev/null"
+    if test $? -ne 0; then status=1; fi
+  done
+done
 
 exit $status
