@@ -29,12 +29,20 @@ status=0
 L="
 line-dom-v2
 carre-bamg-v2
-cube-gmsh-v2
+carre-bamg-q-dom-v2
+carre-q-10-dom-v2
+cube-10-dom-v2
+cube-H-6-dom-v2
+cube-P-5-dom-v2
+my_cube_PH-5-v2
+my_cube_TP-5-v2
+my_cube_TPH-5-v2
 "
-
 for geo in $L; do
-  loop_mpirun "./field_expr2_tst ${SRCDIR}/$geo right 2>/dev/null | diff interpolate_dom-$geo-right-P1.field - >/dev/null"
+ for Pk in P1 P2 P3; do
+  loop_mpirun "./field_expr2_tst ${SRCDIR}/$geo $Pk right 2>/dev/null | diff interpolate_dom-$geo-right-$Pk.field - >/dev/null"
   if test $? -ne 0; then status=1; fi
+ done
 done
 
 exit $status
