@@ -20,7 +20,6 @@
 /// =========================================================================
 // check field_indirect::const_iterator
 #include "rheolef.h"
-#include "rheolef/rounder.h"
 using namespace rheolef;
 using namespace std;
 Float g (const point& x) { return sin(x[0]+x[1]+0.5); }
@@ -35,5 +34,5 @@ int main(int argc, char**argv) {
   field gh = interpolate(Wh, g);
   field zh (Wh);
   zh = -0.5*(-gh/2.0 - gh/2 - fh[dom_name]); // check for field_indirect<T,M>, without const
-  dout << setprecision(15) << field(compose (rounder(prec),zh));
+  dout << round (zh, prec);
 }
