@@ -29,7 +29,14 @@ status=0
 L="
 line-dom-v2
 carre-bamg-v2
-cube-gmsh-v2
+carre-bamg-q-dom-v2
+carre-q-10-dom-v2
+cube-10-dom-v2
+cube-H-6-dom-v2
+cube-P-5-dom-v2
+my_cube_PH-5-v2
+my_cube_TP-5-v2
+my_cube_TPH-5-v2
 "
 
 for geo in $L; do
