@@ -20,13 +20,16 @@
 /// =========================================================================
 // check compose(f,field_expr) for f as a true function
 #include "rheolef.h"
-#include "rheolef/rounder.h"
 using namespace rheolef;
 using namespace std;
 Float g  (const point& x) { return sin(x[0]+x[1]+0.5); }
 Float f  (const Float& u) { return u*(1-u); }
+#ifdef TODO
 Float h  (const Float& u, Float v) { return v*(1-u); }
-
+#endif // TODO
+struct h : std::binary_function<Float,Float,Float> {
+  Float operator() (const Float& u, const Float& v) const { return v*(1-u); }
+};
 int main(int argc, char**argv) {
   environment rheolef(argc, argv);
   geo omega (argv[1]); 
@@ -36,7 +39,6 @@ int main(int argc, char**argv) {
   space Wh (omega[dom_name], "P1");
   field fh = interpolate(Vh, g);
   field gh = interpolate(Wh, g);
-  field zh (Wh);
-  zh = atan2(gh,fh[dom_name]/2) + max(abs(fh[dom_name]), 0) + compose(h, fh[dom_name]+2, 0);
-  dout << setprecision(15) << field(compose (rounder(prec),zh));
+  field zh = interpolate (Wh, atan2(gh,fh[dom_name]/2) + max(abs(fh[dom_name]), 0) + compose(h(), fh[dom_name]+2, 0));
+  dout << round (zh, prec);
 }
