@@ -20,7 +20,6 @@
 /// =========================================================================
 // check += /= on field and field_indirect
 #include "rheolef.h"
-#include "rheolef/rounder.h"
 using namespace rheolef;
 using namespace std;
 Float g  (const point& x) { return sin(x[0]+x[1]+0.5); }
@@ -37,5 +36,5 @@ int main(int argc, char**argv) {
   fh[dom_name] += gh;
   gh += fh[dom_name];
   gh /= 2;
-  dout << setprecision(15) << field(compose (rounder(prec),gh));
+  dout << round (gh, prec);
 }
