@@ -76,12 +76,12 @@ int main(int argc, char**argv) {
     check_subscript_access (x+y);
 
     // dot with expression (lazy evaluation)
-    dout << "dot(x, 1) = " << dot(x, 1) << endl;
-    dout << "dot(2*x-y, 1) = " << dot(2*x-y, 1) << endl;
-    dout << "dot(x, z) = " << dot(x, z) << endl;
-    dout << "dot(x, 2*x-y) = " << dot(x, 2*x - y) << endl;
-    dout << "dot(2*x-y, x) = " << dot(2*x-y, x) << endl;
-    dout << "dot(3*x-y, 2*x-y) = " << dot(3*x-y, 2*x-y) << endl;
+    dout << "dot(x, 1) = " << dual(x, 1) << endl;
+    dout << "dot(2*x-y, 1) = " << dual(2*x-y, 1) << endl;
+    dout << "dot(x, z) = " << dual(x, z) << endl;
+    dout << "dot(x, 2*x-y) = " << dual(x, 2*x - y) << endl;
+    dout << "dot(2*x-y, x) = " << dual(2*x-y, x) << endl;
+    dout << "dot(3*x-y, 2*x-y) = " << dual(3*x-y, 2*x-y) << endl;
 
 #ifdef TO_CLEAN
     // set bad size and then assign: it may exit(1)
