@@ -20,7 +20,6 @@
 /// =========================================================================
 // check field_indirect with field rhs
 #include "rheolef.h"
-#include "rheolef/rounder.h"
 using namespace rheolef;
 using namespace std;
 size_t N;
@@ -39,5 +38,5 @@ int main(int argc, char**argv) {
   field fh = interpolate(Vh, f);
   field gh = interpolate(Wh, g);
   fh[dom_name] = gh;
-  dout << setprecision(15) << field(compose(rounder(prec),fh));
+  dout  << round (fh, prec);
 }
