@@ -24,21 +24,27 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"8"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-#echo "      (not yet)"
-#exit 0
-
-status=0
-
 L="
 line-dom-v2
-carre-100-dom-v2
 carre-bamg-v2
+carre-bamg-q-dom-v2
+carre-q-10-dom-v2
 cube-10-dom-v2
-cube-gmsh-v2
+cube-H-6-dom-v2
+cube-P-5-dom-v2
+my_cube_PH-5-v2
+my_cube_TP-5-v2
+my_cube_TPH-5-v2
 "
+
+tmp="/tmp/tmp$$.field"
+
 for geo in $L; do
-  loop_mpirun "./field_indirect3_tst ${SRCDIR}/$geo right 1e-10 2>/dev/null | diff -w -B ${SRCDIR}/interpolate_dom-$geo-right-P1.field - >/dev/null"
+ for Pk in P1 P2 P3; do
+  loop_mpirun "./field_indirect3_tst ${SRCDIR}/$geo $Pk right 1e-10 2>/dev/null > $tmp && diff -w -B ${SRCDIR}/interpolate_dom-$geo-right-$Pk.field $tmp >/dev/null"
   if test $? -ne 0; then status=1; fi
+ done
 done
+run "rm -f $tmp"
 
 exit $status
