@@ -13,6 +13,6 @@ int main (int argc, char**argv) {
   Bh.unblock ("zero");
   // it was a bug when a geo_domain was used as a domain:
   field phi_h_band = phi_h [gh.band()];
-  gh.band().save();
-  dout << phi_h_band;
+  dout << catchmark("phi")      << phi_h
+       << catchmark("phi_band") << phi_h_band;
 }
