@@ -29,10 +29,21 @@ status=0
 L="
 line-dom-v2
 carre-bamg-v2
-cube-gmsh-v2
+carre-bamg-q-dom-v2
+carre-tq-10-dom-v2
+cube-dom-v2
+cube-H-6-dom-v2
+cube-P-5-dom-v2
+my_cube_TP-5-v2
+my_cube_PH-5-v2
+my_cube_TPH-5-v2
 "
+
 for geo in $L; do
-  loop_mpirun "./field_indirect_tst ${SRCDIR}/$geo.geo 2>/dev/null | diff $SRCDIR/field_indirect-$geo-P1.field - >/dev/null"
+ for Pk in P1 P2 P3; do
+  loop_mpirun "./field_indirect_tst ${SRCDIR}/$geo.geo $Pk left 1e-8 2>/dev/null | diff $SRCDIR/field_indirect-$geo-$Pk.field - >/dev/null"
   if test $? -ne 0; then status=1; fi
+ done
 done
+
 exit $status
