@@ -19,7 +19,6 @@
 ///
 /// =========================================================================
 #include "rheolef.h"
-#include "rheolef/rounder.h"
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
@@ -31,5 +30,5 @@ int main(int argc, char**argv) {
   Float prec = (argc > 3) ? atof(argv[3]) : 1e-10;
   field uh (Vh, 0);
   uh.set_b() = 1;
-  dout << setprecision(15) << field(compose(rounder(prec),uh));
+  dout << round (uh, prec);
 }
