@@ -298,7 +298,7 @@ int main(int argc, char**argv)
     // ---------------------------------------------------
     // first check : compute boundary area with i-th weight
     // ---------------------------------------------------
-    Float mes_gamma_1 = dot(one, m_h*weight_h);
+    Float mes_gamma_1 = dual(one, m_h*weight_h);
     cout << "mes1(gamma) = " << double(mes_gamma_1) << endl;
     // ---------------------------------------------------
     // 2nd check : use trace
@@ -327,13 +327,13 @@ int main(int argc, char**argv)
         //
         // compute boundary area with i-th weight
         //
-        Float mes_gamma_2 = dot(one_bdr, m_gamma_h*weight_bdr);
+        Float mes_gamma_2 = dual(one_bdr, m_gamma_h*weight_bdr);
         cout << "mes2(gamma) = " << double(mes_gamma_2) << endl;
         // ---------------------------------------------------
         // 3nd check : compare two results
         // ---------------------------------------------------
         if (fabs(mes_gamma_1-mes_gamma_2) > sqrt(epsilon)) {
-          derr << "boundary mass problem detected." << endl;
+          derr << "mes1(gamma) != mes2(gamma): boundary mass problem detected." << endl;
           status = 1;
         }
     }
