@@ -22,9 +22,9 @@
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
-  environment distributed(argc, argv);
+  environment rheolef(argc, argv);
   geo omega (argv[1]);
   string dom_name = (argc > 2) ? argv[2] : "right";
   geo gamma = compact (omega[dom_name]);
-  dcout << gamma;
+  dout << gamma;
 }
