@@ -21,21 +21,44 @@
 # -------------------------------------------------------------------------
 SRCDIR=${SRCDIR-"."}
 TOP_SRCDIR=${TOP_SRCDIR-"../.."}
-NPROC_MAX=${NPROC_MAX-"7"}
+NPROC_MAX=${NPROC_MAX-"8"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
+# ----------------------------
+# domain right
+# ----------------------------
 L="
 line-dom-v2
 carre-100-dom-v2
 carre-bamg-v2
+carre-q-10-dom-v2
+carre-bamg-q-dom-v2
+carre-tq-10-dom-v2
 cube-10-dom-v2
 cube-gmsh-v2
-"
-L_TODO="
+cube-H-6-dom-v2
+cube-P-5-dom-v2
+my_cube_PH-5-v2
+my_cube_TP-5-v2
+my_cube_TPH-5-v2
 "
 for geo in $L; do
   loop_mpirun "./geo_domain_tst ${SRCDIR}/$geo.geo right 2>/dev/null | diff -w -B $SRCDIR/$geo.right.geo - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
+# ----------------------------
+# domain boundary
+# ----------------------------
+L="
+circle_p3-v2
+circle_p5-v2
+sphere_p2-v2
+sphere_p3-v2
+"
+for geo in $L; do
+  loop_mpirun "./geo_domain_tst ${SRCDIR}/$geo.geo boundary 2>/dev/null | diff -w -B $SRCDIR/$geo.boundary.geo - >/dev/null"
+  if test $? -ne 0; then status=1; fi
+done
+
 exit $status
