@@ -31,7 +31,7 @@ carre-100-dom-v2
 cube-10-dom-v2
 "
 for geo in $L; do
-  loop_mpirun "./geo_file_tst ${SRCDIR}/$geo.geo 2>/dev/null | diff $SRCDIR/$geo.geo - >/dev/null"
+  loop_mpirun "./geo_file_tst ${SRCDIR}/$geo.geo 2>/dev/null | diff -B -w $SRCDIR/$geo.geo - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 exit $status
