@@ -25,50 +25,41 @@ DATA_DIR="${TOP_SRCDIR}/nfem/data"
 NPROC_MAX=${NPROC_MAX-"7"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-ZDIFF="$TOP_SRCDIR/config/zdiff"
-
 status=0
 
 L="
+zero-5.geo
+line-1-bdry.geo
+line-2-bdry.geo
+line-3-bdry.geo
+line-20-bdry.geo
 carre-v1.geo
 carre-v2.geo
-bielle-v2.geo
 line-dom-v2.geo
 carre-dom-v2.geo
 cube-dom-v2.geo
+cube-H-6-dom-v2.geo
+circle_s_p1-v2.geo
+circle_s_p2-v2.geo
+circle_p1-v2.geo
+circle_p2-v2.geo
+circle_q_p1-v2.geo
+circle_q_p2-v2.geo
+sphere_s_p1-v2.geo
+sphere_s_p2-v2.geo
+sphere_s_q_p1-v2.geo
+sphere_s_q_p2-v2.geo
+sphere_p1-v2.geo
+sphere_p2-v2.geo
+sphere_H_p1-v2.geo
+sphere_H_p2-v2.geo
+cube-P-5-dom-v2.geo
 carre-tq-10-dom-v2.geo
-extrude-TP-gmsh-dom-v2.geo
 "
+
 for geo in $L; do
   run "./geo_seq_tst ${SRCDIR}/$geo 2>/dev/null | diff -B -w ${SRCDIR}/$geo - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
-
-L="
-line-dom
-carre-dom
-cube-dom
-carre-tq-10-dom
-extrude-TP-gmsh-dom
-"
-for geo in $L; do
-  run "./geo_seq_tst ${SRCDIR}/$geo-v1.geo 2>/dev/null | diff -B -w ${SRCDIR}/$geo-v2.geo - >/dev/null"
-  if test $? -ne 0; then status=1; fi
-done
-
-
-L="
-tetra2.geo.gz
-dodecaedre00.geo.gz
-dodecaedre01.geo.gz
-particule.geo.gz
-bielle.geo.gz
-"
-
-for geo in $L; do
-  run "./geo_seq_tst $DATA_DIR/$geo 2>/dev/null | $ZDIFF -B -w $DATA_DIR/$geo - >/dev/null"
-  if test $? -ne 0; then status=1; fi
-done
-run "rm -f tmp.geo"
 exit $status
