@@ -29,18 +29,45 @@ NPROC_MAX=${NPROC_MAX-"8"}
 
 status=0
 
+tmp="/tmp/tmp$$.field"
+
+#-------------------
+# domain "right"
+#-------------------
 L="
 line-dom-v2
-carre-100-dom-v2
 carre-bamg-v2
+carre-bamg-q-dom-v2
+carre-q-10-dom-v2
 cube-10-dom-v2
-cube-gmsh-v2
+cube-H-6-dom-v2
+cube-P-5-dom-v2
+my_cube_PH-5-v2
+my_cube_TP-5-v2
+my_cube_TPH-5-v2
 "
 for geo in $L; do
-  for Pk in P1 P0 P1d; do
-    loop_mpirun "./interpolate_dom_tst ${SRCDIR}/$geo $Pk right 1e-10 2>/dev/null | diff -w -B ${SRCDIR}/interpolate_dom-$geo-right-$Pk.field - >/dev/null"
+  for Pk in P1 P2 P3 P0 P1d; do
+    loop_mpirun "./interpolate_dom_tst ${SRCDIR}/$geo $Pk right 1e-10 2>/dev/null > $tmp && diff -w -B ${SRCDIR}/interpolate_dom-$geo-right-$Pk.field $tmp >/dev/null"
+    if test $? -ne 0; then status=1; fi
+  done
+done
+#-------------------
+# domain "boundary"
+#-------------------
+L="
+circle_p3-v2
+circle_p5-v2
+sphere_p2-v2
+sphere_p3-v2
+"
+for geo in $L; do
+  for Pk in P1 P2 P3 P0 P1d; do
+    loop_mpirun "./interpolate_dom_tst ${SRCDIR}/$geo $Pk boundary 1e-10 2>/dev/null > $tmp && diff -w -B ${SRCDIR}/interpolate_dom-$geo-boundary-$Pk.field $tmp >/dev/null"
     if test $? -ne 0; then status=1; fi
   done
 done
 
+run "rm -f $tmp"
+
 exit $status
