@@ -21,19 +21,26 @@
 # -------------------------------------------------------------------------
 SRCDIR=${SRCDIR-"."}
 TOP_SRCDIR=${TOP_SRCDIR-"../.."}
-NPROC_MAX=${NPROC_MAX-"7"}
+NPROC_MAX=${NPROC_MAX-"8"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
 
 L="
 line-dom-v2
-carre-100-dom-v2
-cube-10-dom-v2
+carre-bamg-v2
+carre-q-10-dom-v2
+carre-tq-10-dom-v2
+cube-dom-v2
+cube-H-6-dom-v2
+cube-P-5-dom-v2
+my_cube_TP-5-v2
+my_cube_PH-5-v2
+my_cube_TPH-5-v2
+circle_p3-v2
 "
-
 for geo in $L; do
-  for Pk in P1 P0 P1d; do
+  for Pk in P1 P2 P3 P0 P1d; do
     loop_mpirun "./interpolate_tst ${SRCDIR}/$geo $Pk 1e-10 2>/dev/null | diff -w -B ${SRCDIR}/interpolate-$geo-$Pk.field - >/dev/null"
     if test $? -ne 0; then status=1; fi
   done
