@@ -27,26 +27,27 @@ NPROC_MAX=${NPROC_MAX-"7"}
 status=0
 
 L="
+zero-5
 line-dom-v2
-carre-100-dom-v2
+carre-10-bdry-v2
 carre-q-10-dom-v2
-cube-10-dom-v2
-cube-P-5-dom-v2
-cube-H-5-dom-v2
-"
-for geo in $L; do
-  for Pk in P1 P0 P1d; do
-    loop_mpirun "./space_tst ${SRCDIR}/$geo.geo $Pk 2>/dev/null >/dev/null"
-    if test $? -ne 0; then status=1; fi
-  done
-done
-
-L="
 carre-tq-10-dom-v2
-extrude-TP-gmsh-dom-v2
+cube-dom-v2
+cube-H-6-dom-v2
+cube-P-5-dom-v2
+my_cube_PH-5-v2
+my_cube_TP-5-v2
+my_cube_TPH-5-v2
+circle_p2-v2
+circle_p5-v2
+circle_tq_p10-v2
+"
+#TODO P9(T)
+L_HIGH="
+sphere_p9-v2
 "
 for geo in $L; do
-  for Pk in P1 P0; do
+  for Pk in P0 P1 P2 P1d P3; do
     loop_mpirun "./space_tst ${SRCDIR}/$geo.geo $Pk 2>/dev/null >/dev/null"
     if test $? -ne 0; then status=1; fi
   done
