@@ -23,7 +23,7 @@ SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}
 
 status=0
 
-command="../bin/mkgeo_grid_3d 5 > box-5.geo"
+command="../sbin/mkgeo_grid_3d 5 > box-5.geo"
 echo "      $command"
 eval        $command
 command="./find_close_vertex_tst box-5.geo 1.2 0.6 0.7 -noplot"
