@@ -20,27 +20,19 @@
 #
 # -------------------------------------------------------------------------
 SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}
-
-export RHEOLEF_BASIS_PATH=${RHEOLEF_BASIS_PATH-"../basis"}
-export RHEOLEF_NUMBERING_PATH=${RHEOLEF_NUMBERING_PATH-"../basis"}
-export RHEOLEF_FORM_ELEMENT_PATH=${RHEOLEF_FORM_ELEMENT_PATH-"../form_element"}
-#HAVE_LU_SOLVER=${HAVE_LU_SOLVER-"yes"}
-if test x"${HAVE_LU_SOLVER}" = x""; then
-    echo "        => skipped since UMFPACK is not available: no sparse LU factorization"
-    exit 0
-fi
+TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+DATA_DIR="${TOP_SRCDIR}/nfem/data"
+NPROC_MAX=${NPROC_MAX-"1"}
+. "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
 
-command="../bin/mkgeo_grid_2d -t 50 5 -a 0 -b 10 -c 0 -d 1 > tmp.geo"
-echo "      $command"
-eval $command 2>/dev/null
+run "../sbin/mkgeo_grid_2d -t 50 5 -a 0 -b 10 -c 0 -d 1 > tmp.geo 2>/dev/null"
 
-command="./form_convect_dg_nh_tst tmp.geo 50"
-echo "      $command"
-eval $command >/dev/null 2>/dev/null
+run "./form_convect_dg_nh_tst tmp.geo 50 >/dev/null 2>/dev/null"
 if test $? -ne 0; then status=1; echo "        => *NO*"; fi
 
-/bin/rm -f tmp.geo
+run "/bin/rm -f tmp.geo"
+
 exit ${status}
 
