@@ -134,10 +134,7 @@ These cases are specified by using some suitable command-line options.
 	Round the output, in order for the non-regression tests to
 	be portable across platforms. Floating point are machine-dependent.
 @end table
-AUTHOR: 
-  LMC-IMAG, 38041 Grenoble cedex 9, France
-  @email{Nicolas.Roquet@@imag.fr}
-  @email{Pierre.Saramito@@imag.fr}
+AUTHOR: Pierre.Saramito@@imag.fr
 End:
 */
 
