@@ -452,6 +452,7 @@ def build_isovalue_table (fmin, fmax, option):
 
 def mayavi2_field_scalar (view, basename, option):
 
+    print "ici scalaire..."
     scene = start_new_scene (view, option)
 
     data = VTKFileReader()
@@ -555,7 +556,9 @@ def mayavi2_field_scalar (view, basename, option):
         if option['approx'] != "P0" and not option['view_map']:
             mm.scalar_lut_manager.number_of_colors = option['n_isovalue']
             mm.scalar_lut_manager.number_of_labels = option['n_isovalue']+1
+        print "ici 2D..."
         if option['elevation']:
+            print "ici 2D elevation..."
 	    if (f_max-f_min > 0):
                 scale = 0.5*numpy.sqrt((x_max-x_min)**2+(y_max-y_min)**2)/(f_max - f_min)
 	    else:
@@ -564,6 +567,13 @@ def mayavi2_field_scalar (view, basename, option):
             elevation.filter.scale_factor = scale
  	    option['ranges'] = (x_min, x_max, y_min, y_max, f_min, f_max)
             elevation.render()
+            # add black lines, usefull when stereo rending
+            iso_surface = IsoSurface()
+	    iso_surface.contour.auto_contours = True
+	    iso_surface.contour.number_of_contours = option['n_isovalue']
+ 	    iso_surface.actor.mapper.scalar_visibility = False
+ 	    iso_surface.actor.property.line_width = 3
+            view.add_module(iso_surface)
         if option['cut']:
             scalar_cut_plane = ScalarCutPlane()
             scalar_cut_plane.implicit_plane.widget.outline_translation = False
@@ -647,11 +657,11 @@ def mayavi2_field_scalar (view, basename, option):
     #print "mm.scalar_lut_manager = ", mm.scalar_lut_manager
     if not option['view_1d'] and option['color'] != 'black_and_white' and mm != None:
         mm.scalar_lut_manager.show_scalar_bar = True
-        if option['label'] != "output" and (option['name'] != "scalars" and option['name'] != "unamed"):
+        if option['label'] != "output" and (option['name'] != "scalars" and option['name'] != "scalar" and option['name'] != "unamed"):
             title = option['name'] + ": " + option['label']
         elif option['label'] != "output":
             title = option['label']
-        elif (option['name'] != "scalars" and option['name'] != "unamed"):
+        elif (option['name'] != "scalars" and option['name'] != "scalar" and option['name'] != "unamed"):
             title = option['name']
         else:
             title = ""
