@@ -24,7 +24,7 @@
 // basic include file for skit implementation
 //
 # include "rheolef/compiler.h" /* compiler dependent part */
-# include "rheolef/occurence.h"     /* shallow copies and ref counting */
+# include "rheolef/smart_pointer.h"     /* shallow copies and ref counting */
 # include "rheolef/classes.h"       /* skit class defs */
 
 # include "rheolef/macros.h"        /* TODO: may disapear with numerics_limits<T> */
