@@ -1,5 +1,5 @@
-# ifndef _RHEO_CSR_H
-# define _RHEO_CSR_H
+# ifndef _RHEOLEF_CSR_H
+# define _RHEOLEF_CSR_H
 ///
 /// This file is part of Rheolef.
 ///
@@ -25,13 +25,19 @@
 #include "rheolef/asr.h"
 #include "rheolef/vector_of_iterator.h"
 #include "rheolef/scatter_message.h"
+#include "rheolef/pair_util.h"
+
+#include <boost/bind.hpp>
+
 namespace rheolef {
 
 // -------------------------------------------------------------
 // the sequential representation
 // -------------------------------------------------------------
+template<class T, class M> class csr_rep {};
+
 template<class T>
-class csr_seq_rep : public vector_of_iterator<std::pair<typename std::vector<T>::size_type,T> > {
+class csr_rep<T,sequential> : public vector_of_iterator<std::pair<typename std::vector<T>::size_type,T> > {
 public:
     typedef typename std::vector<T>::size_type                            size_type;
     typedef T                                                             element_type;
@@ -43,13 +49,14 @@ public:
     typedef typename vector_of_iterator<pair_type>::value_type            data_iterator;
     typedef typename vector_of_iterator<pair_type>::const_value_type      const_data_iterator;
 
-    csr_seq_rep (size_type loc_nrow1 = 0, size_type loc_ncol1 = 0, size_type loc_nnz1 = 0);
+    csr_rep (size_type loc_nrow1 = 0, size_type loc_ncol1 = 0, size_type loc_nnz1 = 0);
     void resize (size_type loc_nrow1 = 0, size_type loc_ncol1 = 0, size_type loc_nnz1 = 0);
-    csr_seq_rep (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1 = 0);
+    csr_rep (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1 = 0);
     void resize (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1 = 0);
-    csr_seq_rep (const csr_seq_rep<T>& a);
-    explicit csr_seq_rep (const asr_seq_rep<T>& a);
-    void to_asr (asr_seq_rep<T>& b) const;
+    csr_rep (const csr_rep<T,sequential>& a);
+    template<class A> void build_from_asr (const asr<T,sequential,A>& a);
+    template<class A> explicit csr_rep    (const asr<T,sequential,A>& a);
+    template<class A> void build_from_diag (const array_rep<T,sequential,A>& d);
 
     const distributor& row_ownership() const { return _row_ownership; }
     const distributor& col_ownership() const { return _col_ownership; }
@@ -63,73 +70,113 @@ public:
     size_type dis_nrow() const { return nrow(); }
     size_type dis_ncol() const { return ncol(); }
     size_type dis_nnz() const { return nnz(); }
+    T max_abs () const;
     bool is_symmetric() const { return _is_symmetric; }
-    void set_symmetry (bool is_symm) { _is_symmetric = is_symm; }
+    void set_symmetry (bool is_symm) const { _is_symmetric = is_symm; }
+    void set_symmetry_by_check (const T& tol = std::numeric_limits<T>::epsilon()) const;
     size_type pattern_dimension() const { return _pattern_dimension; }
-    void set_pattern_dimension(size_type dim) { _pattern_dimension = dim; }
+    void set_pattern_dimension(size_type dim) const { _pattern_dimension = dim; }
     size_type row_first_index () const { return 0; }
     size_type row_last_index () const { return nrow(); }
     size_type col_first_index () const { return 0; }
     size_type col_last_index () const { return ncol(); }
-    size_type ext_nnz() const { return 0; }
     idiststream& get (idiststream&);
     odiststream& put (odiststream&, size_type istart = 0) const;
+    odiststream& put_matrix_market (odiststream&, size_type istart = 0) const;
+    odiststream& put_sparse_matlab (odiststream&, size_type istart = 0) const;
     void dump (const std::string& name, size_type istart = 0) const;
     void mult       (const vec<T,sequential>& x, vec<T,sequential>& y) const;
     void trans_mult (const vec<T,sequential>& x, vec<T,sequential>& y) const;
-    csr_seq_rep<T>& operator*= (const T& lambda);
+    csr_rep<T,sequential>& operator*= (const T& lambda);
     template <class BinaryOp>
-    void assign_add (const csr_seq_rep<T>& a, const csr_seq_rep<T>& b, BinaryOp binop);
-    void build_transpose (csr_seq_rep<T>& b) const;
+    void assign_add (const csr_rep<T,sequential>& a, const csr_rep<T,sequential>& b, BinaryOp binop);
+    void build_transpose (csr_rep<T,sequential>& b) const;
+    void assign_mult (const csr_rep<T,sequential>& a, const csr_rep<T,sequential>& b);
+
+    // accessors, only for distributed (for interface compatibility)
+    size_type ext_nnz() const                { return 0; }
+    size_type dis_ext_nnz() const            { return 0; }
+    const_iterator ext_begin() const         { return const_iterator(); }
+    const_iterator ext_end()   const         { return const_iterator(); }
+    size_type jext2dis_j (size_type jext) const { return 0; }
+
 //protected:
     distributor          		                          _row_ownership;
     distributor          		                          _col_ownership;
     std::vector<std::pair<typename std::vector<T>::size_type,T> > _data;
-    bool							  _is_symmetric;
-    size_type							  _pattern_dimension; // e.g. FEM 3d-pattern
+    mutable bool						  _is_symmetric;
+    mutable size_type						  _pattern_dimension; // e.g. FEM 3d-pattern
 };
+template<class T>
+template<class A>
+inline
+csr_rep<T,sequential>::csr_rep(const asr<T,sequential,A>& a)
+  : vector_of_iterator<pair_type>(a.nrow()+1),
+   _row_ownership (a.row_ownership()),
+   _col_ownership (a.col_ownership()),
+   _data(a.nnz())
+{
+  build_from_asr (a);
+}
+template<class T>
+inline
+idiststream&
+csr_rep<T,sequential>::get (idiststream& ids)
+{
+  typedef std::allocator<T> A; // TODO: use heap_allocator for asr
+  asr<T,sequential,A> a;
+  a.get(ids);
+  build_from_asr (a);
+  return ids;
+}
 // -------------------------------------------------------------
 // the distributed representation
 // -------------------------------------------------------------
 #ifdef _RHEOLEF_HAVE_MPI
 template<class T>
-class csr_mpi_rep : public csr_seq_rep<T> {
+class csr_rep<T,distributed> : public csr_rep<T,sequential> {
 public:
-    typedef typename csr_seq_rep<T>::size_type           size_type;
-    typedef typename csr_seq_rep<T>::element_type        element_type;
-    typedef distributed                                  memory_type;
-    typedef typename csr_seq_rep<T>::iterator            iterator;
-    typedef typename csr_seq_rep<T>::const_iterator      const_iterator;
-    typedef typename csr_seq_rep<T>::data_iterator       data_iterator;
-    typedef typename csr_seq_rep<T>::const_data_iterator const_data_iterator;
+    typedef csr_rep<T,sequential>              base;
+    typedef distributed                        memory_type;
+    typedef typename base::size_type           size_type;
+    typedef typename base::element_type        element_type;
+    typedef typename base::iterator            iterator;
+    typedef typename base::const_iterator      const_iterator;
+    typedef typename base::data_iterator       data_iterator;
+    typedef typename base::const_data_iterator const_data_iterator;
 
-    csr_mpi_rep ();
-    csr_mpi_rep (const csr_mpi_rep<T>& a);
-    explicit csr_mpi_rep (const asr_mpi_rep<T>& a);
-    void build_from_asr (const asr_mpi_rep<T>& a);
-    void to_asr (asr_mpi_rep<T>& b) const;
+    csr_rep ();
+    csr_rep (const csr_rep<T,distributed>& a);
+    template<class A> explicit csr_rep (const asr<T,distributed,A>& a);
+    template<class A> void build_from_asr  (const asr<T,distributed,A>& a);
     void resize (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1 = 0);
+    template<class A> void build_from_diag (const array_rep<T,distributed,A>& d);
 
-    const distributor& row_ownership() const { return csr_seq_rep<T>::_row_ownership; }
-    const distributor& col_ownership() const { return csr_seq_rep<T>::_col_ownership; }
+    const distributor& row_ownership() const { return base::_row_ownership; }
+    const distributor& col_ownership() const { return base::_col_ownership; }
     const communicator& comm() const { return row_ownership().comm(); }
-    const_iterator begin() const { return csr_seq_rep<T>::begin(); }
-    const_iterator end()   const { return csr_seq_rep<T>::end(); }
-          iterator begin()       { return csr_seq_rep<T>::begin(); }
-          iterator end()         { return csr_seq_rep<T>::end(); }
-    size_type      ext_nnz()  const { return _ext.nnz(); }
+    const_iterator begin() const { return base::begin(); }
+    const_iterator end()   const { return base::end(); }
+          iterator begin()       { return base::begin(); }
+          iterator end()         { return base::end(); }
+    size_type      ext_nnz()   const { return _ext.nnz(); }
     const_iterator ext_begin() const { return _ext.begin(); }
     const_iterator ext_end()   const { return _ext.end(); }
-    size_type nrow() const { return csr_seq_rep<T>::nrow(); }
-    size_type ncol() const { return csr_seq_rep<T>::ncol(); }
-    size_type nnz() const { return csr_seq_rep<T>::nnz(); }
+          iterator ext_begin()       { return _ext.begin(); }
+          iterator ext_end()         { return _ext.end(); }
+    size_type nrow() const { return base::nrow(); }
+    size_type ncol() const { return base::ncol(); }
+    size_type nnz() const { return base::nnz(); }
     size_type dis_nrow() const { return row_ownership().dis_size(); }
     size_type dis_ncol() const { return col_ownership().dis_size(); }
-    size_type dis_nnz() const { return _dis_nnz; }
-    bool is_symmetric() const { return csr_seq_rep<T>::is_symmetric(); }
-    void set_symmetry (bool is_symm) { csr_seq_rep<T>::set_symmetry(is_symm); }
-    size_type pattern_dimension() const { return csr_seq_rep<T>::pattern_dimension(); }
-    void set_pattern_dimension(size_type dim) { csr_seq_rep<T>::set_pattern_dimension(dim); }
+    size_type dis_nnz()     const { return _dis_nnz; }
+    size_type dis_ext_nnz() const { return _dis_ext_nnz; }
+    T max_abs () const;
+    bool is_symmetric() const { return base::is_symmetric(); }
+    void set_symmetry (bool is_symm) const { base::set_symmetry(is_symm); }
+    void set_symmetry_by_check (const T& tol = std::numeric_limits<T>::epsilon()) const;
+    size_type pattern_dimension() const { return base::pattern_dimension(); }
+    void set_pattern_dimension(size_type dim) const { base::set_pattern_dimension(dim); }
     size_type row_first_index () const { return row_ownership().first_index(); }
     size_type row_last_index ()  const { return row_ownership().last_index(); }
     size_type col_first_index () const { return col_ownership().first_index(); }
@@ -140,30 +187,68 @@ public:
     void dump (const std::string& name) const;
     void mult       (const vec<T,distributed>& x, vec<T,distributed>& y) const;
     void trans_mult (const vec<T,distributed>& x, vec<T,distributed>& y) const;
-    csr_mpi_rep<T>& operator*= (const T& lambda);
+    csr_rep<T,distributed>& operator*= (const T& lambda);
     template <class BinaryOp>
-    void assign_add (const csr_mpi_rep<T>& a, const csr_mpi_rep<T>& b, BinaryOp binop);
-    void build_transpose (csr_mpi_rep<T>& b) const;
+    void assign_add (const csr_rep<T,distributed>& a, const csr_rep<T,distributed>& b, BinaryOp binop);
+    void build_transpose (csr_rep<T,distributed>& b) const;
+    void assign_mult (const csr_rep<T,distributed>& a, const csr_rep<T,distributed>& b);
 protected:
-    // diagonal part is the basic csr_seq_rep type
+// data:
+    // diagonal part is the basic csr_rep<seq> type
     // extra-diagonal blocs are sequential csr also:
-    csr_seq_rep<T>       		_ext;
-    std::vector<size_type>    		_jext2dis_j;
-    size_type            		_dis_nnz;
+    csr_rep<T,sequential>      		     _ext;
+    std::vector<size_type>    		     _jext2dis_j;
+    size_type            		     _dis_nnz;
+    size_type            		     _dis_ext_nnz;
     
-    // A*x internal stuff: scatter and buffer:
+    // A*x internal stuff: scatter and buffer (lazy initialization):
+    mutable bool                             _scatter_initialized;
     mutable scatter_message<std::vector<T> > _from;
     mutable scatter_message<std::vector<T> > _to;
     mutable std::vector<T>    		     _buffer;
+// internal:
+    void _scatter_init() const;
+    void _scatter_init_guard() const {
+	if (_scatter_initialized) return;
+	_scatter_initialized = true;
+        _scatter_init();
+    }
 };
 template<class T>
 inline
-typename csr_mpi_rep<T>::size_type
-csr_mpi_rep<T>::jext2dis_j (size_type jext)  const
+typename csr_rep<T,distributed>::size_type
+csr_rep<T,distributed>::jext2dis_j (size_type jext)  const
 {
   check_macro (jext < _jext2dis_j.size(), "jext2dis_j: jext="<<jext<<" is out of range [0:"<<_jext2dis_j.size()<<"[");
   return _jext2dis_j [jext];
 }
+template<class T>
+template<class A>
+inline
+csr_rep<T,distributed>::csr_rep(const asr<T,distributed,A>& a)
+  : csr_rep<T,sequential>(),
+    _ext (),
+    _jext2dis_j(),
+    _dis_nnz(0),
+    _dis_ext_nnz(0),
+    _scatter_initialized(false),
+    _from(),
+    _to(),
+    _buffer()
+{
+    build_from_asr (a);
+}
+template<class T>
+inline
+idiststream&
+csr_rep<T,distributed>::get (idiststream& ips)
+{
+    typedef std::allocator<T> A; // TODO: use heap_alloc for asr
+    asr<T,distributed,A> a;
+    a.get (ips);
+    build_from_asr (a);
+    return ips;
+}
 #endif // _RHEOLEF_HAVE_MPI
 
 // these classes are used for allocator from the std::initializer_list
@@ -204,12 +289,12 @@ public:
 };
 //<verbatim:
 template<class T>
-class csr<T,sequential> : public smart_pointer<csr_seq_rep<T> > {
+class csr<T,sequential> : public smart_pointer<csr_rep<T,sequential> > {
 public:
 
 // typedefs:
 
-    typedef csr_seq_rep<T>                    rep;
+    typedef csr_rep<T,sequential>             rep;
     typedef smart_pointer<rep>                base;
     typedef typename rep::memory_type         memory_type;
     typedef typename rep::size_type           size_type;
@@ -222,7 +307,8 @@ public:
 // allocators/deallocators:
 
     csr() : base(new_macro(rep())) {}
-    explicit csr(const asr<T,sequential>& a) : base(new_macro(rep(a.data()))) {}
+    template<class A>
+    explicit csr(const asr<T,sequential,A>& a) : base(new_macro(rep(a))) {}
     void resize (size_type loc_nrow1 = 0, size_type loc_ncol1 = 0, size_type loc_nnz1 = 0)
         { base::data().resize(loc_nrow1, loc_ncol1, loc_nnz1); }
     void resize (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1 = 0)
@@ -243,10 +329,14 @@ public:
     size_type dis_nrow () const              { return row_ownership().dis_size(); }
     size_type dis_ncol () const              { return col_ownership().dis_size(); }
     size_type dis_nnz () const               { return base::data().nnz(); }
+    size_type dis_ext_nnz () const           { return 0; }
     bool is_symmetric() const                { return base::data().is_symmetric(); }
-    void set_symmetry (bool is_symm)         { base::data().set_symmetry(is_symm); }
+    void set_symmetry (bool is_symm) const   { base::data().set_symmetry(is_symm); }
+    void set_symmetry_by_check (const T& tol = std::numeric_limits<T>::epsilon()) const
+                                             { base::data().set_symmetry_by_check(); }
     size_type pattern_dimension() const      { return base::data().pattern_dimension(); }
-    void set_pattern_dimension(size_type dim){ base::data().set_pattern_dimension(dim); }
+    void set_pattern_dimension(size_type dim) const { base::data().set_pattern_dimension(dim); }
+    T max_abs () const                       { return base::data().max_abs(); }
 
     // local sizes
     size_type nrow () const		     { return base::data().nrow(); }
@@ -268,6 +358,8 @@ public:
     size_type ext_nnz() const                { return 0; }
     const_iterator ext_begin() const         { return const_iterator(); }
     const_iterator ext_end()   const         { return const_iterator(); }
+          iterator ext_begin_nonconst()      { return iterator(); }
+          iterator ext_end_nonconst()        { return iterator(); }
     size_type jext2dis_j (size_type jext) const { return 0; }
 
 // algebra:
@@ -289,9 +381,10 @@ public:
       trans_mult (x, y);
       return y;
     }
-    // a+b, a-b
+    // a+b, a-b, a*b
     csr<T,sequential> operator+ (const csr<T,sequential>& b) const;
     csr<T,sequential> operator- (const csr<T,sequential>& b) const;
+    csr<T,sequential> operator* (const csr<T,sequential>& b) const;
 
     // lambda*a
     csr<T,sequential>& operator*= (const T& lambda) {
@@ -335,12 +428,12 @@ trans (const csr<T,sequential>& a)
 #ifdef _RHEOLEF_HAVE_MPI
 //<verbatim:
 template<class T>
-class csr<T,distributed> : public smart_pointer<csr_mpi_rep<T> > {
+class csr<T,distributed> : public smart_pointer<csr_rep<T,distributed> > {
 public:
 
 // typedefs:
 
-    typedef csr_mpi_rep<T>                    rep;
+    typedef csr_rep<T,distributed>                    rep;
     typedef smart_pointer<rep>                base;
     typedef typename rep::memory_type         memory_type;
     typedef typename rep::size_type           size_type;
@@ -353,7 +446,8 @@ public:
 // allocators/deallocators:
 
     csr() : base(new_macro(rep())) {}
-    explicit csr(const asr<T,memory_type>& a) : base(new_macro(rep(a.data()))) {}
+    template<class A>
+    explicit csr(const asr<T,memory_type,A>& a) : base(new_macro(rep(a))) {}
     void resize (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1 = 0)
         { base::data().resize(row_ownership, col_ownership, nnz1); }
 
@@ -372,10 +466,14 @@ public:
     size_type dis_nrow () const              { return row_ownership().dis_size(); }
     size_type dis_ncol () const              { return col_ownership().dis_size(); }
     size_type dis_nnz () const               { return base::data().dis_nnz(); }
+    size_type dis_ext_nnz () const           { return base::data().dis_ext_nnz(); }
     bool is_symmetric() const                { return base::data().is_symmetric(); }
-    void set_symmetry (bool is_symm)         { base::data().set_symmetry(is_symm); }
+    void set_symmetry (bool is_symm) const   { base::data().set_symmetry(is_symm); }
+    void set_symmetry_by_check (const T& tol = std::numeric_limits<T>::epsilon()) const
+                                             { base::data().set_symmetry_by_check(); }
     size_type pattern_dimension() const      { return base::data().pattern_dimension(); }
-    void set_pattern_dimension(size_type dim){ base::data().set_pattern_dimension(dim); }
+    void set_pattern_dimension(size_type dim) const { base::data().set_pattern_dimension(dim); }
+    T max_abs () const                       { return base::data().max_abs(); }
 
     // local sizes
     size_type nrow () const		     { return base::data().nrow(); }
@@ -397,6 +495,8 @@ public:
     size_type ext_nnz() const                { return base::data().ext_nnz(); }
     const_iterator ext_begin() const         { return base::data().ext_begin(); }
     const_iterator ext_end()   const         { return base::data().ext_end(); }
+          iterator ext_begin_nonconst()      { return base::data().ext_begin(); }
+          iterator ext_end_nonconst()        { return base::data().ext_end(); }
     size_type jext2dis_j (size_type jext) const { return base::data().jext2dis_j(jext); }
 
 // algebra:
@@ -419,9 +519,10 @@ public:
       trans_mult (x, y);
       return y;
     }
-    // a+b, a-b
+    // a+b, a-b, a*b
     csr<T,distributed> operator+ (const csr<T,distributed>& b) const;
     csr<T,distributed> operator- (const csr<T,distributed>& b) const;
+    csr<T,distributed> operator* (const csr<T,distributed>& b) const;
 
     // lambda*a
     csr<T,distributed>& operator*= (const T& lambda) {
@@ -460,9 +561,37 @@ trans (const csr<T,distributed>& a)
   a.data().build_transpose (b.data());
   return b;
 }
-//>verbatim:
 #endif // _RHEOLEF_HAVE_MPI
 
+// b = f(a); f as a class-function or usual fct
+template<class T, class M, class Function>
+csr<T,M>
+apply (Function f, const csr<T,M>& a)
+{
+  csr<T,M> b = a;
+  typename csr<T,M>::size_type n = a.nrow(); 
+  typename csr<T,M>::const_iterator dia_ia = a.begin(); 
+  typename csr<T,M>::iterator       dia_ib = b.begin_nonconst(); 
+  pair_transform_second (dia_ia[0], dia_ia[n], dia_ib[0], f);
+  if (a.ext_nnz() != 0) {
+    typename csr<T,M>::const_iterator ext_ia = a.ext_begin(); 
+    typename csr<T,M>::iterator       ext_ib = b.ext_begin_nonconst(); 
+    pair_transform_second (ext_ia[0], ext_ia[n], ext_ib[0], f);
+  }
+  return b;
+}
+template<class T, class M, class Function>
+csr<T,M>
+apply (T (*f)(const T&), const csr<T,M>& a)
+{
+  return apply (std::ptr_fun(f), a);
+}
+//>verbatim:
+
+template<class T, class M>
+csr<T,M>
+diag (const vec<T,M>&);
+
 // ------------------------------
 // i/o
 // ------------------------------
@@ -483,7 +612,7 @@ operator << (odiststream& s, const csr<T,M>& x)
 // ------------------------------
 // a+b, a-b
 // ------------------------------
-template <class T> 
+template <class T>
 inline
 csr<T,sequential>
 csr<T,sequential>::operator+ (const csr<T,sequential>& b) const {
@@ -518,5 +647,54 @@ csr<T,distributed>::operator- (const csr<T,distributed>& b) const {
 }
 #endif // _RHEOLEF_HAVE_MPI
   
+// ------------------------------
+// a*b
+// ------------------------------
+template <class T>
+inline
+csr<T,sequential>
+csr<T,sequential>::operator* (const csr<T,sequential>& b) const {
+  csr<T,sequential> c;
+  c.data().assign_mult (this->data(), b.data());
+  return c;
+}
+#ifdef _RHEOLEF_HAVE_MPI
+template <class T> 
+inline
+csr<T,distributed>
+csr<T,distributed>::operator* (const csr<T,distributed>& b) const {
+  csr<T,distributed> c;
+  c.data().assign_mult (this->data(), b.data());
+  return c;
+}
+#endif // _RHEOLEF_HAVE_MPI
+
+// ------------------------------
+// a.max_abs
+// ------------------------------
+template <class T>
+inline
+T
+csr_rep<T,sequential>::max_abs () const
+{
+  T val = 0;
+  typename csr<T,sequential>::const_iterator ia = begin();
+  for (typename csr_rep<T,sequential>::const_data_iterator iter = ia[0], last = ia[nrow()]; iter != last; ++iter) {
+    val = std::max (val, abs((*iter).second));
+  }
+  return val;
+}
+#ifdef _RHEOLEF_HAVE_MPI
+template <class T>
+inline
+T
+csr_rep<T,distributed>::max_abs () const
+{
+  T val = csr_rep<T,sequential>::max_abs();
+  val = mpi::all_reduce (comm(), val, mpi::maximum<T>());
+  return val;
+}
+#endif // _RHEOLEF_HAVE_MPI
+  
 } // namespace rheolef
-# endif // _RHEO_CSR_H
+# endif // _RHEOLEF_CSR_H
