@@ -66,15 +66,6 @@ struct csr_concat_value {
  csr_concat_value (const vector_vec_trans<T,M>& vt) : s(),  v(),     vv(vt.v), m(),  variant(vector_vec_transpose) {}
  csr_concat_value (const csr<T,M>& x)               : s(),  v(),     vv(),     m(x), variant(matrix) {}
 
-#ifdef TO_CLEAN
-// io/debug:
- friend std::ostream& operator<< (std::ostream& o, const csr_concat_value<T,M>& x) {
-  if (x.variant == scalar) return o << "s";
-  else if (x.variant == vector) return o << "v";
-  else if (x.variant == vector_transpose) return o << "vt";
-  else return o << "m";
- }
-#endif // TO_CLEAN
 // data:
 public:
  T                      s;
