@@ -21,10 +21,8 @@
 
 #include "rheolef/csr.h"
 #include "rheolef/asr.h"
-
-#include "rheolef/msg_util.h"
 #include "rheolef/asr_to_csr.h"
-#include "rheolef/csr_to_asr.h"
+#include "rheolef/msg_util.h"
 #include "rheolef/csr_amux.h"
 #include "rheolef/csr_cumul_trans_mult.h"
 using namespace std;
@@ -34,7 +32,7 @@ namespace rheolef {
 // ----------------------------------------------------------------------------
 
 template<class T>
-csr_seq_rep<T>::csr_seq_rep(const distributor& row_ownership, const distributor& col_ownership, size_type nnz1) 
+csr_rep<T,sequential>::csr_rep(const distributor& row_ownership, const distributor& col_ownership, size_type nnz1) 
  : vector_of_iterator<pair_type>(row_ownership.size()+1),
    _row_ownership (row_ownership),
    _col_ownership (col_ownership),
@@ -45,7 +43,7 @@ csr_seq_rep<T>::csr_seq_rep(const distributor& row_ownership, const distributor&
 }
 template<class T>
 void
-csr_seq_rep<T>::resize (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1) 
+csr_rep<T,sequential>::resize (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1) 
 {
    vector_of_iterator<pair_type>::resize (row_ownership.size()+1);
    _row_ownership = row_ownership;
@@ -55,7 +53,7 @@ csr_seq_rep<T>::resize (const distributor& row_ownership, const distributor& col
    vector_of_iterator<pair_type>::operator[](0) = _data.begin().operator->();
 }
 template<class T>
-csr_seq_rep<T>::csr_seq_rep(size_type loc_nrow1, size_type loc_ncol1, size_type loc_nnz1) 
+csr_rep<T,sequential>::csr_rep(size_type loc_nrow1, size_type loc_ncol1, size_type loc_nnz1) 
  : vector_of_iterator<pair_type> (loc_nrow1+1),
    _row_ownership (distributor::decide, communicator(), loc_nrow1),
    _col_ownership (distributor::decide, communicator(), loc_ncol1),
@@ -66,7 +64,7 @@ csr_seq_rep<T>::csr_seq_rep(size_type loc_nrow1, size_type loc_ncol1, size_type
 }
 template<class T>
 void
-csr_seq_rep<T>::resize (size_type loc_nrow1, size_type loc_ncol1, size_type loc_nnz1)
+csr_rep<T,sequential>::resize (size_type loc_nrow1, size_type loc_ncol1, size_type loc_nnz1)
 {
    vector_of_iterator<pair_type>::resize (loc_nrow1+1);
    _row_ownership = distributor (distributor::decide, communicator(), loc_nrow1);
@@ -76,7 +74,7 @@ csr_seq_rep<T>::resize (size_type loc_nrow1, size_type loc_ncol1, size_type loc_
    vector_of_iterator<pair_type>::operator[](0) = _data.begin().operator->();
 }
 template<class T>
-csr_seq_rep<T>::csr_seq_rep(const csr_seq_rep<T>& b)
+csr_rep<T,sequential>::csr_rep(const csr_rep<T,sequential>& b)
  : vector_of_iterator<pair_type>(b.nrow()+1),
    _row_ownership (b.row_ownership()),
    _col_ownership (b.col_ownership()),
@@ -85,93 +83,86 @@ csr_seq_rep<T>::csr_seq_rep(const csr_seq_rep<T>& b)
    _pattern_dimension (b._pattern_dimension)
 {
   // physical copy of csr
-  typedef typename csr_seq_rep<T>::size_type size_type;
-  typename csr_seq_rep<T>::const_iterator ib = b.begin();
-  typename csr_seq_rep<T>::iterator       ia = begin();
+  const_iterator ib = b.begin();
+  iterator       ia = begin();
   ia[0] = _data.begin().operator->();
   for (size_type i = 0, n = b.nrow(); i < n; i++) {
     ia [i+1] = ia[0] + (ib[i+1] - ib[0]);
   }
 }
 template<class T>
-csr_seq_rep<T>::csr_seq_rep(const asr_seq_rep<T>& a)
-  : vector_of_iterator<pair_type>(a.nrow()+1),
-   _row_ownership (a.row_ownership()),
-   _col_ownership (a.col_ownership()),
-   _data(a.nnz())
+template<class A>
+void
+csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,A>& a)
 {
-    typedef pair<size_type,T> pair_type;
-    typedef typename asr_seq_rep<T>::row_type::value_type const_pair_type;
-    
-    asr_to_csr (
+  resize (a.row_ownership(), a.col_ownership(), a.nnz());
+  typedef std::pair<size_type,T>                pair_type;
+  typedef std::pair<size_type,T>                const_pair_type;
+  //typedef typename asr<T>::row_type::value_type const_pair_type;
+  asr_to_csr (
 	a.begin(),
         a.end(), 
 	always_true<const_pair_type>(), 
 	pair_identity<const_pair_type,pair_type>(), 
         vector_of_iterator<pair_type>::begin(), 
         _data.begin());
-}
+} 
 template<class T>
-void
-csr_seq_rep<T>::to_asr(asr_seq_rep<T>& b) const
+odiststream&
+csr_rep<T,sequential>::put_matrix_market (odiststream& ods, size_type first_dis_i) const
 {
-    typedef pair<size_type,T> pair_type;
-    typedef typename asr_seq_rep<T>::row_type::value_type const_pair_type;
-
-    csr_to_asr (
-        vector_of_iterator<pair_type>::begin(), 
-        vector_of_iterator<pair_type>::end(),
-        _data.begin().operator->(), 
-	pair_identity<pair_type,const_pair_type>(), 
-	b.begin().operator->());
-}
-template<class T>
-idiststream& 
-csr_seq_rep<T>::get (idiststream& ps)
-{
-    typedef pair<size_type,T> pair_type;
-    typedef typename asr_seq_rep<T>::row_type::value_type const_pair_type;
-    asr_seq_rep<T> a;
-    a.get(ps);
-    resize (a.nrow(), a.ncol(), a.nnz());
-    asr_to_csr (
-	a.begin(), 
-        a.end(), 
-	always_true<const_pair_type>(), 
-	pair_identity<const_pair_type,pair_type>(), 
-        vector_of_iterator<pair_type>::begin(), 
-        _data.begin());
-    return ps;
+  std::ostream& os = ods.os();
+  os << setprecision (std::numeric_limits<T>::digits10)
+     << "%%MatrixMarket matrix coordinate real general" << std::endl
+     << nrow() << " " << ncol() << " " << nnz() << endl;
+  const_iterator ia = begin();
+  const size_type base = 1;
+  for (size_type i = 0, n = nrow(); i < n; i++) {
+    for (const_data_iterator iter = ia[i], last = ia[i+1]; iter != last; ++iter) {
+      os << i+first_dis_i+base << " "
+         << (*iter).first+base << " "
+         << (*iter).second << endl;	
+    }
+  }
+  return ods;
 }
 template<class T>
 odiststream&
-csr_seq_rep<T>::put (odiststream& ops, size_type istart) const
+csr_rep<T,sequential>::put_sparse_matlab (odiststream& ods, size_type first_dis_i) const
 {
-    std::ostream& os = ops.os();
-    os << setprecision (std::numeric_limits<T>::digits10)
-       << "%%MatrixMarket matrix coordinate real general" << std::endl
-       << nrow() << " " << ncol() << " " << nnz() << endl;
-    const_iterator ia = begin();
-    const size_type base = 1;
-    for (size_type i = 0, n = nrow(); i < n; i++) {
-        for (const_data_iterator iter_jva = ia[i], last_jva = ia[i+1];
-	    iter_jva != last_jva; iter_jva++) {
-
-	    os << i+istart+base << " "
-               << (*iter_jva).first+base << " "
-               << (*iter_jva).second << endl;	
-  	}
+  std::ostream& os = ods.os();
+  std::string name = iorheo::getbasename(ods.os());
+  if (name == "") name = "a";
+  os << setprecision (std::numeric_limits<T>::digits10)
+     << name << " = spalloc(" << nrow() << "," << ncol() << "," << nnz() << ");" << endl;
+  const_iterator ia = begin();
+  const size_type base = 1;
+  for (size_type i = 0, n = nrow(); i < n; i++) {
+    for (const_data_iterator iter = ia[i], last = ia[i+1]; iter != last; ++iter) {
+      os << name << "(" << i+first_dis_i+base << "," << (*iter).first+base << ") = "
+         << (*iter).second << ";" << endl;	
     }
-    return ops;
+  }
+  return ods;
+}
+template<class T>
+odiststream&
+csr_rep<T,sequential>::put (odiststream& ods, size_type first_dis_i) const
+{
+    iorheo::flag_type format = iorheo::flags(ods.os()) & iorheo::format_field;
+    if (format [iorheo::matlab] || format [iorheo::sparse_matlab]) 
+					{ return put_sparse_matlab   (ods,first_dis_i); }
+    // default is matrix market format
+    return put_matrix_market (ods,first_dis_i);
 }
 template<class T>
 void
-csr_seq_rep<T>::dump (const string& name, size_type istart) const
+csr_rep<T,sequential>::dump (const string& name, size_type first_dis_i) const
 {
     std::ofstream os (name.c_str());
     std::cerr << "! file \"" << name << "\" created." << std::endl;
-    odiststream ops(os);
-    put (ops);
+    odiststream ods(os);
+    put (ods);
 }
 // ----------------------------------------------------------------------------
 // basic linear algebra
@@ -179,7 +170,7 @@ csr_seq_rep<T>::dump (const string& name, size_type istart) const
 
 template<class T>
 void
-csr_seq_rep<T>::mult(
+csr_rep<T,sequential>::mult(
     const vec<T,sequential>& x,
     vec<T,sequential>&       y)
     const
@@ -193,7 +184,7 @@ csr_seq_rep<T>::mult(
 }
 template<class T>
 void
-csr_seq_rep<T>::trans_mult(
+csr_rep<T,sequential>::trans_mult(
     const vec<T,sequential>& x,
     vec<T,sequential>&       y)
     const
@@ -208,8 +199,8 @@ csr_seq_rep<T>::trans_mult(
         y.begin());
 }
 template<class T>
-csr_seq_rep<T>&
-csr_seq_rep<T>::operator*= (const T& lambda)
+csr_rep<T,sequential>&
+csr_rep<T,sequential>::operator*= (const T& lambda)
 {
   iterator ia = begin();
   for (data_iterator p = ia[0], last_p = ia[nrow()]; p != last_p; p++) {
@@ -223,9 +214,9 @@ csr_seq_rep<T>::operator*= (const T& lambda)
 template<class T>
 template<class BinaryOp>
 void
-csr_seq_rep<T>::assign_add (
-    const csr_seq_rep<T>& a, 
-    const csr_seq_rep<T>& b,
+csr_rep<T,sequential>::assign_add (
+    const csr_rep<T,sequential>& a, 
+    const csr_rep<T,sequential>& b,
     BinaryOp binop)
 {
     check_macro (a.nrow() == b.nrow() && a.ncol() == b.ncol(),
@@ -275,9 +266,11 @@ csr_seq_rep<T>::assign_add (
 		iter_jva++;
 		iter_jvb++;
 	    } else if (ja < jb) {
-		*iter_jvc++ = *iter_jva++;
+		*iter_jvc++ = std::pair<size_type,T> (ja, binop((*iter_jva).second, T(0)));
+		iter_jva++;
             } else {
-		*iter_jvc++ = *iter_jvb++;
+		*iter_jvc++ = std::pair<size_type,T> (jb, binop(T(0), (*iter_jvb).second));
+		iter_jvb++;
             }
   	}
         *ic++ = iter_jvc;
@@ -341,7 +334,7 @@ csr_seq_rep<T>::assign_add (
 //       even if original matrix has not
 template<class T>
 void
-csr_seq_rep<T>::build_transpose (csr_seq_rep<T>& b) const
+csr_rep<T,sequential>::build_transpose (csr_rep<T,sequential>& b) const
 {
   b.resize (col_ownership(), row_ownership(), nnz()); 
 
@@ -380,11 +373,116 @@ csr_seq_rep<T>::build_transpose (csr_seq_rep<T>& b) const
   ib[0] = q0;
 }
 // ----------------------------------------------------------------------------
+// set symmetry by check
+// ----------------------------------------------------------------------------
+template<class T>
+void
+csr_rep<T,sequential>::set_symmetry_by_check (const T& tol) const
+{
+  if (nrow() != ncol()) {
+    set_symmetry(false);
+    return;
+  }
+  // check if a-trans(a) == 0 up to machine prec
+  csr_rep<T,sequential> at, d;
+  build_transpose (at);
+  d.assign_add (*this, at, std::minus<T>());
+  set_symmetry(d.max_abs() <= tol);
+}
+// ----------------------------------------------------------------------------
+// expression c=a*b with a temporary c=*this
+// ----------------------------------------------------------------------------
+// compute the sparse size of c=a*b
+template<class T>
+typename csr_rep<T,sequential>::size_type
+csr_csr_mult_size (
+    const csr_rep<T,sequential>& a,
+    const csr_rep<T,sequential>& b)
+{
+  typedef typename csr_rep<T,sequential>::size_type size_type;
+  typename csr_rep<T,sequential>::const_iterator ia = a.begin(), ib = b.begin();
+  size_type nnz_c = 0;
+  for (size_type i = 0, n = a.nrow(); i < n; i++) {
+    std::set<size_type> y;
+    for (typename csr<T>::const_data_iterator ap = ia[i], last_ap = ia[i+1]; ap != last_ap; ++ap) {
+      size_type j = (*ap).first;
+      typename std::set<size_type>::iterator iter_y = y.begin();
+      for (typename csr<T>::const_data_iterator bp = ib[j], last_bp = ib[j+1]; bp != last_bp; ++bp) {
+        size_type k = (*bp).first;
+	iter_y = y.insert(iter_y, k);
+      }
+    }
+    nnz_c += y.size();
+  }
+  return nnz_c;
+}
+// compute the values of the sparse matrix c=a*b
+template<class T>
+static
+void
+csr_csr_mult (
+    const csr_rep<T,sequential>& a,
+    const csr_rep<T,sequential>& b,
+          csr_rep<T,sequential>& c)
+{
+  typedef typename csr_rep<T,sequential>::size_type      size_type;
+  typename csr_rep<T,sequential>::const_iterator ia = a.begin(), ib = b.begin();
+  typename csr_rep<T,sequential>::iterator       ic = c.begin();
+  for (size_type i = 0, n = a.nrow(); i < n; i++) {
+    std::map<size_type,T> y;
+    for (typename csr<T>::const_data_iterator ap = ia[i], last_ap = ia[i+1]; ap != last_ap; ++ap) {
+      size_type j    = (*ap).first;
+      const T&  a_ij = (*ap).second;
+      typename std::map<size_type,T>::iterator prev_y = y.begin();
+      for (typename csr<T>::const_data_iterator bp = ib[j], last_bp = ib[j+1]; bp != last_bp; ++bp) {
+        size_type k    = (*bp).first;
+        const T&  b_jk = (*bp).second;
+	T value = a_ij*b_jk;
+        typename std::map<size_type,T>::iterator curr_y = y.find(k);
+        if (curr_y == y.end()) { 
+          // create a new (i,k,value) entry in matrix C
+	  y.insert (prev_y, std::pair<size_type,T>(k, value));
+        } else {
+          // increment an existing (i,k,value) entry in matrix C
+          (*curr_y).second += value;
+          prev_y = curr_y;
+        }
+      }
+    }
+    ic[i+1] = ic[i] + y.size();
+    // copy the y temporary into the i-th row of C:
+    typename std::map<size_type,T>::const_iterator iter_y = y.begin();
+    for (typename csr<T>::data_iterator cp = ic[i], last_cp = ic[i+1]; cp != last_cp; ++cp, ++iter_y) {
+	*cp = *iter_y;
+    }
+  }
+}
+template<class T>
+void
+csr_rep<T,sequential>::assign_mult (
+    const csr_rep<T,sequential>& a, 
+    const csr_rep<T,sequential>& b)
+{
+  size_type nnz_c = csr_csr_mult_size (a, b);
+  resize (a.row_ownership(), b.col_ownership(), nnz_c);
+  csr_csr_mult (a, b, *this);
+}
+// ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
-template class csr_seq_rep<Float>;
-template void csr_seq_rep<Float>::assign_add (
-	const csr_seq_rep<Float>&, const csr_seq_rep<Float>&, std::plus<Float>);
-template void csr_seq_rep<Float>::assign_add (
-	const csr_seq_rep<Float>&, const csr_seq_rep<Float>&, std::minus<Float>);
+#define _RHEOLEF_instanciate(T) \
+template class csr_rep<T,sequential>;					\
+template void csr_rep<T,sequential>::assign_add (			\
+	const csr_rep<T,sequential>&,					\
+	const csr_rep<T,sequential>&,					\
+	      std::plus<T>);					\
+template void csr_rep<T,sequential>::assign_add (			\
+	const csr_rep<T,sequential>&,					\
+	const csr_rep<T,sequential>&,					\
+	std::minus<T>);						\
+template void csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,std::allocator<T> >&);	\
+template void csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,heap_allocator<T> >&);
+
+_RHEOLEF_instanciate(Float)
+
 } // namespace rheolef
