@@ -105,10 +105,15 @@ distributor::~distributor ()
 distributor::size_type
 distributor::find_owner (size_type dis_i) const
 {
+  // check first on current iproc:
+  size_type iproc = comm().rank();
+  if (is_owned (dis_i, iproc)) return iproc;
+
+  // then lookup in sorted intervals table:
   const_iterator iter = std::lower_bound (begin(), end(), dis_i);
   check_macro (iter != end(), "index = " << dis_i <<" not found in index range[0:" << dis_size() << "[");
   size_type iproc1 = distance (begin(), iter);
-  size_type iproc = (operator[] (iproc1) == dis_i) ? iproc1 : iproc1 - 1;
+  iproc = (operator[] (iproc1) == dis_i) ? iproc1 : iproc1 - 1;
   if (dis_i >= first_index(iproc) && dis_i < last_index(iproc)) {
     return iproc;
   }
