@@ -28,7 +28,7 @@
 namespace rheolef {
 
 /*Class:distributor
-NAME:  distributor - data distribution table (@PACKAGE@-@VERSION@)
+NAME:  @code{distributor} - data distribution table (@PACKAGE@-@VERSION@)
 SYNOPSYS:
    Used by "array"(1), "asr"(1) and "csr"(1).
    and such classes that distribute data as chunk.
@@ -82,25 +82,33 @@ public:
 	/// number of processes
         size_type n_process () const;
 
+ 	/// find iproc associated to a global index dis_i: CPU=log(nproc)
+	size_type find_owner (size_type dis_i) const;
+
+	/// global index range and local size owned by ip-th process
+        size_type first_index (size_type ip) const;
+        size_type last_index (size_type ip) const;
+        size_type size (size_type ip) const;
+
 	/// global index range and local size owned by current process
         size_type first_index () const;
         size_type last_index () const;
         size_type size () const;
 
-	/// global index range and local size owned by k-th process
-        size_type first_index (size_type k) const;
-        size_type last_index (size_type k) const;
-        size_type size (size_type k) const;
+	/// true when dis_i in [first_index(ip):last_index(ip)[
+        bool is_owned (size_type dis_i, size_type ip) const;
+
+        // the same with ip=current process
+        bool is_owned (size_type dis_i) const;
 
-	/// return process id that store a global index
-	size_type owner(size_type global_index) const;
 
 	/// returns a new tag
 	static tag_type get_new_tag();
 
- 	/// find proc index associated to an index: CPU=log(nproc)
-	size_type find_owner (size_type index) const;
+// comparators:
 
+   	bool operator== (const distributor&) const;
+   	bool operator!= (const distributor&) const;
 // data:
 protected:
 	communicator_type _comm;
@@ -176,5 +184,30 @@ distributor::dis_size() const
 {
 	return at(n_process());
 }
+inline
+bool
+distributor::is_owned (size_type dis_i, size_type ip) const
+{
+        return dis_i >= first_index(ip) && dis_i < last_index(ip);
+}
+inline
+bool
+distributor::is_owned (size_type dis_i) const
+{
+        return is_owned (dis_i, process());
+}
+inline
+bool
+distributor::operator!= (const distributor& x) const
+{
+  return !operator==(x);
+}
+inline
+bool
+distributor::operator== (const distributor& x) const
+{
+  return (x.n_process() == n_process()) && (x.size() == size()) && (x.dis_size() == dis_size());
+}
+
 } // namespace rheolef
 #endif // _RHEO_DISTRIBUTOR_H
