@@ -139,6 +139,7 @@ void
 odiststream::open (
   std::string filename, 
   std::string suffix,
+  bool use_gzip,
   const communicator& comm)
 {
   close();
@@ -148,7 +149,7 @@ odiststream::open (
     _ptr_os = 0;
   }
   if (size_type(comm.rank()) == odiststream::io_proc()) {
-    _ptr_os = new_macro (orheostream(filename, suffix));
+    _ptr_os = new_macro (orheostream(filename, suffix, use_gzip));
   } else {
     _ptr_os = new_macro (orheostream);
   }
@@ -165,6 +166,17 @@ odiststream::close ()
     }
   }
 }
+void
+odiststream::flush()
+{
+  if (size_type(_comm.rank()) != odiststream::io_proc()) return;
+  if (_use_alloc && _ptr_os != 0) {
+    orheostream* ptr_ors = (orheostream*)(_ptr_os);
+    (*ptr_ors).flush();
+  } else if (_ptr_os != 0) {
+    (*_ptr_os).flush(); // call usual ostream::flush(), i.e. not gziped output
+  }
+}
 odiststream::~odiststream ()
 {
   close();
