@@ -45,19 +45,20 @@ public:
        : _ptr_os(&os), _use_alloc(false), _comm(comm) {}
 
      odiststream (std::string filename, std::string suffix = "",
+	     bool use_gzip = true,
              const communicator& comm = communicator())
        : _ptr_os(0), _use_alloc(false), _comm()
        {
-         open (filename, suffix, comm);
+         open (filename, suffix, use_gzip, comm);
        }
-
      ~odiststream();
 
 // modifiers:
 
      void open (std::string filename, std::string suffix = "",
+	     bool use_gzip = true,
              const communicator& comm = communicator());
-
+     void flush();
      void close();
 
 // accessors:
@@ -85,22 +86,19 @@ protected:
      bool          _use_alloc;
      communicator  _comm;
 };
-
-// standard i/o
- 
+// standard i/o:
 # define define_sequential_odiststream_raw_macro(arg) 	\
     inline 						\
-    odiststream&						\
+    odiststream&					\
     operator << (odiststream& s, arg) {			\
         if (s.nop()) return s; s.os() << x; return s;	\
     }
-
-# define define_sequential_odiststream_macro(T) 		\
+# define define_sequential_odiststream_macro(T) 	\
     define_sequential_odiststream_raw_macro(const T& x)
 
 # define define_distributed_odiststream_macro(T) 	\
     inline 						\
-    odiststream&						\
+    odiststream&					\
     operator << (odiststream& s, const T& x) {		\
         s.os() << x; return s;				\
     }
@@ -246,13 +244,14 @@ inline
 idiststream&
 operator>> (idiststream& ids, const catchmark& m)
 {
-    if (ids.nop()) return ids;
-    ids.is() >> setmark(m.mark());
-    std::string label = "#" + m.mark();
-    if (!scatch(ids.is(),label)) {
-        warning_macro ("catchmark: label `"<< label <<"' not found on input");
-    }
-    return ids;
+  if (ids.nop()) return ids;
+  ids.is() >> setmark(m.mark());
+  std::string label = "#" + m.mark();
+  if (!scatch(ids.is(),label)) {
+    bool verbose  = iorheo::getverbose(ids.is());
+    if (verbose) warning_macro ("catchmark: label `"<< label <<"' not found on input");
+  }
+  return ids;
 }
 inline
 odiststream&
