@@ -20,21 +20,23 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ///
 /// =========================================================================
+// wrapper for std::set<size_t>: union as a+b and a += b and others goodies
+//
+// motivation: this class is usefull for array<index_set,M> to send/receive variable-sized
+// lists via MPI correctly
+// array<index_set,M> is used by the geo class to manage connectivity
+// and compute neighbours
+//
+// author: Pierre.Saramito@imag.fr
+//
+// date: 19 mai 2012
+//
 #include "rheolef/distributed.h"
 #include "rheolef/pretty_name.h"
-#include "rheolef/array.h" // for is_container_of_mpi_datatype ; TODO: move
+#include "rheolef/container_traits.h"
 
 #include <boost/serialization/set.hpp>
 #include <boost/serialization/base_object.hpp>
-#ifdef TO_CLEAN
-#include <boost/serialization/list.hpp>
-#include <boost/serialization/string.hpp>
-#include <boost/serialization/version.hpp>
-#include <boost/serialization/split_free.hpp>
-#include <boost/serialization/split_member.hpp>
-#endif // TO_CLEAN
-
-
 namespace rheolef {
 
 /*Class:index_set
@@ -93,20 +95,24 @@ public:
 };
 //>verbatim:
 
+// operator += for array::assembly
+template <class T>
+struct index_set_add_op : std::binary_function<T,T,T> {
+    T& operator()(T& x, const T&                      y) const { return x += y; }
+    T& operator()(T& x, const typename T::value_type& y) const { return x += y; }
+};
 // for boost mpi and array<index_set>:
-template <>
-struct is_container_of_mpi_datatype<index_set> : boost::mpl::true_ {
+template <> struct default_set_op<index_set> {
+  typedef index_set_add_op<index_set> type;
+};
+template <> struct is_container<index_set> : boost::mpl::true_ {
   typedef boost::mpl::true_ type;
 };
-
-// operator += for array::assembly
-template <class T1, class T2>
-struct index_set_add_op : std::binary_function<T1,T2,T1> {
-    T1& operator()(T1& x, const T2& y) const {
-	x += y;
-	return x;
-    }
+#ifdef _RHEOLEF_HAVE_MPI
+template <> struct is_container_of_mpi_datatype<index_set> : boost::mpl::true_ {
+  typedef boost::mpl::true_ type;
 };
+#endif // _RHEOLEF_HAVE_MPI
 // -------------------------------------------------------------------
 // inlined
 // -------------------------------------------------------------------
