@@ -94,7 +94,7 @@ mpi_assembly_begin (
             break;
           }
         }
-        assert_macro (iproc != nproc, "bad stash data: processor range error (0:nproc-1).");
+        assert_macro (iproc != nproc, "bad stash data: index "<<*iter_idx<<" out of range [0:"<<ownership[nproc]<<"[");
       }
     } // end block
     // ----------------------------------------------------------------
