@@ -60,31 +60,31 @@ END:
 //<mpi_scatter_begin:
 template <
     class InputIterator, 
-    class T, 
+    class Message, 
     class Tag,
     class Comm>
 void
 mpi_scatter_begin_global (
     InputIterator           		x,
-    scatter_message<std::vector<T> >&   from,
-    scatter_message<std::vector<T> >&   to,
+    Message&                            from,
+    Message&                            to,
     Tag                     		tag,
     Comm                    		comm)
 {
-    typedef typename std::vector<T>::size_type size_type;
+    typedef typename Message::size_type        size_type;
     // ----------------------------------------------------------
     // 1) post receives
     // ----------------------------------------------------------
     from.requests.clear();
     {
-      size_type n_receive = from.starts.size() - 1;
+      size_type n_receive = from.starts().size() - 1;
       size_type i_start = 0;
       for (size_type i = 0; i < n_receive; i++) {
-        size_type i_size = from.starts [i+1] - from.starts [i];
+        size_type i_size = from.starts() [i+1] - from.starts() [i];
 	mpi::request i_req = comm.irecv(
-            from.procs [i],
+            from.procs() [i],
 	    tag,
-    	    from.values.begin().operator->() + i_start,
+    	    from.values().begin().operator->() + i_start,
 	    i_size); 
         i_start += i_size;
         from.requests.push_back (std::make_pair(i, i_req));
@@ -93,28 +93,21 @@ mpi_scatter_begin_global (
     // ----------------------------------------------------------
     // 2) apply right permutation
     // ----------------------------------------------------------
-    assert_macro (to.indices.size() == to.starts [to.n_proc()],
- 		"incompatible pointer/indexes array sizes.");
-
-    msg_right_permutation_apply (
-        to.indices.begin(),
-        to.indices.end(),
-	x,
-        to.values.begin());
+    to.load_values (x);
 
     // ----------------------------------------------------------
     // 3) do sends
     // ----------------------------------------------------------
     to.requests.clear();
     {
-      size_type n_send = to.starts.size() - 1;
+      size_type n_send = to.starts().size() - 1;
       size_type i_start = 0;
       for (size_type i = 0; i < n_send; i++) {
-        size_type i_size = to.starts [i+1] - to.starts [i];
+        size_type i_size = to.starts() [i+1] - to.starts() [i];
 	mpi::request i_req = comm.isend(
-            to.procs [i],
+            to.procs() [i],
 	    tag,
-    	    to.values.begin().operator->() + i_start,
+    	    to.values().begin().operator->() + i_start,
 	    i_size); 
         i_start += i_size;
         to.requests.push_back (std::make_pair(i, i_req));
@@ -125,15 +118,16 @@ template <
     class InputIterator, 
     class OutputIterator, 
     class SetOp, 
-    class T>
+    class Message>
 void
 mpi_scatter_begin_local (
     InputIterator           		x,
     OutputIterator          		y,
-    scatter_message<std::vector<T> >&   from,
-    scatter_message<std::vector<T> >&   to,
+    Message&                            from,
+    Message&                            to,
     SetOp		    		op)
 {
+#ifdef TO_CLEAN
     msg_both_permutation_apply (
 	to.local_slots.begin(),
 	to.local_slots.end(),
@@ -141,20 +135,23 @@ mpi_scatter_begin_local (
 	op,
 	from.local_slots.begin(),
 	y);
+#endif // TO_CLEAN
 }
 // take care of local insert: template specialisation
 template <
     class InputIterator, 
     class OutputIterator, 
-    class T>
+    class Message>
 void
 mpi_scatter_begin_local (
     InputIterator           		x,
     OutputIterator          		y,
-    scatter_message<std::vector<T> >&   from,
-    scatter_message<std::vector<T> >&   to,
-    set_op<T,T>		    		op)
+    Message&                            from,
+    Message&                            to,
+    set_op<typename Message::value_type, typename Message::value_type> op)
 {
+#ifdef TO_CLEAN
+    // used when x & y have distinct pointer types (multi-valued) 
     if (y == x && ! to.local_nonmatching_computed) {
         // scatter_local_optimize(to,from);
 	fatal_macro ("y == x: adress matches in scatter: not yet -- sorry");
@@ -185,12 +182,13 @@ mpi_scatter_begin_local (
 	    from.local_slots_nonmatching.begin(),
 	    y);
     }
+#endif // TO_CLEAN
 }
 template <
     class InputIterator, 
     class OutputIterator, 
+    class Message,
     class SetOp, 
-    class Container,
     class Tag,
     class Comm>
 inline
@@ -198,28 +196,8 @@ void
 mpi_scatter_begin(
     InputIterator      		     	x,
     OutputIterator     		     	y,
-    scatter_message<Container>&   	from,
-    scatter_message<Container>&   	to,
-    SetOp			    	op,
-    Tag                		     	tag,
-    Comm               		     	comm)
-{
-    error_macro ("undefined scatter for " << typename_macro(Container));
-}
-template <
-    class InputIterator, 
-    class OutputIterator, 
-    class SetOp, 
-    class T,
-    class Tag,
-    class Comm>
-inline
-void
-mpi_scatter_begin(
-    InputIterator      		     	x,
-    OutputIterator     		     	y,
-    scatter_message<std::vector<T> >&   from,
-    scatter_message<std::vector<T> >&   to,
+    Message&                            from,
+    Message&                            to,
     SetOp			    	op,
     Tag                		     	tag,
     Comm               		     	comm)
@@ -228,6 +206,7 @@ mpi_scatter_begin(
     if (to.n_local() == 0) {
 	return;
     }
+    error_macro ("local messages: no more supported");
     mpi_scatter_begin_local  (x, y, from, to, op);
 }
 //>mpi_scatter_begin:
