@@ -63,7 +63,7 @@ struct set_add_op : std::binary_function<T1,T2,T1> {
 };  
 // dummy iterator, when an iterator is required but
 // we have no usage.
-template <class T, class Distance = ptrdiff_t>
+template <class T, class Distance = std::ptrdiff_t>
 class dummy_iterator : public std::iterator<std::input_iterator_tag, T, Distance, const T*, const T&> {
 public:
 	dummy_iterator& operator++() { return *this; }
@@ -75,7 +75,7 @@ protected:
 	T _dummy;
 };
 // index iterator, simulates array[i] = i
-template <class Size, class Distance = ptrdiff_t>
+template <class Size, class Distance = std::ptrdiff_t>
 class index_iterator : public std::iterator<std::input_iterator_tag, Size, Distance, const Size*, const Size&> {
 public:
 	index_iterator& operator++() { _i++; return *this; }
