@@ -102,14 +102,12 @@ NOTE:
 
   @noindent
   @code{pgmres} follows the algorithm described on p. 20 in
-  @quotation
-	Templates for the Solution of Linear Systems: Building Blocks for Iterative Methods, 
+  @emph{Templates for the solution of linear systems: building blocks for iterative methods}, 
 	2nd Edition, 
         R. Barrett, M. Berry, T. F. Chan, J. Demmel, J. Donato, J. Dongarra, V. Eijkhout,
 	R. Pozo, C. Romine, H. Van der Vorst,
         SIAM, 1994, 
 	@url{ftp.netlib.org/templates/templates.ps}.
-  @end quotation
 
   @noindent
   The present implementation is inspired from @code{IML++ 1.2} iterative method library,
