@@ -22,6 +22,7 @@
 //
 #include "rheolef/solver.h"
 #include "solver_wrapper.h"
+#include "solver_umfpack.h"
 #include "solver_mumps.h"
 #include "solver_trilinos_ifpack.h"
 #include "solver_no_trilinos_ifpack.h"
@@ -45,6 +46,15 @@ template<class T, class M>
 void
 solver_rep<T,M>::build_lu (const csr<T,M>& a, const solver_option_type& opt)
 {
+#ifdef _RHEOLEF_HAVE_UMFPACK
+  if (a.dis_ext_nnz() == 0) {
+    // diagonal bloc per process => use umfpack
+    typedef solver_umfpack_rep<T,M> rep;
+    if (_ptr) delete_macro (_ptr);
+    _ptr = new_macro (rep(a,opt));
+    return;
+  }
+#endif // _RHEOLEF_HAVE_UMFPACK
 #ifdef _RHEOLEF_HAVE_MUMPS
   typedef solver_mumps_rep<T,M> rep;
 #elif defined(_RHEOLEF_HAVE_PASTIX)
