@@ -40,16 +40,17 @@ solver_pastix_rep<T,distributed>::solver_pastix_rep (const csr<T>& a, const solv
    _new_idx(0),
    _new_val(0)
 {
+warning_macro ("call load...");
   load (a, opt);
+warning_macro ("return load...");
 }
 template<class T>
 void
 solver_pastix_rep<T,distributed>::load (const csr<T>& a, const solver_option_type& opt)
 {
+warning_macro ("load...");
    base::_is_sym = a.is_symmetric(); 
    base::_pattern_dimension = a.pattern_dimension(); 
-   warning_macro ("is_sym = " << base::_is_sym);
-   warning_macro ("pattern_dim = " << base::_pattern_dimension);
    _comm = a.row_ownership().comm();
    base::_csr_row_ownership = a.row_ownership();
    base::_csr_col_ownership = a.col_ownership();
@@ -60,14 +61,12 @@ solver_pastix_rep<T,distributed>::load (const csr<T>& a, const solver_option_typ
   // there is a bug in pastix related to "np < a.dis_nrow" : use an alternative solver...
   if (a.nrow() == 0) {
     base::_have_pastix_bug_small_matrix = true;
-    warning_macro ("sym_fact: too small matrix bug detected... circumvent");
   }
   // ask if other procs have a bug ?
   base::_have_pastix_bug_small_matrix = mpi::all_reduce (comm(), base::_have_pastix_bug_small_matrix, mpi::maximum<bool>());
   if (base::_have_pastix_bug_small_matrix) {
     // one of the procs at least have a too small matrix for pastix !
    base::_a_when_bug = a;
-    warning_macro ("sym_fact(n="<<a.nrow()<<"): ok, circumvent !");
     return;
   }
   if (base::_is_sym) {
@@ -80,6 +79,7 @@ solver_pastix_rep<T,distributed>::load (const csr<T>& a, const solver_option_typ
   }
   symbolic_factorization ();
   numeric_factorization();
+warning_macro ("load done");
 }
 template<class T>
 void
@@ -90,13 +90,33 @@ solver_pastix_rep<T,distributed>::load_unsymmetric (const csr<T>& a)
   resize (n, nnz);
   load_both_continued (a); 
 }
+// compute how many a.dia (dis_i,dis_j) have dis_i > dis_j
+template<class T>
+static
+size_t
+compute_csr_upper_dia_nnz (const csr<T>& a) 
+{
+  size_t csr_upper_dia_nnz = 0;
+  size_t first_dis_i = a.row_ownership().first_index();
+  size_t first_dis_j = a.col_ownership().first_index();
+  for (size_t i = 0; i < a.nrow(); i++) {
+    size_t dis_i = first_dis_i + i;
+    typename csr<T>::const_iterator ia = a.begin();
+    for (typename csr<T>::const_data_iterator ap = ia[i]; ap < ia[i+1]; ap++) {
+      size_t j = (*ap).first;
+      size_t dis_j =  first_dis_j + j;
+      if (dis_i <= dis_j) csr_upper_dia_nnz++;
+    }
+  }
+  return csr_upper_dia_nnz;
+}
 // compute how many a.ext (dis_i,pa_j) have dis_i > dis_j
 template<class T>
 static
 size_t
-compute_csr_lower_ext_nnz (const csr<T>& a) 
+compute_csr_upper_ext_nnz (const csr<T>& a) 
 {
-  size_t csr_lower_ext_nnz = 0;
+  size_t csr_upper_ext_nnz = 0;
   size_t first_dis_i = a.row_ownership().first_index();
   size_t first_dis_j = a.col_ownership().first_index();
   for (size_t i = 0; i < a.nrow(); i++) {
@@ -105,20 +125,20 @@ compute_csr_lower_ext_nnz (const csr<T>& a)
     for (typename csr<T>::const_data_iterator ap = ext_ia[i]; ap < ext_ia[i+1]; ap++) {
       const size_t& jext = (*ap).first;
       size_t dis_j =  a.jext2dis_j (jext);
-      if (dis_i > dis_j) csr_lower_ext_nnz++;
+      if (dis_i <= dis_j) csr_upper_ext_nnz++;
     }
   }
-  return csr_lower_ext_nnz;
+  return csr_upper_ext_nnz;
 }
 template<class T>
 void
 solver_pastix_rep<T,distributed>::load_symmetric (const csr<T>& a) 
 {
-  check_macro ((a.nnz()-a.ncol()) % 2 == 0, "factorization: symmetric csr has unsymmetric structure");
   // conserve only the lower part of the csc(pastix) = the upper past of the csr(rheolef)
   size_t n   = a.nrow();
-  size_t csr_lower_ext_nnz = compute_csr_lower_ext_nnz(a);
-  size_t nnz = a.nnz() - (a.nnz() - a.nrow())/2 + a.ext_nnz() - csr_lower_ext_nnz;
+  size_t csr_upper_dia_nnz = compute_csr_upper_dia_nnz(a);
+  size_t csr_upper_ext_nnz = compute_csr_upper_ext_nnz(a);
+  size_t nnz = csr_upper_dia_nnz + csr_upper_ext_nnz;
   resize (n, nnz);
   load_both_continued (a);
 }
@@ -156,7 +176,7 @@ solver_pastix_rep<T,distributed>::load_both_continued (const csr<T>& a)
     }
     base::_ptr [i+1] = bp + base::_base;
   }
-  check_macro (bp == base::_nnz, "factorization: invalid nnz count");
+  check_macro (bp == base::_nnz, "factorization: invalid count: nnz="<<base::_nnz<<", count="<<bp);
 }
 template<class T>
 void
@@ -164,7 +184,6 @@ solver_pastix_rep<T,distributed>::update_values (const csr<T>& a)
 {
   if (base::_have_pastix_bug_small_matrix) {
    base::_a_when_bug = a;
-    warning_macro ("update: bug, circumvent !");
     return;
   }
   check_macro (size_t(base::_n) == a.nrow() && size_t(base::_n) == a.ncol(),
@@ -175,8 +194,9 @@ solver_pastix_rep<T,distributed>::update_values (const csr<T>& a)
     nnz_a = a.nnz() + a.ext_nnz();
   } else {
     // conserve only the lower part of the csc(pastix) = the upper past of the csr(rheolef)
-    size_t csr_lower_ext_nnz = compute_csr_lower_ext_nnz(a);
-    nnz_a = a.nnz() - (a.nnz() - a.nrow())/2 + a.ext_nnz() - csr_lower_ext_nnz;
+    size_t csr_upper_dia_nnz = compute_csr_upper_dia_nnz(a);
+    size_t csr_upper_ext_nnz = compute_csr_upper_ext_nnz(a);
+    nnz_a = csr_upper_dia_nnz + csr_upper_ext_nnz;
   }
   check_macro (size_t(base::_nnz) == nnz_a,
     "update: local input matrix nnz distribution mismatch: nnz="<<nnz_a<<", expect nnz="<<base::_nnz);
@@ -223,7 +243,7 @@ solver_pastix_rep<T,distributed>::check () const
   /**
    * Pastix matrix needs :
    *    - to be in fortran numbering
-   *    - to have only the lower triangular part in symmetric case
+   *    - to have only the lower-csc (=upper-csr) triangular part in symmetric case
    *    - to have a graph with a symmetric structure in unsymmetric case
    */
   pastix_int_t  symmetry = (is_symmetric() ? API_SYM_YES : API_SYM_NO);
@@ -236,17 +256,14 @@ solver_pastix_rep<T,distributed>::check () const
            base::_n, &ptr_begin, &idx_begin, &val_begin, &i2dis_i_base_begin,
 		     1); 
   check_macro (status == 0, "pastix check returns error status = " << status);
-  warning_macro ("pastix matrix check: ok");
 }
 template<class T>
 void
 solver_pastix_rep<T,distributed>::symbolic_factorization ()
 {
   if (base::_have_pastix_bug_small_matrix) {
-    warning_macro ("sym_fact: bug, circumvent !");
     return;
   }
-  warning_macro ("sym_fact [1]...");
   const pastix_int_t nbthread = 1; // threads are not yet very well supported with openmpi & scotch
   const pastix_int_t ordering = 0; // scotch
 
@@ -282,15 +299,14 @@ solver_pastix_rep<T,distributed>::symbolic_factorization ()
   base::_iparm[IPARM_VERBOSE]             = base::_opt.verbose_level;
   base::_iparm[IPARM_ORDERING]            = ordering;
   bool do_incomplete;
-  if (base::_opt.incomplete != solver_option_type::decide) {
-    do_incomplete = (base::_opt.incomplete != 0);
+  if (base::_opt.iterative != solver_option_type::decide) {
+    do_incomplete = (base::_opt.iterative != 0);
   } else {
     do_incomplete = (base::_pattern_dimension > 2); // 3d-pattern => iterative & IC(k) precond
   }
-  warning_macro ("do_incomplete = " << do_incomplete);
   base::_iparm[IPARM_INCOMPLETE]          = (do_incomplete ? 1 : 0);
   base::_iparm[IPARM_OOC_LIMIT]           = base::_opt.ooc;
-  if (base::_opt.incomplete == 1) {
+  if (base::_opt.iterative == 1) {
       base::_dparm[DPARM_EPSILON_REFINEMENT] = base::_opt.tol;
   }
   base::_iparm[IPARM_LEVEL_OF_FILL]       = base::_opt.level_of_fill;
@@ -301,12 +317,6 @@ solver_pastix_rep<T,distributed>::symbolic_factorization ()
   //     i2new_dis_i[i] = i2new_dis_i [i]
   base::_i2new_dis_i.resize (base::_n);
 
-  warning_macro ("sym_fact [2] i2new_dis_i...");
-  warning_macro ("sym_fact [2] n="<<base::_n);
-  warning_macro ("sym_fact [2] _ptr.begin="<< base::_ptr.begin().operator->());
-  warning_macro ("sym_fact [2] _idx.begin="<< base::_idx.begin().operator->());
-  warning_macro ("sym_fact [2] _i2dis_i_base.begin="<< _i2dis_i_base.begin().operator->());
-  warning_macro ("sym_fact [2] _i2new_dis_i.begin="<< base::_i2new_dis_i.begin().operator->());
   pastix_int_t itmp = 0; // pastix does not manage NULL pointers: when n=0, vector::begin() retuns a NULL...
   T       vtmp = 0; // pastix does not manage NULL pointers: when n=0, vector::begin() retuns a NULL...
 
@@ -317,7 +327,6 @@ solver_pastix_rep<T,distributed>::symbolic_factorization ()
   base::_iparm[IPARM_START_TASK]          = API_TASK_ORDERING;
   base::_iparm[IPARM_END_TASK]            = API_TASK_ANALYSE;
 
-  warning_macro ("sym_fact [3] call pastix...");
   d_dpastix (base::pp_data(), 
 	  _comm, 
 	  base::_n, 
@@ -331,29 +340,23 @@ solver_pastix_rep<T,distributed>::symbolic_factorization ()
           1,
           base::_iparm,
           base::_dparm);
-  warning_macro ("sym_fact [3] call pastix done");
 
-  warning_macro ("sym_fact [3] call getLocalNodeNbr...");
   _new_n = d_pastix_getLocalNodeNbr (base::pp_data());
-  warning_macro ("sym_fact [3] call getLocalNodeNbr done");
   
   // 2) buil new local to global column correspondance  
   //  new_i2dis_i_base[new_i] - base = new_i2dis_i [new_i] with a base=1
-  warning_macro ("sym_fact [3] new_i2dis_i...");
   base::_new_i2dis_i_base.resize (_new_n);
   d_pastix_getLocalNodeLst (base::pp_data(), base::_new_i2dis_i_base.begin().operator->());
-  warning_macro ("sym_fact done");
 }
 template<class T>
 void
 solver_pastix_rep<T,distributed>::numeric_factorization ()
 {
   if (base::_have_pastix_bug_small_matrix) {
-    warning_macro ("num_fact: bug, circumvent !");
+    trace_macro ("num_fact: bug, circumvent !");
     return;
   }
   // 3) redistributing the matrix in the new numbering
-  warning_macro ("num_fact [1] perm(a) & perm(b)...");
   pastix_int_t status2 = d_cscd_redispatch (
 	  base::_n, 
           base::_ptr.begin().operator->(),
@@ -372,7 +375,6 @@ solver_pastix_rep<T,distributed>::numeric_factorization ()
 
   // pastix tasks:
   //    4. numerical factorization
-  warning_macro ("num_fact [2] factorise...");
   base::_iparm[IPARM_START_TASK]          = API_TASK_NUMFACT;
   base::_iparm[IPARM_END_TASK]            = API_TASK_NUMFACT;
   d_dpastix (base::pp_data(), 
@@ -388,12 +390,10 @@ solver_pastix_rep<T,distributed>::numeric_factorization ()
 	  0,
 	  base::_iparm,
 	  base::_dparm);
-
-  warning_macro ("num fact done");
 }
 template<class T>
 vec<T>
-solver_pastix_rep<T,distributed>::trans_solve (const vec<T>& rhs)
+solver_pastix_rep<T,distributed>::trans_solve (const vec<T>& rhs) const
 {
   if (base::_have_pastix_bug_small_matrix) {
     error_macro ("trans_solve: bug, circumvent not yet !");
@@ -401,7 +401,6 @@ solver_pastix_rep<T,distributed>::trans_solve (const vec<T>& rhs)
   // ================================================================
   // solve
   // ================================================================
-  warning_macro ("trans_solve [1]... n="<<base::_n<<", new_n="<<_new_n);
   check_macro (rhs.size() == size_t(base::_n), "invalid rhs size="<<rhs.size()<<": expect size="<<base::_n);
 
   // redispatch rhs separately: formally: new_rhs [new_i] := rhs [i2new_i[i]]
@@ -423,10 +422,8 @@ solver_pastix_rep<T,distributed>::trans_solve (const vec<T>& rhs)
     }
   }
   // external terms: TODO: scatter begin&end in the symbolic step
-  warning_macro ("trans_solve [2] perm(rhs) scatter size="<<dis_i_set.size()<<", n="<<base::_n<<", new_n="<<_new_n);
   std::map<size_t,T> dis_i_map;
   rhs.get_dis_entry (dis_i_set, dis_i_map);
-  warning_macro ("strans_solve [2] perm(rhs) scatter done");
   for (typename map<size_t,T>::const_iterator
      iter = dis_i_map.begin(),
      last = dis_i_map.end(); iter != last; iter++) {
@@ -439,7 +436,6 @@ solver_pastix_rep<T,distributed>::trans_solve (const vec<T>& rhs)
   //    5. numerical solve
   //    6. numerical refinement
   //    7. clean
-  warning_macro ("trans_solve [3] solve...new_rhs.ptr="<< base::_new_rhs.begin().operator->());
   T vtmp = 0; // pastix does not manage NULL rhs pointer: when new_n=0, but vector::begin() retuns a NULL...
   base::_iparm[IPARM_START_TASK]          = API_TASK_SOLVE;
   base::_iparm[IPARM_END_TASK]            = API_TASK_REFINE;
@@ -458,45 +454,36 @@ solver_pastix_rep<T,distributed>::trans_solve (const vec<T>& rhs)
 	  base::_dparm);
 
   // new_i2dis_i_base [new_i] - base = new_i2dis_i [new_i]
-  warning_macro ("trans_solve [4] perm(x)...");
   vec<T> x (base::_csr_row_ownership);
   for (pastix_int_t new_i = 0; new_i < _new_n; new_i++) {
     size_t dis_i = base::_new_i2dis_i_base [new_i] - base::_base;
     x.dis_entry (dis_i) = base::_new_rhs[new_i];
   }
   x.dis_entry_assembly();
-  warning_macro ("trans_solve done");
   return x;
 }
 template<class T>
 vec<T>
-solver_pastix_rep<T,distributed>::solve (const vec<T>& rhs)
+solver_pastix_rep<T,distributed>::solve (const vec<T>& rhs) const
 {
-  dis_warning_macro ("solve...");
-  warning_macro ("solve: have_bug="<<base::_have_pastix_bug_small_matrix);
   if (base::_have_pastix_bug_small_matrix) {
-    warning_macro ("solve: bug, circumvent !");
     T tol = std::numeric_limits<T>::epsilon();
     size_t max_iter = 1000; // TODO: use _opt to get tol & max_iter
     vec<T> x (base::_a_when_bug.col_ownership(), 0);
-    warning_macro ("solve: x.dis_size="<<x.dis_size()<<", x.size="<<x.size());
-    warning_macro ("solve: pcg...");
-    int status = pcg (base::_a_when_bug, x, rhs, eye<T>(), max_iter, tol, &dcerr);
-    warning_macro ("solve: pcg done");
+    int status = pcg (base::_a_when_bug, x, rhs, eye<T>(), max_iter, tol, &derr);
     check_macro (tol < std::numeric_limits<T>::epsilon(), "solver(cg): machine precision not reached: "<<tol);
     return x;
   }
   // TODO: make a csc<T> wrapper arround csr<T> and use csc<T> in form & form_assembly
   // => avoid the transposition
   if (! base::_is_sym) {
-    warning_macro ("solve: not yet supported for unsymmetric matrix; continue with trans_solve....");
+    warning_macro ("solve: not yet supported for unsymmetric matrix");
   }
   return trans_solve (rhs);
 }
 template<class T>
 solver_pastix_rep<T,distributed>::~solver_pastix_rep()
 {
-  warning_macro ("dstor...");
   // tasks:
   //    7. clean
   base::_iparm[IPARM_START_TASK]          = API_TASK_CLEAN;
@@ -517,12 +504,10 @@ solver_pastix_rep<T,distributed>::~solver_pastix_rep()
 	  base::_dparm);
 
   // was allocated by d_cscd_redispatch()
-  warning_macro ("dstor call free...");
   if (_new_ptr != NULL) free (_new_ptr);
   if (_new_idx != NULL) free (_new_idx);
   if (_new_val != NULL) free (_new_val);
   base::_pastix_data = 0; 
-  warning_macro ("dstor done");
 }
 // ----------------------------------------------------------------------------
 // instanciation in library
