@@ -24,10 +24,13 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"8"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
+status=0
 if test "$MPIRUN" = ""; then
   echo "      (skipped)"
 else
   run "awk -f array_of_idxset_gen.awk > tmp.valid" 
   loop_mpirun "./array_of_idxset_io_tst < tmp.valid 2> /dev/null | diff -w -B tmp.valid - >/dev/null" 
+  status=$?
   run "rm -f tmp.valid" 
 fi
+exit $status
