@@ -36,35 +36,22 @@ int main(int argc, char**argv) {
     switch (comm.rank()) {
       case 0: {
 	x[0] += 100;
-	index_set val;
-	val += 201;
-	val += 301;
-	x.dis_entry(1) += val;
+	x.dis_entry(1) += 201;
+	x.dis_entry(1) += 301;
 	break;
       }
       case 1: {
 	x[0] += 101;
-	index_set val;
-	val += 200;
-	x.dis_entry(1) += val;
+	x.dis_entry(1) += 200;
 	break;
       }
       case 2: {
 	x[0] += 102;
-	index_set val;
-	val += 401;
-#define BUG
-#ifdef BUG
-	x.dis_entry(1) += val;
-#else // BUG
-	x.dis_entry(2) += val;
-#endif // BUG
+	x.dis_entry(1) += 401;
 	break;
       }
     }
-    x.dis_entry_assembly (index_set_add_op<index_set,index_set>());
+    x.dis_entry_assembly();
     dout << x.dis_size() << std::endl
          << x            << std::endl;
-#ifdef TODO
-#endif // TODO
 }
