@@ -27,8 +27,10 @@ NPROC_MAX=${NPROC_MAX-"8"}
 #echo "      (not yet)"
 #exit 0
 
-if test "$MPIRUN" = ""; then
-  echo "      (skipped)"
+if test "$MPIRUN" = "" || test "$NPROC_MAX" -lt 3; then
+  echo "      skipped (requiers np >= 3)"
 else
   run "$MPIRUN -np 3 ./array_of_idxset_tst 2> /dev/null | diff -w -B array_of_idxset_tst.valid - >/dev/null" 
+  status=$?
+  exit $status
 fi
