@@ -46,7 +46,7 @@ int main(int argc, char**argv) {
 	x.dis_entry(1) += 401;
 	break;
     }
-    x.dis_entry_assembly (set_add_op<size_t,size_t>());
+    x.dis_entry_assembly (set_add_op<size_t,size_t>()); // overwrite default that is set_op<>
     dout << x.dis_size() << std::endl
          << x            << std::endl;
 }
