@@ -25,9 +25,11 @@ NPROC_MAX=${NPROC_MAX-"7"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 if test "$MPIRUN" = "" || test "$NPROC_MAX" -le 2; then
-  echo "      (skipped)"
+  echo "      skipped (requiers np >= 2)"
 else
-  run "$MPIRUN -np 2 ./mpi_boost_nonblocking_array_of_idxset2_tst 2>/dev/null | sort -n | diff -w -B mpi_boost_nonblocking_array_of_idxset2_tst.valid -"
+  run "rm -f ./mpi_boost_nonblocking_array_of_idxset2_tst-[01]"
+  run "$MPIRUN -np 2 ./mpi_boost_nonblocking_array_of_idxset2_tst 2>/dev/null && cat ./mpi_boost_nonblocking_array_of_idxset2_tst-[01] | diff -w -B mpi_boost_nonblocking_array_of_idxset2_tst.valid -"
   status=$?
+  run "rm -f ./mpi_boost_nonblocking_array_of_idxset2_tst-[01]"
   exit $status
 fi
