@@ -24,8 +24,18 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"7"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-if test "$MPIRUN" = ""; then
-  echo "      (skipped)"
+#echo "    (skipped for foehn)" # TODO
+#exit 0
+
+status=0
+
+if test "$MPIRUN" = "" || test "$NPROC_MAX" -lt 2; then
+  echo "      skipped (requiers np >= 2)"
 else
-  run "$MPIRUN -np 2 ./mpi_boost_nonblocking_array_of_idxset_tst 2>/dev/null | sort -n | diff -w -B mpi_boost_nonblocking_array_of_idxset_tst.valid -"
+  run "rm -f ./mpi_boost_nonblocking_array_of_idxset_tst-[01]"
+  run "$MPIRUN -np 2 ./mpi_boost_nonblocking_array_of_idxset_tst 2>/dev/null && cat ./mpi_boost_nonblocking_array_of_idxset_tst-[01] | diff -w -B mpi_boost_nonblocking_array_of_idxset_tst.valid -"
+  if test $? -ne 0; then status=1; break; fi
+  run "rm -f ./mpi_boost_nonblocking_array_of_idxset_tst-[01]"
 fi
+
+exit $status
