@@ -44,7 +44,7 @@ namespace boost {
 // -------------------------------------------------------------
 typedef pair<size_t,double> pair_t;
 int main(int argc, char* argv[]) {
-  environment distributed(argc, argv);
+  environment rheolef(argc, argv);
   mpi::communicator comm;
   if (comm.size() != 2) return 0;
   if (comm.rank() == 0) {
