@@ -24,7 +24,7 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"7"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-echo "MPI_TST..."
+#echo "MPI_TST..."
 
 if test "$MPIRUN" = ""; then
   echo "      (skipped)"
