@@ -49,7 +49,7 @@ struct phi : unary_function<Float,Float> {
   Float operator() (const Float& x) { return 2*x; }
 };
 int main(int argc, char**argv) {
-    environment distributed(argc, argv);
+    environment rheolef(argc, argv);
     size_t n = (argc < 2) ? 5 : atoi(argv[1]);
     vec<Float> x(n, 2.5);
     vec<Float> y(n, 4.);
@@ -57,34 +57,34 @@ int main(int argc, char**argv) {
     // set size and then assign:
     vec<Float> z(n); 
     z = 2*x - y;
-    dcout << "z = 2*x-y : z.dis_size = " << z.dis_size() << endl;
-    z.put_values (dcout);
+    dout << "z = 2*x-y : z.dis_size = " << z.dis_size() << endl;
+    z.put_values (dout);
     
     // size is zero and then assign:
     vec<Float> z1; 
     z1 = 2*x - y;
-    dcout << "z1.dis_size = " << z1.dis_size() << endl;
-    z1.put_values (dcout);
+    dout << "z1.dis_size = " << z1.dis_size() << endl;
+    z1.put_values (dout);
     
     // copy cstor:
     vec<Float> z2 = 2*x - y;
-    dcout << "z2.dis_size = " << z2.dis_size() << endl;
-    z2.put_values (dcout);
+    dout << "z2.dis_size = " << z2.dis_size() << endl;
+    z2.put_values (dout);
 
     check_iterator_access  (x+y);
     check_subscript_access (x+y);
 
     // dot with expression (lazy evaluation)
-    dcout << "dot(x, z) = " << dot(x, z) << endl;
-    dcout << "dot(x, 2*x-y) = " << dot(x, 2*x - y) << endl;
-    dcout << "dot(2*x-y, x) = " << dot(2*x-y, x) << endl;
-    dcout << "dot(3*x-y, 2*x-y) = " << dot(3*x-y, 2*x-y) << endl;
+    dout << "dot(x, z) = " << dot(x, z) << endl;
+    dout << "dot(x, 2*x-y) = " << dot(x, 2*x - y) << endl;
+    dout << "dot(2*x-y, x) = " << dot(2*x-y, x) << endl;
+    dout << "dot(3*x-y, 2*x-y) = " << dot(3*x-y, 2*x-y) << endl;
 
 #ifdef TO_CLEAN    
     // set bad size and then assign: it may exit(1)
     vec<Float> z3(n+1); 
     z3 = 2*x - y;
-    dcout << "z3 = " << z3.size() << endl;
-    z3.put_values (dcout);
+    dout << "z3 = " << z3.size() << endl;
+    z3.put_values (dout);
 #endif // TO_CLEAN    
 }
