@@ -119,7 +119,7 @@ void Triangles::Read(MeshIstream & f_in,int Version,Real8 cutoffradian)
 	   nbvx=nbv;
 	   vertices=new Vertex[nbvx];
 	   assert(vertices);
-	   ordre=new (Vertex* [nbvx]);
+	   ordre=new (Vertex* [this->nbvx]);
 	   assert(ordre);
 	   
 	   nbiv = nbv;
@@ -392,14 +392,14 @@ void Triangles::Read_am_fmt(MeshIstream & f_in)
      Int4 i;
      f_in.cm() >> nbv >> nbt ;
      if (verbosity>3)
-       cout << "    nbv = " << nbv  << " nbt = " << nbt << endl;
+       cout << "    nbv = |" << nbv  << "|; nbt = " << nbt << endl;
      f_in.eol() ;// 
      nbvx = nbv;
      nbtx =  2*nbv-2; // for filling The Holes and quadrilaterals 
      triangles =new Triangle[nbtx];
      assert(triangles);
      vertices=new Vertex[nbvx];
-     ordre=new (Vertex* [nbvx]);
+     ordre=new (Vertex* [this->nbvx]);
      
      for (     i=0;i<nbt;i++)
        {
@@ -448,7 +448,7 @@ void  Triangles::Read_am(MeshIstream &ff)
   triangles =new Triangle[nbtx];
   assert(triangles);
   vertices=new Vertex[nbvx];
-  ordre=new (Vertex* [nbvx]);
+  ordre=new (Vertex* [this->nbvx]);
   
 
   Int4 i;
@@ -547,7 +547,7 @@ void  Triangles::Read_nopo(MeshIstream & ff)
   triangles =new Triangle[nbtx];
   assert(triangles);
   vertices=new Vertex[nbvx];
-  ordre=new (Vertex* [nbvx]);
+  ordre=new (Vertex* [this->nbvx]);
 
 
  f_in >> l;
@@ -711,7 +711,7 @@ void  Triangles::Read_nopo(MeshIstream & ff)
   triangles =new Triangle[nbtx];
   assert(triangles);
   vertices=new Vertex[nbvx];
-  ordre=new (Vertex* [nbvx]);
+  ordre=new (Vertex* [this->nbvx]);
   Int4 k=0;
   
   for ( i=0;i<ne;i++) 
@@ -774,7 +774,7 @@ void  Triangles::Read_msh(MeshIstream &f_in)
      triangles =new Triangle[nbtx];
      assert(triangles);
      vertices=new Vertex[nbvx];
-     ordre=new (Vertex* [nbvx]);
+     ordre=new (Vertex* [this->nbvx]);
       edges = new Edge[nbe];
      for ( i=0;i<nbv;i++)
 	{
@@ -822,7 +822,7 @@ void  Triangles::Read_amdba(MeshIstream &f_in )
      triangles =new Triangle[nbtx];
      assert(triangles);
      vertices=new Vertex[nbvx];
-     ordre=new (Vertex* [nbvx]);
+     ordre=new (Vertex* [this->nbvx]);
      Int4 j;
       for ( i=0;i<nbv;i++)
 	{
@@ -1149,6 +1149,7 @@ void Geometry::ReadGeometry(MeshIstream & f_in,const char * filename)
           
           for (i=0;i<n;i++) {     
             f_in  >>  j ;
+	    cout << "BUG TRACE: j="<<j<<", nbv="<<nbv<<endl;
             assert( j <= nbv );
             assert( j > 0 );
             j--;
