@@ -67,13 +67,13 @@ public:
 
 // typedefs:
 
-    typedef size_t    size_type;
-    typedef ptrdiff_t difference_type;
-    typedef T*        pointer;
-    typedef const T*  const_pointer;
-    typedef T&        reference;
-    typedef const T&  const_reference;
-    typedef T         value_type;
+    typedef size_t         size_type;
+    typedef std::ptrdiff_t difference_type;
+    typedef T*             pointer;
+    typedef const T*       const_pointer;
+    typedef T&             reference;
+    typedef const T&       const_reference;
+    typedef T              value_type;
 
 // constructors:
 
@@ -125,6 +125,9 @@ public:
         // placement new operator:
         new( reinterpret_cast<void*>(p) ) T(c);
     }
+    // C++ 2011: default construct a value of type T at the location referenced by p
+    void construct (pointer p) { new ( reinterpret_cast<void*>(p) ) T(); }
+
     void destroy (pointer p)
     {
         // call destructor directly:
