@@ -167,21 +167,27 @@ public:
 protected:
     std::ifstream _ifs;
 };
+static const bool dont_gzip = false;
 class orheostream : public io::filtering_stream<io::output> {
 public:
     orheostream() : io::filtering_stream<io::output>() {}
-    orheostream(const std::string& name, const std::string& suffix = std::string());
+    orheostream(const std::string& name, const std::string& suffix = std::string(),
+	bool use_gzip = true);
     virtual ~orheostream();
-    void open  (const std::string& name, const std::string& suffix = std::string());
+    void open  (const std::string& name, const std::string& suffix = std::string(),
+	bool use_gzip = true);
+    void flush();
     void close();
 protected:
     std::ofstream _ofs;
+    bool          _use_gzip;
+    std::string   _full_name;
 };
 std::string itos (std::string::size_type i);
 std::string ftos (const Float& x);
 
 // catch first occurence of string in file
-bool scatch (std::istream& in, const std::string& ch);
+bool scatch (std::istream& in, const std::string& ch, bool full_match = true);
 
 // has_suffix("toto.suffix", "suffix") -> true
 bool has_suffix (const std::string& name, const std::string& suffix);
